@@ -1,7 +1,4 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
+# SPDX-License-Identifier: Apache-2.0
 
 import numpy as np  # type: ignore
 
@@ -14,7 +11,7 @@ from typing import Sequence
 class SingleSign(Base):
 
     @staticmethod
-    def export():  # type: () -> None
+    def export() -> None:
         node = onnx.helper.make_node(
             'Sign', ['x'], ['y'], name='test')
 
@@ -30,6 +27,6 @@ class SingleSign(Base):
             outputs=[onnx.helper.make_tensor_value_info('y',
                                                         onnx.TensorProto.FLOAT,
                                                         [7])])
-        model = onnx.helper.make_model(graph, producer_name='backend-test')
+        model = onnx.helper.make_model_gen_version(graph, producer_name='backend-test', opset_imports=[onnx.helper.make_opsetid("", 9)])
         expect(model, inputs=[x], outputs=[y],
                name='test_sign_model')
