@@ -1,7 +1,4 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
+# SPDX-License-Identifier: Apache-2.0
 
 import numpy as np  # type: ignore
 
@@ -13,7 +10,7 @@ from . import expect
 class SingleRelu(Base):
 
     @staticmethod
-    def export():  # type: () -> None
+    def export() -> None:
 
         node = onnx.helper.make_node(
             'Relu', ['x'], ['y'], name='test')
@@ -24,7 +21,7 @@ class SingleRelu(Base):
                 'x', onnx.TensorProto.FLOAT, [1, 2])],
             outputs=[onnx.helper.make_tensor_value_info(
                 'y', onnx.TensorProto.FLOAT, [1, 2])])
-        model = onnx.helper.make_model(graph, producer_name='backend-test')
+        model = onnx.helper.make_model_gen_version(graph, producer_name='backend-test', opset_imports=[onnx.helper.make_opsetid("", 9)])
 
         x = np.random.randn(1, 2).astype(np.float32)
         y = np.maximum(x, 0)
