@@ -1,7 +1,4 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
+# SPDX-License-Identifier: Apache-2.0
 
 import numpy as np  # type: ignore
 
@@ -13,7 +10,7 @@ from . import expect
 class Add(Base):
 
     @staticmethod
-    def export():  # type: () -> None
+    def export() -> None:
         node = onnx.helper.make_node(
             'Add',
             inputs=['x', 'y'],
@@ -26,7 +23,20 @@ class Add(Base):
                name='test_add')
 
     @staticmethod
-    def export_add_broadcast():  # type: () -> None
+    def export_add_uint8() -> None:
+        node = onnx.helper.make_node(
+            'Add',
+            inputs=['x', 'y'],
+            outputs=['sum'],
+        )
+
+        x = np.random.randint(24, size=(3, 4, 5), dtype=np.uint8)
+        y = np.random.randint(24, size=(3, 4, 5), dtype=np.uint8)
+        expect(node, inputs=[x, y], outputs=[x + y],
+               name='test_add_uint8')
+
+    @staticmethod
+    def export_add_broadcast() -> None:
         node = onnx.helper.make_node(
             'Add',
             inputs=['x', 'y'],
