@@ -1,7 +1,4 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
+# SPDX-License-Identifier: Apache-2.0
 
 import numpy as np  # type: ignore
 
@@ -13,7 +10,7 @@ from . import expect
 class Constant(Base):
 
     @staticmethod
-    def export():  # type: () -> None
+    def export() -> None:
         values = np.random.randn(5, 5).astype(np.float32)
         node = onnx.helper.make_node(
             'Constant',
