@@ -1,7 +1,4 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
+# SPDX-License-Identifier: Apache-2.0
 
 import numpy as np  # type: ignore
 
@@ -13,7 +10,7 @@ from . import expect
 class GlobalMaxPool(Base):
 
     @staticmethod
-    def export():  # type: () -> None
+    def export() -> None:
 
         node = onnx.helper.make_node(
             'GlobalMaxPool',
@@ -21,14 +18,11 @@ class GlobalMaxPool(Base):
             outputs=['y'],
         )
         x = np.random.randn(1, 3, 5, 5).astype(np.float32)
-        spatial_shape = np.ndim(x) - 2
-        y = np.max(x, axis=tuple(range(spatial_shape, spatial_shape + 2)))
-        for _ in range(spatial_shape):
-            y = np.expand_dims(y, -1)
+        y = np.max(x, axis=tuple(range(2, np.ndim(x))), keepdims=True)
         expect(node, inputs=[x], outputs=[y], name='test_globalmaxpool')
 
     @staticmethod
-    def export_globalmaxpool_precomputed():  # type: () -> None
+    def export_globalmaxpool_precomputed() -> None:
 
         node = onnx.helper.make_node(
             'GlobalMaxPool',
