@@ -1,10 +1,5 @@
 # SPDX-License-Identifier: Apache-2.0
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import numpy as np  # type: ignore
 
 import onnx
@@ -15,7 +10,7 @@ from . import expect
 class IsInf(Base):
 
     @staticmethod
-    def export_infinity():  # type: () -> None
+    def export_infinity() -> None:
         node = onnx.helper.make_node('IsInf',
                                      inputs=['x'],
                                      outputs=['y'],
@@ -27,7 +22,7 @@ class IsInf(Base):
         expect(node, inputs=[x], outputs=[y], name='test_isinf')
 
     @staticmethod
-    def export_positive_infinity_only():  # type: () -> None
+    def export_positive_infinity_only() -> None:
         node = onnx.helper.make_node('IsInf',
                                      inputs=['x'],
                                      outputs=['y'],
@@ -40,7 +35,7 @@ class IsInf(Base):
         expect(node, inputs=[x], outputs=[y], name='test_isinf_positive')
 
     @staticmethod
-    def export_negative_infinity_only():  # type: () -> None
+    def export_negative_infinity_only() -> None:
         node = onnx.helper.make_node('IsInf',
                                      inputs=['x'],
                                      outputs=['y'],
