@@ -1,7 +1,4 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
+# SPDX-License-Identifier: Apache-2.0
 
 import numpy as np  # type: ignore
 
@@ -13,7 +10,7 @@ from . import expect
 class LeakyRelu(Base):
 
     @staticmethod
-    def export():  # type: () -> None
+    def export() -> None:
         node = onnx.helper.make_node(
             'LeakyRelu',
             inputs=['x'],
@@ -33,7 +30,7 @@ class LeakyRelu(Base):
                name='test_leakyrelu')
 
     @staticmethod
-    def export_leakyrelu_default():  # type: () -> None
+    def export_leakyrelu_default() -> None:
         default_alpha = 0.01
         node = onnx.helper.make_node(
             'LeakyRelu',
