@@ -1,7 +1,4 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
+# SPDX-License-Identifier: Apache-2.0
 
 import numpy as np  # type: ignore
 import onnx
@@ -12,7 +9,7 @@ from . import expect
 class MatMulInteger(Base):
 
     @staticmethod
-    def export():  # type: () -> None
+    def export() -> None:
         node = onnx.helper.make_node('MatMulInteger',
             inputs=['A', 'B', 'a_zero_point', 'b_zero_point'],
             outputs=['Y'],)
