@@ -1,7 +1,4 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
+# SPDX-License-Identifier: Apache-2.0
 
 import numpy as np  # type: ignore
 
@@ -13,14 +10,14 @@ from . import expect
 class NonZero(Base):
 
     @staticmethod
-    def export():  # type: () -> None
+    def export() -> None:
         node = onnx.helper.make_node(
             'NonZero',
             inputs=['condition'],
             outputs=['result'],
         )
 
-        condition = np.array([[1, 0], [1, 1]], dtype=np.bool)
-        result = np.array((np.nonzero(condition)))  # expected output [[0, 1, 1], [0, 0, 1]]
+        condition = np.array([[1, 0], [1, 1]], dtype=bool)
+        result = np.array(np.nonzero(condition), dtype=np.int64)  # expected output [[0, 1, 1], [0, 0, 1]]
         expect(node, inputs=[condition], outputs=[result],
                name='test_nonzero_example')
