@@ -1,18 +1,14 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
+# SPDX-License-Identifier: Apache-2.0
 
 import numpy as np  # type: ignore
 
 import onnx
 from ..base import Base
 from . import expect
-from typing import Any, List, Callable, Union, Optional, Text
+from typing import Any, List, Callable, Union, Optional
 
 
-def cartesian(arrays, out=None):
-    # type: (List[np.ndarray], np.ndarray) -> np.ndarray
+def cartesian(arrays: List[np.ndarray], out: np.ndarray = None) -> np.ndarray:
     """
     From https://stackoverflow.com/a/1235363
     Generate a cartesian product of input arrays.
@@ -60,16 +56,16 @@ def cartesian(arrays, out=None):
     return out
 
 
-def interpolate_1d_with_x(data,                                             # type: np.ndarray
-                          scale_factor,                                     # type: float
-                          x,                                                # type: float
-                          get_coeffs,                                       # type: Callable[[float], np.ndarray]
-                          roi=None,                                         # type: np.ndarray
-                          extrapolation_value=0.0,                          # type: float
-                          coordinate_transformation_mode='half_pixel',      # type: Text
-                          exclude_outside=False,                            # type: bool
-                          ):                                                # type: (...) -> np.ndarray
-    def get_neighbor_idxes(x, n, limit):  # type: (float, int, int) -> np.ndarray
+def interpolate_1d_with_x(data: np.ndarray,
+                          scale_factor: float,
+                          x: float,
+                          get_coeffs: Callable[[float], np.ndarray],
+                          roi: np.ndarray = None,
+                          extrapolation_value: float = 0.0,
+                          coordinate_transformation_mode: str = 'half_pixel',
+                          exclude_outside: bool = False,
+                          ) -> np.ndarray:
+    def get_neighbor_idxes(x: float, n: int, limit: int) -> np.ndarray:
         """
         Return the n nearest indexes to x among [0, limit), prefer the indexes smaller than x.
         As a result, the ratio must be in (0, 1]
@@ -90,7 +86,7 @@ def interpolate_1d_with_x(data,                                             # ty
         idxes = sorted(idxes)
         return np.array(idxes)
 
-    def get_neighbor(x, n, data):  # type: (float, int, np.ndarray) -> np.ndarray
+    def get_neighbor(x: float, n: int, data: np.ndarray) -> np.ndarray:
         """
         Pad `data` in 'edge' mode, and get n nearest elements in the padded array and their indexes in the original
         array
@@ -100,7 +96,7 @@ def interpolate_1d_with_x(data,                                             # ty
         :return: A tuple containing the indexes of neighbor elements (the index can be smaller than 0 or higher than
         len(data)) and the value of these elements
         """
-        pad_width = np.ceil(n / 2).astype(np.int)
+        pad_width = np.ceil(n / 2).astype(int)
         padded = np.pad(data, pad_width, mode='edge')
         x += pad_width
 
@@ -127,16 +123,16 @@ def interpolate_1d_with_x(data,                                             # ty
         # Return extrapolation_value directly as what TF CropAndResize does
         if x_ori < 0 or x_ori > input_width - 1:
             return extrapolation_value
-    elif coordinate_transformation_mode == 'tf_half_pixel_for_nn':
-        x_ori = (x + 0.5) / scale_factor
     elif coordinate_transformation_mode == 'pytorch_half_pixel':
         if output_width == 1:
             x_ori = -0.5
         else:
             x_ori = (x + 0.5) / scale_factor - 0.5
-    else:  # coordinate_transformation_mode == 'half_pixel'
+    elif coordinate_transformation_mode == 'half_pixel':
         x_ori = (x + 0.5) / scale_factor - 0.5
-    x_ori_int = np.floor(x_ori).astype(np.int).item()
+    else:
+        raise ValueError(f'invalid coordinate_transformation_mode: {coordinate_transformation_mode}')
+    x_ori_int = np.floor(x_ori).astype(int).item()
 
     # ratio must be in (0, 1] since we prefer the pixel on the left of `x_ori`
     if x_ori.is_integer():
@@ -158,14 +154,14 @@ def interpolate_1d_with_x(data,                                             # ty
     return np.dot(coeffs, points).item()
 
 
-def interpolate_nd_with_x(data,                      # type: np.ndarray
-                          n,                         # type: int
-                          scale_factors,             # type: List[float]
-                          x,                         # type: List[float]
-                          get_coeffs,                # type: Callable[[float], np.ndarray]
-                          roi=None,                  # type: np.ndarray
-                          **kwargs                   # type: Any
-                          ):                         # type: (...) -> np.ndarray
+def interpolate_nd_with_x(data: np.ndarray,
+                          n: int,
+                          scale_factors: List[float],
+                          x: List[float],
+                          get_coeffs: Callable[[float], np.ndarray],
+                          roi: np.ndarray = None,
+                          **kwargs: Any
+                          ) -> np.ndarray:
     if n == 1:
         return interpolate_1d_with_x(data, scale_factors[0], x[0], get_coeffs, roi=roi,
                                      **kwargs)
@@ -178,21 +174,21 @@ def interpolate_nd_with_x(data,                      # type: np.ndarray
         roi=None if roi is None else [roi[0], roi[n]], **kwargs)
 
 
-def interpolate_nd(data,                      # type: np.ndarray
-                   get_coeffs,                # type: Callable[[float], np.ndarray]
-                   output_size=None,          # type: Optional[List[int]]
-                   scale_factors=None,        # type: Optional[List[float]]
-                   roi=None,                  # type: np.ndarray
-                   **kwargs                   # type: Any
-                   ):                         # type: (...) -> np.ndarray
-    def get_all_coords(data):   # type: (np.ndarray) -> np.ndarray
+def interpolate_nd(data: np.ndarray,
+                   get_coeffs: Callable[[float], np.ndarray],
+                   output_size: Optional[List[int]] = None,
+                   scale_factors: Optional[List[float]] = None,
+                   roi: np.ndarray = None,
+                   **kwargs: Any
+                   ) -> np.ndarray:
+    def get_all_coords(data: np.ndarray) -> np.ndarray:
         return cartesian([list(range(data.shape[i])) for i in range(len(data.shape))])
 
     assert output_size is not None or scale_factors is not None
     if output_size is not None:
         scale_factors = np.array(output_size) / np.array(data.shape)
     else:
-        output_size = (scale_factors * np.array(data.shape)).astype(np.int)
+        output_size = (scale_factors * np.array(data.shape)).astype(int)
     assert scale_factors is not None
 
     ret = np.zeros(output_size)
@@ -202,7 +198,7 @@ def interpolate_nd(data,                      # type: np.ndarray
     return ret
 
 
-def cubic_coeffs(ratio, A=-0.75):   # type: (float, float) -> np.ndarray
+def cubic_coeffs(ratio: float, A: float = -0.75) -> np.ndarray:
     coeffs = [((A * (ratio + 1) - 5 * A) * (ratio + 1) + 8 * A) * (ratio + 1) - 4 * A,
               ((A + 2) * ratio - (A + 3)) * ratio * ratio + 1,
               ((A + 2) * (1 - ratio) - (A + 3)) * (1 - ratio) * (1 - ratio) + 1,
@@ -211,11 +207,11 @@ def cubic_coeffs(ratio, A=-0.75):   # type: (float, float) -> np.ndarray
     return np.array(coeffs)
 
 
-def linear_coeffs(ratio):           # type: (float) -> np.ndarray
+def linear_coeffs(ratio: float) -> np.ndarray:
     return np.array([1 - ratio, ratio])
 
 
-def nearest_coeffs(ratio, mode='round_prefer_floor'):          # type: (float, Text) -> np.ndarray
+def nearest_coeffs(ratio: float, mode: str = 'round_prefer_floor') -> np.ndarray:
     if type(ratio) == int or ratio.is_integer():
         return np.array([0, 1])
     elif mode == 'round_prefer_floor':
@@ -231,10 +227,10 @@ def nearest_coeffs(ratio, mode='round_prefer_floor'):          # type: (float, T
 class Resize(Base):
 
     @staticmethod
-    def export_resize_upsample_scales_nearest():  # type: () -> None
+    def export_resize_upsample_scales_nearest() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales'],
+            inputs=['X', '', 'scales'],
             outputs=['Y'],
             mode='nearest',
         )
@@ -244,7 +240,6 @@ class Resize(Base):
             [3, 4],
         ]]], dtype=np.float32)
 
-        roi = np.array([], dtype=np.float32)
         scales = np.array([1.0, 1.0, 2.0, 3.0], dtype=np.float32)
 
         # [[[[1. 1. 1. 2. 2. 2.]
@@ -254,14 +249,14 @@ class Resize(Base):
         output = interpolate_nd(
             data, nearest_coeffs, scale_factors=scales).astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales], outputs=[output],
+        expect(node, inputs=[data, scales], outputs=[output],
                name='test_resize_upsample_scales_nearest')
 
     @staticmethod
-    def export_resize_downsample_scales_nearest():  # type: () -> None
+    def export_resize_downsample_scales_nearest() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales'],
+            inputs=['X', '', 'scales'],
             outputs=['Y'],
             mode='nearest',
         )
@@ -271,21 +266,20 @@ class Resize(Base):
             [5, 6, 7, 8],
         ]]], dtype=np.float32)
 
-        roi = np.array([], dtype=np.float32)
         scales = np.array([1.0, 1.0, 0.6, 0.6], dtype=np.float32)
 
         # [[[[1. 3.]]]]
         output = interpolate_nd(
             data, nearest_coeffs, scale_factors=scales).astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales], outputs=[output],
+        expect(node, inputs=[data, scales], outputs=[output],
                name='test_resize_downsample_scales_nearest')
 
     @staticmethod
-    def export_resize_upsample_sizes_nearest():  # type: () -> None
+    def export_resize_upsample_sizes_nearest() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales', 'sizes'],
+            inputs=['X', '', '', 'sizes'],
             outputs=['Y'],
             mode='nearest',
         )
@@ -295,8 +289,6 @@ class Resize(Base):
             [3, 4],
         ]]], dtype=np.float32)
 
-        roi = np.array([], dtype=np.float32)
-        scales = np.array([], dtype=np.float32)
         sizes = np.array([1, 1, 7, 8], dtype=np.int64)
 
         # [[[[1. 1. 1. 1. 2. 2. 2. 2.]
@@ -309,14 +301,14 @@ class Resize(Base):
         output = interpolate_nd(
             data, nearest_coeffs, output_size=sizes).astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales, sizes], outputs=[output],
+        expect(node, inputs=[data, sizes], outputs=[output],
                name='test_resize_upsample_sizes_nearest')
 
     @staticmethod
-    def export_resize_downsample_sizes_nearest():  # type: () -> None
+    def export_resize_downsample_sizes_nearest() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales', 'sizes'],
+            inputs=['X', '', '', 'sizes'],
             outputs=['Y'],
             mode='nearest',
         )
@@ -326,22 +318,20 @@ class Resize(Base):
             [5, 6, 7, 8],
         ]]], dtype=np.float32)
 
-        roi = np.array([], dtype=np.float32)
-        scales = np.array([], dtype=np.float32)
         sizes = np.array([1, 1, 1, 3], dtype=np.int64)
 
         # [[[[1. 3.]]]]
         output = interpolate_nd(
             data, nearest_coeffs, output_size=sizes).astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales, sizes], outputs=[output],
+        expect(node, inputs=[data, sizes], outputs=[output],
                name='test_resize_downsample_sizes_nearest')
 
     @staticmethod
-    def export_resize_upsample_scales_linear():  # type: () -> None
+    def export_resize_upsample_scales_linear() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales'],
+            inputs=['X', '', 'scales'],
             outputs=['Y'],
             mode='linear',
         )
@@ -351,7 +341,6 @@ class Resize(Base):
             [3, 4],
         ]]], dtype=np.float32)
 
-        roi = np.array([], dtype=np.float32)
         scales = np.array([1.0, 1.0, 2.0, 2.0], dtype=np.float32)
 
         # [[[[1.   1.25 1.75 2.  ]
@@ -361,14 +350,14 @@ class Resize(Base):
         output = interpolate_nd(
             data, linear_coeffs, scale_factors=scales).astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales], outputs=[output],
+        expect(node, inputs=[data, scales], outputs=[output],
                name='test_resize_upsample_scales_linear')
 
     @staticmethod
-    def export_resize_upsample_scales_linear_align_corners():  # type: () -> None
+    def export_resize_upsample_scales_linear_align_corners() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales'],
+            inputs=['X', '', 'scales'],
             outputs=['Y'],
             mode='linear',
             coordinate_transformation_mode='align_corners'
@@ -379,7 +368,6 @@ class Resize(Base):
             [3, 4],
         ]]], dtype=np.float32)
 
-        roi = np.array([], dtype=np.float32)
         scales = np.array([1.0, 1.0, 2.0, 2.0], dtype=np.float32)
 
         # [[[[1.         1.33333333 1.66666667 2.        ]
@@ -389,14 +377,14 @@ class Resize(Base):
         output = interpolate_nd(
             data, linear_coeffs, scale_factors=scales, coordinate_transformation_mode='align_corners').astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales], outputs=[output],
+        expect(node, inputs=[data, scales], outputs=[output],
                name='test_resize_upsample_scales_linear_align_corners')
 
     @staticmethod
-    def export_resize_downsample_scales_linear():  # type: () -> None
+    def export_resize_downsample_scales_linear() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales'],
+            inputs=['X', '', 'scales'],
             outputs=['Y'],
             mode='linear',
         )
@@ -406,21 +394,20 @@ class Resize(Base):
             [5, 6, 7, 8],
         ]]], dtype=np.float32)
 
-        roi = np.array([], dtype=np.float32)
         scales = np.array([1.0, 1.0, 0.6, 0.6], dtype=np.float32)
 
         # [[[[2.6666665 4.3333331]]]]
         output = interpolate_nd(
             data, linear_coeffs, scale_factors=scales).astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales], outputs=[output],
+        expect(node, inputs=[data, scales], outputs=[output],
                name='test_resize_downsample_scales_linear')
 
     @staticmethod
-    def export_resize_downsample_scales_linear_align_corners():  # type: () -> None
+    def export_resize_downsample_scales_linear_align_corners() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales'],
+            inputs=['X', '', 'scales'],
             outputs=['Y'],
             mode='linear',
             coordinate_transformation_mode='align_corners'
@@ -431,21 +418,20 @@ class Resize(Base):
             [5, 6, 7, 8],
         ]]], dtype=np.float32)
 
-        roi = np.array([], dtype=np.float32)
         scales = np.array([1.0, 1.0, 0.6, 0.6], dtype=np.float32)
 
         # [[[[1.       3.142857]]]]
         output = interpolate_nd(
             data, linear_coeffs, scale_factors=scales, coordinate_transformation_mode='align_corners').astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales], outputs=[output],
+        expect(node, inputs=[data, scales], outputs=[output],
                name='test_resize_downsample_scales_linear_align_corners')
 
     @staticmethod
-    def export_resize_upsample_scales_cubic():  # type: () -> None
+    def export_resize_upsample_scales_cubic() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales'],
+            inputs=['X', '', 'scales'],
             outputs=['Y'],
             mode='cubic',
         )
@@ -457,7 +443,6 @@ class Resize(Base):
             [13, 14, 15, 16],
         ]]], dtype=np.float32)
 
-        roi = np.array([], dtype=np.float32)
         scales = np.array([1.0, 1.0, 2.0, 2.0], dtype=np.float32)
 
         # [[[[ 0.47265625  0.76953125  1.24609375  1.875       2.28125
@@ -479,14 +464,14 @@ class Resize(Base):
         output = interpolate_nd(
             data, cubic_coeffs, scale_factors=scales).astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales], outputs=[output],
+        expect(node, inputs=[data, scales], outputs=[output],
                name='test_resize_upsample_scales_cubic')
 
     @staticmethod
-    def export_resize_upsample_scales_cubic_align_corners():  # type: () -> None
+    def export_resize_upsample_scales_cubic_align_corners() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales'],
+            inputs=['X', '', 'scales'],
             outputs=['Y'],
             mode='cubic',
             coordinate_transformation_mode='align_corners'
@@ -499,7 +484,6 @@ class Resize(Base):
             [13, 14, 15, 16],
         ]]], dtype=np.float32)
 
-        roi = np.array([], dtype=np.float32)
         scales = np.array([1.0, 1.0, 2.0, 2.0], dtype=np.float32)
 
         # [[[[ 1.          1.34110787  1.80029155  2.32944606  2.67055394
@@ -521,14 +505,14 @@ class Resize(Base):
         output = interpolate_nd(
             data, cubic_coeffs, scale_factors=scales, coordinate_transformation_mode='align_corners').astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales], outputs=[output],
+        expect(node, inputs=[data, scales], outputs=[output],
                name='test_resize_upsample_scales_cubic_align_corners')
 
     @staticmethod
-    def export_resize_downsample_scales_cubic():  # type: () -> None
+    def export_resize_downsample_scales_cubic() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales'],
+            inputs=['X', '', 'scales'],
             outputs=['Y'],
             mode='cubic',
         )
@@ -540,7 +524,6 @@ class Resize(Base):
             [13, 14, 15, 16],
         ]]], dtype=np.float32)
 
-        roi = np.array([], dtype=np.float32)
         scales = np.array([1.0, 1.0, 0.8, 0.8], dtype=np.float32)
 
         # [[[[ 1.47119141  2.78125     4.08251953]
@@ -549,14 +532,14 @@ class Resize(Base):
         output = interpolate_nd(
             data, cubic_coeffs, scale_factors=scales).astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales], outputs=[output],
+        expect(node, inputs=[data, scales], outputs=[output],
                name='test_resize_downsample_scales_cubic')
 
     @staticmethod
-    def export_resize_downsample_scales_cubic_align_corners():  # type: () -> None
+    def export_resize_downsample_scales_cubic_align_corners() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales'],
+            inputs=['X', '', 'scales'],
             outputs=['Y'],
             mode='cubic',
             coordinate_transformation_mode='align_corners'
@@ -569,7 +552,6 @@ class Resize(Base):
             [13, 14, 15, 16],
         ]]], dtype=np.float32)
 
-        roi = np.array([], dtype=np.float32)
         scales = np.array([1.0, 1.0, 0.8, 0.8], dtype=np.float32)
 
         # [[[[ 1.          2.39519159  3.79038317]
@@ -578,14 +560,14 @@ class Resize(Base):
         output = interpolate_nd(
             data, cubic_coeffs, scale_factors=scales, coordinate_transformation_mode='align_corners').astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales], outputs=[output],
+        expect(node, inputs=[data, scales], outputs=[output],
                name='test_resize_downsample_scales_cubic_align_corners')
 
     @staticmethod
-    def export_resize_upsample_sizes_cubic():  # type: () -> None
+    def export_resize_upsample_sizes_cubic() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales', 'sizes'],
+            inputs=['X', '', '', 'sizes'],
             outputs=['Y'],
             mode='cubic',
         )
@@ -597,8 +579,6 @@ class Resize(Base):
             [13, 14, 15, 16],
         ]]], dtype=np.float32)
 
-        roi = np.array([], dtype=np.float32)
-        scales = np.array([], dtype=np.float32)
         sizes = np.array([1, 1, 9, 10], dtype=np.int64)
 
         # [[[[ 0.45507922  0.64057922  0.97157922  1.42257922  1.90732922
@@ -622,14 +602,14 @@ class Resize(Base):
         output = interpolate_nd(
             data, cubic_coeffs, output_size=sizes).astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales, sizes], outputs=[output],
+        expect(node, inputs=[data, sizes], outputs=[output],
                name='test_resize_upsample_sizes_cubic')
 
     @staticmethod
-    def export_resize_downsample_sizes_cubic():  # type: () -> None
+    def export_resize_downsample_sizes_cubic() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales', 'sizes'],
+            inputs=['X', '', '', 'sizes'],
             outputs=['Y'],
             mode='cubic',
         )
@@ -641,8 +621,6 @@ class Resize(Base):
             [13, 14, 15, 16],
         ]]], dtype=np.float32)
 
-        roi = np.array([], dtype=np.float32)
-        scales = np.array([], dtype=np.float32)
         sizes = np.array([1, 1, 3, 3], dtype=np.int64)
 
         # [[[[ 1.63078704  3.00462963  4.37847222]
@@ -651,15 +629,15 @@ class Resize(Base):
         output = interpolate_nd(
             data, cubic_coeffs, output_size=sizes).astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales, sizes], outputs=[output],
+        expect(node, inputs=[data, sizes], outputs=[output],
                name='test_resize_downsample_sizes_cubic')
 
     # TensorFlow v1 bicubic with half_pixel_centers=True
     @staticmethod
-    def export_resize_upsample_scales_cubic_A_n0p5_exclude_outside():  # type: () -> None
+    def export_resize_upsample_scales_cubic_A_n0p5_exclude_outside() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales'],
+            inputs=['X', '', 'scales'],
             outputs=['Y'],
             mode='cubic',
             cubic_coeff_a=-0.5,
@@ -673,7 +651,6 @@ class Resize(Base):
             [13, 14, 15, 16],
         ]]], dtype=np.float32)
 
-        roi = np.array([], dtype=np.float32)
         scales = np.array([1.0, 1.0, 2.0, 2.0], dtype=np.float32)
 
         # [[[[ 0.55882353  0.81494204  1.35698249  1.89705882  2.39705882
@@ -695,14 +672,14 @@ class Resize(Base):
         output = interpolate_nd(data, lambda x: cubic_coeffs(x, A=-0.5), scale_factors=scales,
                                 exclude_outside=True).astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales], outputs=[output],
+        expect(node, inputs=[data, scales], outputs=[output],
                name='test_resize_upsample_scales_cubic_A_n0p5_exclude_outside')
 
     @staticmethod
-    def export_resize_downsample_scales_cubic_A_n0p5_exclude_outside():  # type: () -> None
+    def export_resize_downsample_scales_cubic_A_n0p5_exclude_outside() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales'],
+            inputs=['X', '', 'scales'],
             outputs=['Y'],
             mode='cubic',
             cubic_coeff_a=-0.5,
@@ -716,7 +693,6 @@ class Resize(Base):
             [13, 14, 15, 16],
         ]]], dtype=np.float32)
 
-        roi = np.array([], dtype=np.float32)
         scales = np.array([1.0, 1.0, 0.8, 0.8], dtype=np.float32)
 
         # [[[[ 1.36812675  2.6695014   4.0133367 ]
@@ -725,15 +701,15 @@ class Resize(Base):
         output = interpolate_nd(data, lambda x: cubic_coeffs(x, A=-0.5), scale_factors=scales,
                                 exclude_outside=True).astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales], outputs=[output],
+        expect(node, inputs=[data, scales], outputs=[output],
                name='test_resize_downsample_scales_cubic_A_n0p5_exclude_outside')
 
     # TensorFlow v1 bicubic with half_pixel_centers=False
     @staticmethod
-    def export_resize_upsample_scales_cubic_asymmetric():  # type: () -> None
+    def export_resize_upsample_scales_cubic_asymmetric() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales'],
+            inputs=['X', '', 'scales'],
             outputs=['Y'],
             mode='cubic',
             coordinate_transformation_mode='asymmetric'
@@ -747,7 +723,6 @@ class Resize(Base):
         ]]], dtype=np.float32)
 
         scales = np.array([1.0, 1.0, 2.0, 2.0], dtype=np.float32)
-        roi = np.array([], dtype=np.float32)
 
         # [[[[ 1.       1.40625  2.       2.5      3.       3.59375  4.
         #      4.09375]
@@ -768,14 +743,14 @@ class Resize(Base):
         output = interpolate_nd(data, lambda x: cubic_coeffs(x, A=-0.75), scale_factors=scales,
                                 coordinate_transformation_mode='asymmetric').astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales], outputs=[output],
+        expect(node, inputs=[data, scales], outputs=[output],
                name='test_resize_upsample_scales_cubic_asymmetric')
 
     @staticmethod
-    def export_resize_tf_crop_and_resize():  # type: () -> None
+    def export_resize_tf_crop_and_resize() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales', 'sizes'],
+            inputs=['X', 'roi', '', 'sizes'],
             outputs=['Y'],
             mode='linear',
             coordinate_transformation_mode='tf_crop_and_resize'
@@ -790,7 +765,6 @@ class Resize(Base):
 
         # Note: for some rois, the result may be different with that of TF for inaccurate floating point
         roi = np.array([0, 0, 0.4, 0.6, 1, 1, 0.6, 0.8], dtype=np.float32)
-        scales = np.array([], dtype=np.float32)
         sizes = np.array([1, 1, 3, 3], dtype=np.int64)
 
         # [[[[ 7.6000004  7.9        8.2      ]
@@ -799,14 +773,14 @@ class Resize(Base):
         output = interpolate_nd(data, linear_coeffs, output_size=sizes, roi=roi,
                                 coordinate_transformation_mode='tf_crop_and_resize').astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales, sizes], outputs=[output],
+        expect(node, inputs=[data, roi, sizes], outputs=[output],
                name='test_resize_tf_crop_and_resize')
 
     @staticmethod
-    def export_resize_tf_crop_and_resize_extrapolation_value():  # type: () -> None
+    def export_resize_tf_crop_and_resize_extrapolation_value() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales', 'sizes'],
+            inputs=['X', 'roi', '', 'sizes'],
             outputs=['Y'],
             mode='linear',
             coordinate_transformation_mode='tf_crop_and_resize',
@@ -822,7 +796,6 @@ class Resize(Base):
 
         # Note: for some rois, the result may be different with that of TF for inaccurate floating point
         roi = np.array([0, 0, 0.4, 0.6, 1, 1, 1.2, 1.7], dtype=np.float32)
-        scales = np.array([], dtype=np.float32)
         sizes = np.array([1, 1, 3, 3], dtype=np.int64)
 
         # [[[[ 7.6000004 10.        10.       ]
@@ -831,44 +804,14 @@ class Resize(Base):
         output = interpolate_nd(data, linear_coeffs, output_size=sizes, roi=roi,
                                 coordinate_transformation_mode='tf_crop_and_resize', extrapolation_value=10.0).astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales, sizes], outputs=[output],
+        expect(node, inputs=[data, roi, sizes], outputs=[output],
                name='test_resize_tf_crop_and_resize')
 
     @staticmethod
-    def export_resize_downsample_sizes_nearest_tf_half_pixel_for_nn():  # type: () -> None
+    def export_resize_downsample_sizes_linear_pytorch_half_pixel() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales', 'sizes'],
-            outputs=['Y'],
-            mode='nearest',
-            coordinate_transformation_mode='tf_half_pixel_for_nn'
-        )
-
-        data = np.array([[[
-            [1, 2, 3, 4],
-            [5, 6, 7, 8],
-            [9, 10, 11, 12],
-            [13, 14, 15, 16],
-        ]]], dtype=np.float32)
-
-        roi = np.array([], dtype=np.float32)
-        scales = np.array([], dtype=np.float32)
-        sizes = np.array([1, 1, 3, 2], dtype=np.int64)
-
-        # [[[[ 6.  8.]
-        #    [10. 12.]
-        #    [14. 16.]]]]
-        output = interpolate_nd(
-            data, nearest_coeffs, output_size=sizes, coordinate_transformation_mode='tf_half_pixel_for_nn').astype(np.float32)
-
-        expect(node, inputs=[data, roi, scales, sizes], outputs=[output],
-               name='test_resize_downsample_sizes_nearest_tf_half_pixel_for_nn')
-
-    @staticmethod
-    def export_resize_downsample_sizes_linear_pytorch_half_pixel():  # type: () -> None
-        node = onnx.helper.make_node(
-            'Resize',
-            inputs=['X', 'roi', 'scales', 'sizes'],
+            inputs=['X', '', '', 'sizes'],
             outputs=['Y'],
             mode='linear',
             coordinate_transformation_mode='pytorch_half_pixel'
@@ -881,8 +824,6 @@ class Resize(Base):
             [13, 14, 15, 16],
         ]]], dtype=np.float32)
 
-        roi = np.array([], dtype=np.float32)
-        scales = np.array([], dtype=np.float32)
         sizes = np.array([1, 1, 3, 1], dtype=np.int64)
 
         # [[[[ 1.6666666]
@@ -891,14 +832,14 @@ class Resize(Base):
         output = interpolate_nd(
             data, linear_coeffs, output_size=sizes, coordinate_transformation_mode='pytorch_half_pixel').astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales, sizes], outputs=[output],
+        expect(node, inputs=[data, sizes], outputs=[output],
                name='test_resize_downsample_sizes_linear_pytorch_half_pixel')
 
     @staticmethod
-    def export_resize_upsample_sizes_nearest_floor_align_corners():  # type: () -> None
+    def export_resize_upsample_sizes_nearest_floor_align_corners() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales', 'sizes'],
+            inputs=['X', '', '', 'sizes'],
             outputs=['Y'],
             mode='nearest',
             coordinate_transformation_mode='align_corners',
@@ -912,8 +853,6 @@ class Resize(Base):
             [13, 14, 15, 16],
         ]]], dtype=np.float32)
 
-        roi = np.array([], dtype=np.float32)
-        scales = np.array([], dtype=np.float32)
         sizes = np.array([1, 1, 8, 8], dtype=np.int64)
 
         # [[[[ 1.  1.  1.  2.  2.  3.  3.  4.]
@@ -927,14 +866,14 @@ class Resize(Base):
         output = interpolate_nd(
             data, lambda x: nearest_coeffs(x, mode='floor'), output_size=sizes, coordinate_transformation_mode='align_corners').astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales, sizes], outputs=[output],
+        expect(node, inputs=[data, sizes], outputs=[output],
                name='test_resize_upsample_sizes_nearest_floor_align_corners')
 
     @staticmethod
-    def export_resize_upsample_sizes_nearest_round_prefer_ceil_asymmetric():  # type: () -> None
+    def export_resize_upsample_sizes_nearest_round_prefer_ceil_asymmetric() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales', 'sizes'],
+            inputs=['X', '', '', 'sizes'],
             outputs=['Y'],
             mode='nearest',
             coordinate_transformation_mode='asymmetric',
@@ -948,8 +887,6 @@ class Resize(Base):
             [13, 14, 15, 16],
         ]]], dtype=np.float32)
 
-        roi = np.array([], dtype=np.float32)
-        scales = np.array([], dtype=np.float32)
         sizes = np.array([1, 1, 8, 8], dtype=np.int64)
 
         # [[[[ 1.  2.  2.  3.  3.  4.  4.  4.]
@@ -964,14 +901,14 @@ class Resize(Base):
             data, lambda x: nearest_coeffs(x, mode='round_prefer_ceil'),
             output_size=sizes, coordinate_transformation_mode='asymmetric').astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales, sizes], outputs=[output],
+        expect(node, inputs=[data, sizes], outputs=[output],
                name='test_resize_upsample_sizes_nearest_round_prefer_ceil_asymmetric')
 
     @staticmethod
-    def export_resize_upsample_sizes_nearest_ceil_half_pixel():  # type: () -> None
+    def export_resize_upsample_sizes_nearest_ceil_half_pixel() -> None:
         node = onnx.helper.make_node(
             'Resize',
-            inputs=['X', 'roi', 'scales', 'sizes'],
+            inputs=['X', '', '', 'sizes'],
             outputs=['Y'],
             mode='nearest',
             coordinate_transformation_mode='half_pixel',
@@ -985,8 +922,6 @@ class Resize(Base):
             [13, 14, 15, 16],
         ]]], dtype=np.float32)
 
-        roi = np.array([], dtype=np.float32)
-        scales = np.array([], dtype=np.float32)
         sizes = np.array([1, 1, 8, 8], dtype=np.int64)
 
         # [[[[ 1.  2.  2.  3.  3.  4.  4.  4.]
@@ -1000,5 +935,5 @@ class Resize(Base):
         output = interpolate_nd(
             data, lambda x: nearest_coeffs(x, mode='ceil'), output_size=sizes).astype(np.float32)
 
-        expect(node, inputs=[data, roi, scales, sizes], outputs=[output],
+        expect(node, inputs=[data, sizes], outputs=[output],
                name='test_resize_upsample_sizes_nearest_ceil_half_pixel')
