@@ -1,7 +1,4 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
+# SPDX-License-Identifier: Apache-2.0
 
 import numpy as np  # type: ignore
 
@@ -34,7 +31,8 @@ def softmaxcrossentropy(x, target, weight=None, reduction='mean', ignore_index=N
         # setting mode='clip' to deal with ignore_index > C or < 0 cases.
         # when the target value is > C or < 0, it doesn't matter which value we are
         # taking in gather_weight, since it will be set to 0 in the following if-block
-        gather_weight = np.take(weight, target, mode='clip')
+        # use np.int32 to make it compatible with x86 machines
+        gather_weight = np.take(weight, np.array(target, dtype=np.int32), mode='clip')
         # set `ignore_index`'s loss weight to 0.
         # The loss tensor will be multiplied by this weight tensor,
         # so `ingore_index`'s loss value will be eliminated.
@@ -89,7 +87,7 @@ def softmaxcrossentropy(x, target, weight=None, reduction='mean', ignore_index=N
 class SoftmaxCrossEntropyLoss(Base):
 
     @staticmethod
-    def export_softmaxcrossentropy_none():  # type: () -> None
+    def export_softmaxcrossentropy_none() -> None:
         # Define operator attributes.
         reduction = 'none'
 
@@ -102,16 +100,16 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, ))
+        labels = np.random.randint(0, high=5, size=(3, )).astype(np.int64)
 
         # Compute SoftmaxCrossEntropyLoss
         sce = softmaxcrossentropy(x, labels, reduction='none')
 
         # Check results
-        expect(node, inputs=[x, labels], outputs=[sce], name='test_softmax_cross_entropy_none')
+        expect(node, inputs=[x, labels], outputs=[sce], name='test_sce_none')
 
     @staticmethod
-    def export_softmaxcrossentropy_none_log_prob():  # type: () -> None
+    def export_softmaxcrossentropy_none_log_prob() -> None:
         # Define operator attributes.
         reduction = 'none'
 
@@ -124,16 +122,16 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, ))
+        labels = np.random.randint(0, high=5, size=(3, )).astype(np.int64)
 
         # Compute SoftmaxCrossEntropyLoss
         loss, log_prob = softmaxcrossentropy(x, labels, reduction='none', get_log_prob=True)
 
         # Check results
-        expect(node, inputs=[x, labels], outputs=[loss, log_prob], name='test_softmax_cross_entropy_none_log_prob')
+        expect(node, inputs=[x, labels], outputs=[loss, log_prob], name='test_sce_none_log_prob')
 
     @staticmethod
-    def export_softmaxcrossentropy_none_weights():  # type: () -> None
+    def export_softmaxcrossentropy_none_weights() -> None:
         # Define operator attributes.
         reduction = 'none'
 
@@ -146,17 +144,17 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, ))
+        labels = np.random.randint(0, high=5, size=(3, )).astype(np.int64)
         weights = np.array([0.9, 0.7, 0.8, 0.9, 0.9], dtype=np.float32)
 
         # Compute SoftmaxCrossEntropyLoss
         sce = softmaxcrossentropy(x, labels, weight=weights, reduction='none')
 
         # Check results
-        expect(node, inputs=[x, labels, weights], outputs=[sce], name='test_softmax_cross_entropy_none_weights')
+        expect(node, inputs=[x, labels, weights], outputs=[sce], name='test_sce_none_weights')
 
     @staticmethod
-    def export_softmaxcrossentropy_none_weights_log_prob():  # type: () -> None
+    def export_softmaxcrossentropy_none_weights_log_prob() -> None:
         # Define operator attributes.
         reduction = 'none'
 
@@ -169,17 +167,17 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, ))
+        labels = np.random.randint(0, high=5, size=(3, )).astype(np.int64)
         weights = np.array([0.9, 0.7, 0.8, 0.9, 0.9], dtype=np.float32)
 
         # Compute SoftmaxCrossEntropyLoss
         loss, log_prob = softmaxcrossentropy(x, labels, weight=weights, reduction='none', get_log_prob=True)
 
         # Check results
-        expect(node, inputs=[x, labels, weights], outputs=[loss, log_prob], name='test_softmax_cross_entropy_none_weights_log_prob')
+        expect(node, inputs=[x, labels, weights], outputs=[loss, log_prob], name='test_sce_none_weights_log_prob')
 
     @staticmethod
-    def export_softmaxcrossentropy_sum():  # type: () -> None
+    def export_softmaxcrossentropy_sum() -> None:
         # Define operator attributes.
         reduction = 'sum'
 
@@ -192,16 +190,16 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, ))
+        labels = np.random.randint(0, high=5, size=(3, )).astype(np.int64)
 
         # Compute SoftmaxCrossEntropyLoss
         sce = softmaxcrossentropy(x, labels, reduction='sum')
 
         # Check results
-        expect(node, inputs=[x, labels], outputs=[sce], name='test_softmax_cross_entropy_sum')
+        expect(node, inputs=[x, labels], outputs=[sce], name='test_sce_sum')
 
     @staticmethod
-    def export_softmaxcrossentropy_sum_log_prob():  # type: () -> None
+    def export_softmaxcrossentropy_sum_log_prob() -> None:
         # Define operator attributes.
         reduction = 'sum'
 
@@ -214,16 +212,16 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, ))
+        labels = np.random.randint(0, high=5, size=(3, )).astype(np.int64)
 
         # Compute SoftmaxCrossEntropyLoss
         loss, log_prob = softmaxcrossentropy(x, labels, reduction='sum', get_log_prob=True)
 
         # Check results
-        expect(node, inputs=[x, labels], outputs=[loss, log_prob], name='test_softmax_cross_entropy_sum_log_prob')
+        expect(node, inputs=[x, labels], outputs=[loss, log_prob], name='test_sce_sum_log_prob')
 
     @staticmethod
-    def export_softmaxcrossentropy_mean():  # type: () -> None
+    def export_softmaxcrossentropy_mean() -> None:
         # Define operator attributes.
         reduction = 'mean'
 
@@ -236,16 +234,16 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, ))
+        labels = np.random.randint(0, high=5, size=(3, )).astype(np.int64)
 
         # Compute SoftmaxCrossEntropyLoss
         sce = softmaxcrossentropy(x, labels)
 
         # Check results
-        expect(node, inputs=[x, labels], outputs=[sce], name='test_softmax_cross_entropy_mean')
+        expect(node, inputs=[x, labels], outputs=[sce], name='test_sce_mean')
 
     @staticmethod
-    def export_softmaxcrossentropy_mean_log_prob():  # type: () -> None
+    def export_softmaxcrossentropy_mean_log_prob() -> None:
         # Define operator attributes.
         reduction = 'mean'
 
@@ -258,16 +256,16 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, ))
+        labels = np.random.randint(0, high=5, size=(3, )).astype(np.int64)
 
         # Compute SoftmaxCrossEntropyLoss
         loss, log_prob = softmaxcrossentropy(x, labels, get_log_prob=True)
 
         # Check results
-        expect(node, inputs=[x, labels], outputs=[loss, log_prob], name='test_softmax_cross_entropy_mean_log_prob')
+        expect(node, inputs=[x, labels], outputs=[loss, log_prob], name='test_sce_mean_log_prob')
 
     @staticmethod
-    def export_softmaxcrossentropy_mean_3d():  # type: () -> None
+    def export_softmaxcrossentropy_mean_3d() -> None:
         # Define operator attributes.
         reduction = 'mean'
 
@@ -280,16 +278,16 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5, 2).astype(np.float32)
-        y = np.random.randint(0, high=5, size=(3, 2))
+        y = np.random.randint(0, high=5, size=(3, 2)).astype(np.int64)
 
         # Compute SoftmaxCrossEntropyLoss
         sce = softmaxcrossentropy(x, y)
 
         # Check results
-        expect(node, inputs=[x, y], outputs=[sce], name='test_softmax_cross_entropy_mean_3d')
+        expect(node, inputs=[x, y], outputs=[sce], name='test_sce_mean_3d')
 
     @staticmethod
-    def export_softmaxcrossentropy_mean_3d_log_prob():  # type: () -> None
+    def export_softmaxcrossentropy_mean_3d_log_prob() -> None:
         # Define operator attributes.
         reduction = 'mean'
 
@@ -302,16 +300,16 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5, 2).astype(np.float32)
-        y = np.random.randint(0, high=5, size=(3, 2))
+        y = np.random.randint(0, high=5, size=(3, 2)).astype(np.int64)
 
         # Compute SoftmaxCrossEntropyLoss
         loss, log_prob = softmaxcrossentropy(x, y, get_log_prob=True)
 
         # Check results
-        expect(node, inputs=[x, y], outputs=[loss, log_prob], name='test_softmax_cross_entropy_mean_3d_log_prob')
+        expect(node, inputs=[x, y], outputs=[loss, log_prob], name='test_sce_mean_3d_log_prob')
 
     @staticmethod
-    def export_softmaxcrossentropy_mean_weights():  # type: () -> None
+    def export_softmaxcrossentropy_mean_weights() -> None:
         # Define operator attributes.
         reduction = 'mean'
 
@@ -324,17 +322,17 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, ))
+        labels = np.random.randint(0, high=5, size=(3, )).astype(np.int64)
         weights = np.array([0.9, 0.7, 0.8, 0.9, 0.9], dtype=np.float32)
 
         # Compute SoftmaxCrossEntropyLoss
         sce = softmaxcrossentropy(x, labels, weight=weights)
 
         # Check results
-        expect(node, inputs=[x, labels, weights], outputs=[sce], name='test_softmax_cross_entropy_mean_weight')
+        expect(node, inputs=[x, labels, weights], outputs=[sce], name='test_sce_mean_weight')
 
     @staticmethod
-    def export_softmaxcrossentropy_mean_weights_log_prob():  # type: () -> None
+    def export_softmaxcrossentropy_mean_weights_log_prob() -> None:
         # Define operator attributes.
         reduction = 'mean'
 
@@ -347,17 +345,17 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, ))
+        labels = np.random.randint(0, high=5, size=(3, )).astype(np.int64)
         weights = np.array([0.9, 0.7, 0.8, 0.9, 0.9], dtype=np.float32)
 
         # Compute SoftmaxCrossEntropyLoss
         loss, log_prob = softmaxcrossentropy(x, labels, weight=weights, get_log_prob=True)
 
         # Check results
-        expect(node, inputs=[x, labels, weights], outputs=[loss, log_prob], name='test_softmax_cross_entropy_mean_weight_log_prob')
+        expect(node, inputs=[x, labels, weights], outputs=[loss, log_prob], name='test_sce_mean_weight_log_prob')
 
     @staticmethod
-    def export_softmaxcrossentropy_mean_weights_ignore_index():  # type: () -> None
+    def export_softmaxcrossentropy_mean_weights_ii() -> None:
         # Define operator attributes.
         reduction = 'mean'
         ignore_index = np.int64(0)
@@ -372,7 +370,7 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, ))
+        labels = np.random.randint(0, high=5, size=(3, )).astype(np.int64)
         labels[0] = np.int64(0)
         weights = np.array([0.9, 0.7, 0.8, 0.9, 0.9], dtype=np.float32)
 
@@ -380,10 +378,10 @@ class SoftmaxCrossEntropyLoss(Base):
         sce = softmaxcrossentropy(x, labels, weight=weights, ignore_index=ignore_index)
 
         # Check results
-        expect(node, inputs=[x, labels, weights], outputs=[sce], name='test_softmax_cross_entropy_mean_weight_ignore_index')
+        expect(node, inputs=[x, labels, weights], outputs=[sce], name='test_sce_mean_weight_ii')
 
     @staticmethod
-    def export_softmaxcrossentropy_mean_weights_ignore_index_log_prob():  # type: () -> None
+    def export_softmaxcrossentropy_mean_weights_ii_log_prob() -> None:
         # Define operator attributes.
         reduction = 'mean'
         ignore_index = np.int64(0)
@@ -398,7 +396,7 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, ))
+        labels = np.random.randint(0, high=5, size=(3, )).astype(np.int64)
         labels[0] = np.int64(0)
         weights = np.array([0.9, 0.7, 0.8, 0.9, 0.9], dtype=np.float32)
 
@@ -406,10 +404,10 @@ class SoftmaxCrossEntropyLoss(Base):
         loss, log_prob = softmaxcrossentropy(x, labels, weight=weights, ignore_index=ignore_index, get_log_prob=True)
 
         # Check results
-        expect(node, inputs=[x, labels, weights], outputs=[loss, log_prob], name='test_softmax_cross_entropy_mean_weight_ignore_index_log_prob')
+        expect(node, inputs=[x, labels, weights], outputs=[loss, log_prob], name='test_sce_mean_weight_ii_log_prob')
 
     @staticmethod
-    def export_softmaxcrossentropy_mean_no_weights_ignore_index():  # type: () -> None
+    def export_softmaxcrossentropy_mean_no_weights_ii() -> None:
         # Define operator attributes.
         reduction = 'mean'
         ignore_index = np.int64(2)
@@ -424,17 +422,17 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, ))
+        labels = np.random.randint(0, high=5, size=(3, )).astype(np.int64)
         labels[0] = np.int64(2)
 
         # Compute SoftmaxCrossEntropyLoss
         sce = softmaxcrossentropy(x, labels, ignore_index=ignore_index)
 
         # Check results
-        expect(node, inputs=[x, labels], outputs=[sce], name='test_softmax_cross_entropy_mean_no_weight_ignore_index')
+        expect(node, inputs=[x, labels], outputs=[sce], name='test_sce_mean_no_weight_ii')
 
     @staticmethod
-    def export_softmaxcrossentropy_mean_no_weights_ignore_index_log_prob():  # type: () -> None
+    def export_softmaxcrossentropy_mean_no_weights_ii_log_prob() -> None:
         # Define operator attributes.
         reduction = 'mean'
         ignore_index = np.int64(2)
@@ -449,17 +447,17 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, ))
+        labels = np.random.randint(0, high=5, size=(3, )).astype(np.int64)
         labels[0] = np.int64(2)
 
         # Compute SoftmaxCrossEntropyLoss
         loss, log_prob = softmaxcrossentropy(x, labels, ignore_index=ignore_index, get_log_prob=True)
 
         # Check results
-        expect(node, inputs=[x, labels], outputs=[loss, log_prob], name='test_softmax_cross_entropy_mean_no_weight_ignore_index_log_prob')
+        expect(node, inputs=[x, labels], outputs=[loss, log_prob], name='test_sce_mean_no_weight_ii_log_prob')
 
     @staticmethod
-    def export_softmaxcrossentropy_mean_weights_ignore_index_3d():  # type: () -> None
+    def export_softmaxcrossentropy_mean_weights_ii_3d() -> None:
         # Define operator attributes.
         reduction = 'mean'
         ignore_index = np.int64(1)
@@ -474,7 +472,7 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5, 2).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, 2))
+        labels = np.random.randint(0, high=5, size=(3, 2)).astype(np.int64)
         labels[0][0] = np.int64(1)
         weights = np.array([0.2, 0.3, 0.6, 0.1, 0.5], dtype=np.float32)
 
@@ -482,10 +480,10 @@ class SoftmaxCrossEntropyLoss(Base):
         sce = softmaxcrossentropy(x, labels, weight=weights, ignore_index=ignore_index)
 
         # Check results
-        expect(node, inputs=[x, labels, weights], outputs=[sce], name='test_softmax_cross_entropy_mean_weight_ignore_index_3d')
+        expect(node, inputs=[x, labels, weights], outputs=[sce], name='test_sce_mean_weight_ii_3d')
 
     @staticmethod
-    def export_softmaxcrossentropy_mean_weights_ignore_index_3d_log_prob():  # type: () -> None
+    def export_softmaxcrossentropy_mean_weights_ii_3d_log_prob() -> None:
         # Define operator attributes.
         reduction = 'mean'
         ignore_index = np.int64(1)
@@ -500,7 +498,7 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5, 2).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, 2))
+        labels = np.random.randint(0, high=5, size=(3, 2)).astype(np.int64)
         labels[0][0] = np.int64(1)
         weights = np.array([0.2, 0.3, 0.6, 0.1, 0.5], dtype=np.float32)
 
@@ -508,10 +506,10 @@ class SoftmaxCrossEntropyLoss(Base):
         loss, log_prob = softmaxcrossentropy(x, labels, weight=weights, ignore_index=ignore_index, get_log_prob=True)
 
         # Check results
-        expect(node, inputs=[x, labels, weights], outputs=[loss, log_prob], name='test_softmax_cross_entropy_mean_weight_ignore_index_3d_log_prob')
+        expect(node, inputs=[x, labels, weights], outputs=[loss, log_prob], name='test_sce_mean_weight_ii_3d_log_prob')
 
     @staticmethod
-    def export_softmaxcrossentropy_mean_no_weights_ignore_index_3d():  # type: () -> None
+    def export_softmaxcrossentropy_mean_no_weights_ii_3d() -> None:
         # Define operator attributes.
         reduction = 'mean'
         ignore_index = np.int64(2)
@@ -526,17 +524,17 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5, 2).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, 2))
+        labels = np.random.randint(0, high=5, size=(3, 2)).astype(np.int64)
         labels[0][0] = np.int64(2)
 
         # Compute SoftmaxCrossEntropyLoss
         sce = softmaxcrossentropy(x, labels, ignore_index=ignore_index)
 
         # Check results
-        expect(node, inputs=[x, labels], outputs=[sce], name='test_softmax_cross_entropy_mean_no_weight_ignore_index_3d')
+        expect(node, inputs=[x, labels], outputs=[sce], name='test_sce_mean_no_weight_ii_3d')
 
     @staticmethod
-    def export_softmaxcrossentropy_mean_no_weights_ignore_index_3d_log_prob():  # type: () -> None
+    def export_softmaxcrossentropy_mean_no_weights_ii_3d_log_prob() -> None:
         # Define operator attributes.
         reduction = 'mean'
         ignore_index = np.int64(2)
@@ -551,17 +549,17 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5, 2).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, 2))
+        labels = np.random.randint(0, high=5, size=(3, 2)).astype(np.int64)
         labels[0][0] = np.int64(2)
 
         # Compute SoftmaxCrossEntropyLoss
         loss, log_prob = softmaxcrossentropy(x, labels, ignore_index=ignore_index, get_log_prob=True)
 
         # Check results
-        expect(node, inputs=[x, labels], outputs=[loss, log_prob], name='test_softmax_cross_entropy_mean_no_weight_ignore_index_3d_log_prob')
+        expect(node, inputs=[x, labels], outputs=[loss, log_prob], name='test_sce_mean_no_weight_ii_3d_log_prob')
 
     @staticmethod
-    def export_softmaxcrossentropy_mean_weights_ignore_index_4d():  # type: () -> None
+    def export_softmaxcrossentropy_mean_weights_ii_4d() -> None:
         # Define operator attributes.
         reduction = 'mean'
         ignore_index = np.int64(2)
@@ -576,7 +574,7 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5, 2, 7).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, 2, 7))
+        labels = np.random.randint(0, high=5, size=(3, 2, 7)).astype(np.int64)
         labels[0][0][0] = np.int64(2)
         weights = np.array([0.2, 0.3, 0.6, 0.1, 0.5], dtype=np.float32)
 
@@ -584,10 +582,10 @@ class SoftmaxCrossEntropyLoss(Base):
         sce = softmaxcrossentropy(x, labels, reduction=reduction, weight=weights, ignore_index=ignore_index)
 
         # Check results
-        expect(node, inputs=[x, labels, weights], outputs=[sce], name='test_softmax_cross_entropy_mean_weight_ignore_index_4d')
+        expect(node, inputs=[x, labels, weights], outputs=[sce], name='test_sce_mean_weight_ii_4d')
 
     @staticmethod
-    def export_softmaxcrossentropy_mean_weights_ignore_index_4d_log_prob():  # type: () -> None
+    def export_softmaxcrossentropy_mean_weights_ii_4d_log_prob() -> None:
         # Define operator attributes.
         reduction = 'mean'
         ignore_index = np.int64(2)
@@ -602,7 +600,7 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5, 2, 7).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, 2, 7))
+        labels = np.random.randint(0, high=5, size=(3, 2, 7)).astype(np.int64)
         labels[0][0][0] = np.int64(2)
         weights = np.array([0.2, 0.3, 0.6, 0.1, 0.5], dtype=np.float32)
 
@@ -610,10 +608,10 @@ class SoftmaxCrossEntropyLoss(Base):
         loss, log_prob = softmaxcrossentropy(x, labels, reduction=reduction, weight=weights, ignore_index=ignore_index, get_log_prob=True)
 
         # Check results
-        expect(node, inputs=[x, labels, weights], outputs=[loss, log_prob], name='test_softmax_cross_entropy_mean_weight_ignore_index_4d_log_prob')
+        expect(node, inputs=[x, labels, weights], outputs=[loss, log_prob], name='test_sce_mean_weight_ii_4d_log_prob')
 
     @staticmethod
-    def export_softmaxcrossentropy_mean_no_weights_ignore_index_4d():  # type: () -> None
+    def export_softmaxcrossentropy_mean_no_weights_ii_4d() -> None:
         # Define operator attributes.
         reduction = 'mean'
         ignore_index = np.int64(2)
@@ -628,17 +626,17 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5, 2, 7).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, 2, 7))
+        labels = np.random.randint(0, high=5, size=(3, 2, 7)).astype(np.int64)
         labels[0][0][0] = np.int64(2)
 
         # Compute SoftmaxCrossEntropyLoss
         sce = softmaxcrossentropy(x, labels, reduction=reduction, ignore_index=ignore_index)
 
         # Check results
-        expect(node, inputs=[x, labels], outputs=[sce], name='test_softmax_cross_entropy_mean_no_weight_ignore_index_4d')
+        expect(node, inputs=[x, labels], outputs=[sce], name='test_sce_mean_no_weight_ii_4d')
 
     @staticmethod
-    def export_softmaxcrossentropy_mean_no_weights_ignore_index_4d_log_prob():  # type: () -> None
+    def export_softmaxcrossentropy_mean_no_weights_ii_4d_log_prob() -> None:
         # Define operator attributes.
         reduction = 'mean'
         ignore_index = np.int64(2)
@@ -653,17 +651,17 @@ class SoftmaxCrossEntropyLoss(Base):
         # Define operator inputs.
         np.random.seed(0)
         x = np.random.rand(3, 5, 2, 7).astype(np.float32)
-        labels = np.random.randint(0, high=5, size=(3, 2, 7))
+        labels = np.random.randint(0, high=5, size=(3, 2, 7)).astype(np.int64)
         labels[0][0][0] = np.int64(2)
 
         # Compute SoftmaxCrossEntropyLoss
         loss, log_prob = softmaxcrossentropy(x, labels, reduction=reduction, ignore_index=ignore_index, get_log_prob=True)
 
         # Check results
-        expect(node, inputs=[x, labels], outputs=[loss, log_prob], name='test_softmax_cross_entropy_mean_no_weight_ignore_index_4d_log_prob')
+        expect(node, inputs=[x, labels], outputs=[loss, log_prob], name='test_sce_mean_no_weight_ii_4d_log_prob')
 
     @staticmethod
-    def export_input_shape_is_NCd1d2d3d4d5_mean_weight():  # type: () -> None
+    def export_input_shape_is_NCd1d2d3d4d5_mean_weight() -> None:
         reduction = 'mean'
 
         node = onnx.helper.make_node('SoftmaxCrossEntropyLoss',
@@ -674,7 +672,7 @@ class SoftmaxCrossEntropyLoss(Base):
         N, C, dim1, dim2, dim3, dim4, dim5 = 3, 5, 6, 6, 5, 3, 4
         np.random.seed(0)
         x = np.random.rand(N, C, dim1, dim2, dim3, dim4, dim5).astype(np.float32)
-        labels = np.random.randint(0, high=C, size=(N, dim1, dim2, dim3, dim4, dim5))
+        labels = np.random.randint(0, high=C, size=(N, dim1, dim2, dim3, dim4, dim5)).astype(np.int64)
         weight = np.random.rand(C).astype(np.float32)
 
         sce = softmaxcrossentropy(x,
@@ -682,10 +680,10 @@ class SoftmaxCrossEntropyLoss(Base):
                                 weight=weight,
                                 reduction=reduction)
 
-        expect(node, inputs=[x, labels, weight], outputs=[sce], name='test_softmax_cross_entropy_input_shape_is_NCd1d2d3d4d5_mean_weight')
+        expect(node, inputs=[x, labels, weight], outputs=[sce], name='test_sce_NCd1d2d3d4d5_mean_weight')
 
     @staticmethod
-    def export_input_shape_is_NCd1d2d3d4d5_mean_weight_log_prob():  # type: () -> None
+    def export_input_shape_is_NCd1d2d3d4d5_mean_weight_log_prob() -> None:
         reduction = 'mean'
 
         node = onnx.helper.make_node('SoftmaxCrossEntropyLoss',
@@ -696,7 +694,7 @@ class SoftmaxCrossEntropyLoss(Base):
         N, C, dim1, dim2, dim3, dim4, dim5 = 3, 5, 6, 6, 5, 3, 4
         np.random.seed(0)
         x = np.random.rand(N, C, dim1, dim2, dim3, dim4, dim5).astype(np.float32)
-        labels = np.random.randint(0, high=C, size=(N, dim1, dim2, dim3, dim4, dim5))
+        labels = np.random.randint(0, high=C, size=(N, dim1, dim2, dim3, dim4, dim5)).astype(np.int64)
         weight = np.random.rand(C).astype(np.float32)
 
         loss, log_prob = softmaxcrossentropy(x,
@@ -705,10 +703,10 @@ class SoftmaxCrossEntropyLoss(Base):
                                 reduction=reduction,
                                 get_log_prob=True)
 
-        expect(node, inputs=[x, labels, weight], outputs=[loss, log_prob], name='test_softmax_cross_entropy_input_shape_is_NCd1d2d3d4d5_mean_weight_log_prob')
+        expect(node, inputs=[x, labels, weight], outputs=[loss, log_prob], name='test_sce_NCd1d2d3d4d5_mean_weight_log_prob')
 
     @staticmethod
-    def export_input_shape_is_NCd1d2d3d4d5_none_no_weight():  # type: () -> None
+    def export_input_shape_is_NCd1d2d3d4d5_none_no_weight() -> None:
         reduction = 'none'
 
         node = onnx.helper.make_node('SoftmaxCrossEntropyLoss',
@@ -719,16 +717,16 @@ class SoftmaxCrossEntropyLoss(Base):
         N, C, dim1, dim2, dim3, dim4, dim5 = 3, 5, 6, 6, 5, 3, 4
         np.random.seed(0)
         x = np.random.rand(N, C, dim1, dim2, dim3, dim4, dim5).astype(np.float32)
-        labels = np.random.randint(0, high=C, size=(N, dim1, dim2, dim3, dim4, dim5))
+        labels = np.random.randint(0, high=C, size=(N, dim1, dim2, dim3, dim4, dim5)).astype(np.int64)
 
         sce = softmaxcrossentropy(x,
                                 labels,
                                 reduction=reduction)
 
-        expect(node, inputs=[x, labels], outputs=[sce], name='test_softmax_cross_entropy_input_shape_is_NCd1d2d3d4d5_none_no_weight')
+        expect(node, inputs=[x, labels], outputs=[sce], name='test_sce_NCd1d2d3d4d5_none_no_weight')
 
     @staticmethod
-    def export_input_shape_is_NCd1d2d3d4d5_none_no_weight_log_prob():  # type: () -> None
+    def export_input_shape_is_NCd1d2d3d4d5_none_no_weight_log_prob() -> None:
         reduction = 'none'
 
         node = onnx.helper.make_node('SoftmaxCrossEntropyLoss',
@@ -739,17 +737,17 @@ class SoftmaxCrossEntropyLoss(Base):
         N, C, dim1, dim2, dim3, dim4, dim5 = 3, 5, 6, 6, 5, 3, 4
         np.random.seed(0)
         x = np.random.rand(N, C, dim1, dim2, dim3, dim4, dim5).astype(np.float32)
-        labels = np.random.randint(0, high=C, size=(N, dim1, dim2, dim3, dim4, dim5))
+        labels = np.random.randint(0, high=C, size=(N, dim1, dim2, dim3, dim4, dim5)).astype(np.int64)
 
         loss, log_prob = softmaxcrossentropy(x,
                                 labels,
                                 reduction=reduction,
                                 get_log_prob=True)
 
-        expect(node, inputs=[x, labels], outputs=[loss, log_prob], name='test_softmax_cross_entropy_input_shape_is_NCd1d2d3d4d5_none_no_weight_log_prob')
+        expect(node, inputs=[x, labels], outputs=[loss, log_prob], name='test_sce_NCd1d2d3d4d5_none_no_weight_log_prob')
 
     @staticmethod
-    def export_input_shape_is_NCd1_mean_weight_negative_ignore_index():  # type: () -> None
+    def export_input_shape_is_NCd1_mean_weight_negative_ii() -> None:
         reduction = 'mean'
         ignore_index = np.int64(-1)
 
@@ -762,7 +760,7 @@ class SoftmaxCrossEntropyLoss(Base):
         N, C, dim1 = 3, 5, 6
         np.random.seed(0)
         x = np.random.rand(N, C, dim1).astype(np.float32)
-        labels = np.random.randint(0, high=C, size=(N, dim1))
+        labels = np.random.randint(0, high=C, size=(N, dim1)).astype(np.int64)
         labels[0][0] = -1
         weight = np.random.rand(C).astype(np.float32)
 
@@ -772,10 +770,10 @@ class SoftmaxCrossEntropyLoss(Base):
                                   reduction=reduction,
                                   ignore_index=ignore_index)
 
-        expect(node, inputs=[x, labels, weight], outputs=[sce], name='test_softmax_cross_entropy_input_shape_is_NCd1_mean_weight_negative_ignore_index')
+        expect(node, inputs=[x, labels, weight], outputs=[sce], name='test_sce_NCd1_mean_weight_negative_ii')
 
     @staticmethod
-    def export_input_shape_is_NCd1_mean_weight_negative_ignore_index_log_prob():  # type: () -> None
+    def export_input_shape_is_NCd1_mean_weight_negative_ii_log_prob() -> None:
         reduction = 'mean'
         ignore_index = np.int64(-1)
 
@@ -788,7 +786,7 @@ class SoftmaxCrossEntropyLoss(Base):
         N, C, dim1 = 3, 5, 6
         np.random.seed(0)
         x = np.random.rand(N, C, dim1).astype(np.float32)
-        labels = np.random.randint(0, high=C, size=(N, dim1))
+        labels = np.random.randint(0, high=C, size=(N, dim1)).astype(np.int64)
         labels[0][0] = -1
         weight = np.random.rand(C).astype(np.float32)
 
@@ -799,10 +797,10 @@ class SoftmaxCrossEntropyLoss(Base):
                                   ignore_index=ignore_index,
                                   get_log_prob=True)
 
-        expect(node, inputs=[x, labels, weight], outputs=[loss, log_prob], name='test_softmax_cross_entropy_input_shape_is_NCd1_mean_weight_negative_ignore_index_log_prob')
+        expect(node, inputs=[x, labels, weight], outputs=[loss, log_prob], name='test_sce_NCd1_mean_weight_negative_ii_log_prob')
 
     @staticmethod
-    def export_input_shape_is_NCd1d2d3_none_no_weight_negative_ignore_index():  # type: () -> None
+    def export_input_shape_is_NCd1d2d3_none_no_weight_negative_ii() -> None:
         reduction = 'none'
         ignore_index = np.int64(-5)
 
@@ -815,7 +813,7 @@ class SoftmaxCrossEntropyLoss(Base):
         N, C, dim1, dim2, dim3 = 3, 5, 6, 6, 5
         np.random.seed(0)
         x = np.random.rand(N, C, dim1, dim2, dim3).astype(np.float32)
-        labels = np.random.randint(0, high=C, size=(N, dim1, dim2, dim3))
+        labels = np.random.randint(0, high=C, size=(N, dim1, dim2, dim3)).astype(np.int64)
         labels[0][0][0][0] = -5
 
         sce = softmaxcrossentropy(x,
@@ -823,10 +821,10 @@ class SoftmaxCrossEntropyLoss(Base):
                                   reduction=reduction,
                                   ignore_index=ignore_index)
 
-        expect(node, inputs=[x, labels], outputs=[sce], name='test_softmax_cross_entropy_input_shape_is_NCd1d2d3_none_no_weight_negative_ignore_index')
+        expect(node, inputs=[x, labels], outputs=[sce], name='test_sce_NCd1d2d3_none_no_weight_negative_ii')
 
     @staticmethod
-    def export_input_shape_is_NCd1d2d3_none_no_weight_negative_ignore_index_log_prob():  # type: () -> None
+    def export_input_shape_is_NCd1d2d3_none_no_weight_negative_ii_log_prob() -> None:
         reduction = 'none'
         ignore_index = np.int64(-5)
 
@@ -839,7 +837,7 @@ class SoftmaxCrossEntropyLoss(Base):
         N, C, dim1, dim2, dim3 = 3, 5, 6, 6, 5
         np.random.seed(0)
         x = np.random.rand(N, C, dim1, dim2, dim3).astype(np.float32)
-        labels = np.random.randint(0, high=C, size=(N, dim1, dim2, dim3))
+        labels = np.random.randint(0, high=C, size=(N, dim1, dim2, dim3)).astype(np.int64)
         labels[0][0][0][0] = -5
 
         loss, log_prob = softmaxcrossentropy(x,
@@ -848,10 +846,10 @@ class SoftmaxCrossEntropyLoss(Base):
                                   ignore_index=ignore_index,
                                   get_log_prob=True)
 
-        expect(node, inputs=[x, labels], outputs=[loss, log_prob], name='test_softmax_cross_entropy_input_shape_is_NCd1d2d3_none_no_weight_negative_ignore_index_log_prob')
+        expect(node, inputs=[x, labels], outputs=[loss, log_prob], name='test_sce_NCd1d2d3_none_no_weight_negative_ii_log_prob')
 
     @staticmethod
-    def export_input_shape_is_NCd1d2d3_sum_weight_high_ignore_index():  # type: () -> None
+    def export_input_shape_is_NCd1d2d3_sum_weight_high_ii() -> None:
         reduction = 'sum'
         ignore_index = np.int64(10)
 
@@ -864,7 +862,7 @@ class SoftmaxCrossEntropyLoss(Base):
         N, C = 3, 5
         np.random.seed(0)
         x = np.random.rand(N, C).astype(np.float32)
-        labels = np.random.randint(0, high=C, size=(N))
+        labels = np.random.randint(0, high=C, size=(N)).astype(np.int64)
         labels[0] = 10
         weight = np.random.rand(C).astype(np.float32)
 
@@ -874,10 +872,10 @@ class SoftmaxCrossEntropyLoss(Base):
                                   reduction=reduction,
                                   ignore_index=ignore_index)
 
-        expect(node, inputs=[x, labels, weight], outputs=[sce], name='test_softmax_cross_entropy_input_shape_is_NCd1d2d3_sum_weight_high_ignore_index')
+        expect(node, inputs=[x, labels, weight], outputs=[sce], name='test_sce_NCd1d2d3_sum_weight_high_ii')
 
     @staticmethod
-    def export_input_shape_is_NCd1d2d3_sum_weight_high_ignore_index_log_prob():  # type: () -> None
+    def export_input_shape_is_NCd1d2d3_sum_weight_high_ii_log_prob() -> None:
         reduction = 'sum'
         ignore_index = np.int64(10)
 
@@ -890,7 +888,7 @@ class SoftmaxCrossEntropyLoss(Base):
         N, C = 3, 5
         np.random.seed(0)
         x = np.random.rand(N, C).astype(np.float32)
-        labels = np.random.randint(0, high=C, size=(N))
+        labels = np.random.randint(0, high=C, size=(N)).astype(np.int64)
         labels[0] = 10
         weight = np.random.rand(C).astype(np.float32)
 
@@ -901,4 +899,4 @@ class SoftmaxCrossEntropyLoss(Base):
                                   ignore_index=ignore_index,
                                   get_log_prob=True)
 
-        expect(node, inputs=[x, labels, weight], outputs=[loss, log_prob], name='test_softmax_cross_entropy_input_shape_is_NCd1d2d3_sum_weight_high_ignore_index_log_prob')
+        expect(node, inputs=[x, labels, weight], outputs=[loss, log_prob], name='test_sce_NCd1d2d3_sum_weight_high_ii_log_prob')
