@@ -1,7 +1,4 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
+# SPDX-License-Identifier: Apache-2.0
 
 import numpy as np  # type: ignore
 
@@ -13,7 +10,7 @@ from . import expect
 class Tile(Base):
 
     @staticmethod
-    def export_tile():  # type: () -> None
+    def export_tile() -> None:
         node = onnx.helper.make_node(
             'Tile',
             inputs=['x', 'y'],
@@ -32,7 +29,7 @@ class Tile(Base):
                name='test_tile')
 
     @staticmethod
-    def export_tile_precomputed():  # type: () -> None
+    def export_tile_precomputed() -> None:
         node = onnx.helper.make_node(
             'Tile',
             inputs=['x', 'y'],
