@@ -1,7 +1,4 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
+# SPDX-License-Identifier: Apache-2.0
 
 import numpy as np  # type: ignore
 
@@ -14,7 +11,7 @@ from onnx import helper
 class Upsample(Base):
 
     @staticmethod
-    def export_nearest():  # type: () -> None
+    def export_nearest() -> None:
         node = onnx.helper.make_node(
             'Upsample',
             inputs=['X', 'scales'],
