@@ -1,6 +1,4 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
+# SPDX-License-Identifier: Apache-2.0
 
 import importlib
 import pkgutil
@@ -17,15 +15,15 @@ all_numeric_dtypes = [
 ]
 
 
-def import_recursive(package):  # type: (ModuleType) -> None
+def import_recursive(package: ModuleType) -> None:
     """
     Takes a package and imports all modules underneath it
     """
-    pkg_dir = None  # type: Optional[List[str]]
+    pkg_dir: Optional[List[str]] = None
     pkg_dir = package.__path__  # type: ignore
     module_location = package.__name__
     for (_module_loader, name, ispkg) in pkgutil.iter_modules(pkg_dir):
-        module_name = "{}.{}".format(module_location, name)  # Module/package
+        module_name = f"{module_location}.{name}"  # Module/package
         module = importlib.import_module(module_name)
         if ispkg:
             import_recursive(module)
