@@ -1,18 +1,16 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
+# SPDX-License-Identifier: Apache-2.0
 
 import pytest  # type: ignore
+import _pytest  # type: ignore
 
 from .coverage import Coverage
-from typing import Dict, Text, Sequence, Any, List
+from typing import Dict, Sequence, Any, List
 
 _coverage = Coverage()
-_marks = {}  # type: Dict[Text, Sequence[Any]]
+_marks: Dict[str, Sequence[Any]] = {}
 
 
-def _add_mark(mark, bucket):  # type: (Any, Text) -> None
+def _add_mark(mark: Any, bucket: str) -> None:
     proto = mark.args[0]
     if isinstance(proto, list):
         assert len(proto) == 1
@@ -21,14 +19,14 @@ def _add_mark(mark, bucket):  # type: (Any, Text) -> None
         _coverage.add_proto(proto, bucket, mark.args[1] == 'RealModel')
 
 
-def pytest_runtest_call(item):  # type: (pytest.nodes.Item) -> None
+def pytest_runtest_call(item: _pytest.nodes.Item) -> None:
     mark = item.get_closest_marker('onnx_coverage')
     if mark:
         assert item.nodeid not in _marks
         _marks[item.nodeid] = mark
 
 
-def pytest_runtest_logreport(report):  # type: (Any) -> None
+def pytest_runtest_logreport(report: Any) -> None:
     if (report.when == 'call'
         and report.outcome == 'passed'
             and report.nodeid in _marks):
@@ -37,7 +35,7 @@ def pytest_runtest_logreport(report):  # type: (Any) -> None
 
 
 @pytest.hookimpl(trylast=True)  # type: ignore
-def pytest_terminal_summary(terminalreporter, exitstatus):  # type: (pytest.terminal.TerminalReporter, int) -> None
+def pytest_terminal_summary(terminalreporter: _pytest.terminal.TerminalReporter, exitstatus: int) -> None:
     for mark in _marks.values():
         _add_mark(mark, 'loaded')
     _coverage.report_text(terminalreporter)
