@@ -1,4 +1,10 @@
+/*
+ * SPDX-License-Identifier: Apache-2.0
+ */
+
 #include "onnx/checker.h"
+#include "onnx/common/file_utils.h"
+#include "onnx/common/path.h"
 #include "onnx/defs/schema.h"
 #include "onnx/defs/tensor_proto_util.h"
 #include "onnx/proto_utils.h"
@@ -8,39 +14,37 @@
 #include <iterator>
 #include <unordered_set>
 
+#ifdef _WIN32
+#include <direct.h>
+#else // POSIX
+#include <sys/stat.h>
+#endif
+
 namespace ONNX_NAMESPACE {
 namespace checker {
 
-#define enforce_has_field(proto, field)                                     \
-  do {                                                                      \
-    if (!proto.has_##field()) {                                             \
-      fail_check(                                                           \
-          "Field '", #field, "' of ", #proto, " is required but missing."); \
-    }                                                                       \
+#define enforce_has_field(proto, field)                                              \
+  do {                                                                               \
+    if (!proto.has_##field()) {                                                      \
+      fail_check("Field '", #field, "' of '", #proto, "' is required but missing."); \
+    }                                                                                \
   } while (0)
 
-#define enforce_has_repeated_field(proto, field)                            \
-  do {                                                                      \
-    if (!proto.field##_size()) {                                            \
-      fail_check("Repeated Field '", #field, "' is required but missing."); \
-    }                                                                       \
+#define enforce_has_repeated_field(proto, field)                                              \
+  do {                                                                                        \
+    if (!proto.field##_size()) {                                                              \
+      fail_check("Repeated Field '", #field, "' of '", #proto, "' is required but missing."); \
+    }                                                                                         \
   } while (0)
 
-#define enforce_non_empty_field(proto, field) \
-  do {                                        \
-    if (proto.field().empty()) {              \
-      fail_check(                             \
-          "Field '",                          \
-          #field,                             \
-          "' of ",                            \
-          #proto,                             \
-          " is required to be non-empty.");   \
-    }                                         \
+#define enforce_non_empty_field(proto, field)                                            \
+  do {                                                                                   \
+    if (proto.field().empty()) {                                                         \
+      fail_check("Field '", #field, "' of '", #proto, "' is required to be non-empty."); \
+    }                                                                                    \
   } while (0)
 
-void check_value_info(
-    const ValueInfoProto& value_info,
-    const CheckerContext& ctx) {
+void check_value_info(const ValueInfoProto& value_info, const CheckerContext& ctx) {
   enforce_non_empty_field(value_info, name);
   // Relax constraint for subgraph input/output.
   if (!ctx.is_main_graph())
@@ -53,6 +57,10 @@ void check_value_info(
       enforce_has_field(type, elem_type);
       enforce_has_field(type, shape);
     } break;
+    case TypeProto::kOptionalType: {
+      const auto& type = value_info.type().optional_type();
+      enforce_has_field(type, elem_type);
+    } break;
     case TypeProto::kSequenceType: {
       const auto& type = value_info.type().sequence_type();
       enforce_has_field(type, elem_type);
@@ -65,29 +73,22 @@ void check_value_info(
 #ifdef ONNX_ML
     case TypeProto::kOpaqueType:
       break;
+#endif
     case TypeProto::kSparseTensorType: {
       const auto& type = value_info.type().sparse_tensor_type();
       enforce_has_field(type, elem_type);
       enforce_has_field(type, shape);
     } break;
-#endif
 
     default:
-      fail_check(
-          "Unrecognized type value case (value_info name: ",
-          value_info.name(),
-          "): ",
-          value_case);
+      fail_check("Unrecognized type value case (value_info name: ", value_info.name(), "): ", value_case);
   }
 }
 
 void check_tensor(const TensorProto& tensor, const CheckerContext& ctx) {
   enforce_has_field(tensor, data_type);
   if (tensor.data_type() == TensorProto::UNDEFINED) {
-    fail_check(
-        "setting data_type field (tensor name: ",
-        tensor.name(),
-        ") to UNDEFINED is not allowed");
+    fail_check("setting data_type field (tensor name: ", tensor.name(), ") to UNDEFINED is not allowed");
   }
 
   int num_value_fields = 0;
@@ -111,8 +112,7 @@ void check_tensor(const TensorProto& tensor, const CheckerContext& ctx) {
 
 #undef check_data_field
 
-  bool stored_externally = tensor.has_data_location() &&
-      tensor.data_location() == TensorProto::EXTERNAL;
+  bool stored_externally = tensor.has_data_location() && tensor.data_location() == TensorProto::EXTERNAL;
   if (stored_externally) {
     if (num_value_fields != 0) {
       fail_check(
@@ -126,21 +126,21 @@ void check_tensor(const TensorProto& tensor, const CheckerContext& ctx) {
     for (const StringStringEntryProto& entry : tensor.external_data()) {
       if (entry.has_key() && entry.has_value() && entry.key() == "location") {
         has_location = true;
-        if (!std::ifstream(ctx.get_model_dir() + entry.value())) {
+        std::string data_path = path_join(ctx.get_model_dir(), entry.value());
+        // use stat to check whether the file exists
+        struct stat buffer;
+        if (stat((data_path).c_str(), &buffer) != 0) {
           fail_check(
               "Data of TensorProto ( tensor name: ",
               tensor.name(),
               ") should be stored in ",
-              ctx.get_model_dir() + entry.value(),
+              data_path,
               ", but it doesn't exist or is not accessible.");
         }
       }
     }
     if (!has_location) {
-      fail_check(
-          "TensorProto ( tensor name: ",
-          tensor.name(),
-          ") is stored externally but doesn't have a location.");
+      fail_check("TensorProto ( tensor name: ", tensor.name(), ") is stored externally but doesn't have a location.");
     }
     return;
   }
@@ -149,23 +149,14 @@ void check_tensor(const TensorProto& tensor, const CheckerContext& ctx) {
     nelem *= x;
   }
   if (nelem == 0 && num_value_fields != 0) {
-    fail_check(
-        "TensorProto (tensor name: ",
-        tensor.name(),
-        ") is 0-element but contains data!");
+    fail_check("TensorProto (tensor name: ", tensor.name(), ") is 0-element but contains data!");
   }
   if (nelem != 0 && num_value_fields != 1) {
-    fail_check(
-        "TensorProto (tensor name: ",
-        tensor.name(),
-        ") should contain one and only one value field.");
+    fail_check("TensorProto (tensor name: ", tensor.name(), ") should contain one and only one value field.");
   }
   if (has_raw_data) {
     if (tensor.data_type() == TensorProto::STRING) {
-      fail_check(
-          "STRING data (tensor name: ",
-          tensor.name(),
-          ") should not be stored in raw_data field");
+      fail_check("STRING data (tensor name: ", tensor.name(), ") should not be stored in raw_data field");
     }
     return;
   } else {
@@ -217,17 +208,111 @@ void check_tensor(const TensorProto& tensor, const CheckerContext& ctx) {
         break;
 
       default:
-        fail_check(
-            "Unrecognized data_type (tensor name: ",
-            tensor.name(),
-            "): ",
-            tensor.data_type());
+        fail_check("Unrecognized data_type (tensor name: ", tensor.name(), "): ", tensor.data_type());
     }
   }
 
 #undef check_field
 }
 
+void check_sequence(const SequenceProto& sequence, const CheckerContext& ctx) {
+  enforce_has_field(sequence, elem_type);
+  if (sequence.elem_type() == SequenceProto::TENSOR) {
+    for (const TensorProto& tensor : sequence.tensor_values()) {
+      check_tensor(tensor, ctx);
+    }
+  } else if (sequence.elem_type() == SequenceProto::SPARSE_TENSOR) {
+    for (const SparseTensorProto& sparse_tensor : sequence.sparse_tensor_values()) {
+      check_sparse_tensor(sparse_tensor, ctx);
+    }
+  } else if (sequence.elem_type() == SequenceProto::SEQUENCE) {
+    for (const SequenceProto& seq : sequence.sequence_values()) {
+      check_sequence(seq, ctx);
+    }
+  } else if (sequence.elem_type() == SequenceProto::MAP) {
+    for (const MapProto& map : sequence.map_values()) {
+      check_map(map, ctx);
+    }
+  } else {
+    fail_check(
+        "Sequence ( Structure name: ",
+        sequence.name(),
+        ", elem_type: ",
+        sequence.elem_type(),
+        ") is not have a valid element type.");
+  }
+}
+
+void check_optional(const OptionalProto& optional, const CheckerContext& ctx) {
+  enforce_has_field(optional, elem_type);
+  if (optional.elem_type() == OptionalProto::UNDEFINED) {
+    return;
+  } else if (optional.elem_type() == OptionalProto::TENSOR) {
+    if (optional.has_tensor_value())
+      check_tensor(optional.tensor_value(), ctx);
+  } else if (optional.elem_type() == OptionalProto::SPARSE_TENSOR) {
+    if (optional.has_sparse_tensor_value())
+      check_sparse_tensor(optional.sparse_tensor_value(), ctx);
+  } else if (optional.elem_type() == OptionalProto::SEQUENCE) {
+    if (optional.has_sequence_value())
+      check_sequence(optional.sequence_value(), ctx);
+  } else if (optional.elem_type() == OptionalProto::MAP) {
+    if (optional.has_map_value())
+      check_map(optional.map_value(), ctx);
+  } else {
+    fail_check(
+        "Optional ( Structure name: ",
+        optional.name(),
+        ", elem_type: ",
+        optional.elem_type(),
+        ") is not have a valid element type.");
+  }
+}
+
+void check_map(const MapProto& map, const CheckerContext& ctx) {
+  enforce_has_field(map, key_type);
+  if (map.key_type() == TensorProto::UNDEFINED) {
+    fail_check("setting key_type field (map name: ", map.name(), ") to UNDEFINED is not allowed");
+  }
+  // Check if key is a valid type, specifically INT8, INT16, INT32, INT64,
+  // UINT8, UINT16, UINT32, UINT64, or STRING.
+  if ((map.key_type() == TensorProto::FLOAT) || (map.key_type() == TensorProto::BOOL) ||
+      (map.key_type() == TensorProto::FLOAT16) || (map.key_type() == TensorProto::COMPLEX64) ||
+      (map.key_type() == TensorProto::COMPLEX128)) {
+    fail_check(
+        "setting key_type field (map name: ",
+        map.name(),
+        ") to invalid TensorProto key_type ",
+        map.key_type(),
+        " is not allowed");
+  }
+
+  // MapProto will use either keys or string_keys, so only one should be > 0.
+  if ((map.keys_size() > 0) && (map.string_keys_size() > 0)) {
+    fail_check("Map (name: ", map.name(), ") should not contain more than one keys field.");
+  }
+
+  int num_keys = map.keys_size() + map.string_keys_size();
+  int num_values = 0;
+
+  enforce_has_field(map, values);
+  check_sequence(map.values(), ctx);
+
+  if (map.values().elem_type() == SequenceProto::TENSOR) {
+    num_values = map.values().tensor_values_size();
+  } else if (map.values().elem_type() == SequenceProto::SPARSE_TENSOR) {
+    num_values = map.values().sparse_tensor_values_size();
+  } else if (map.values().elem_type() == SequenceProto::SEQUENCE) {
+    num_values = map.values().sequence_values_size();
+  } else if (map.values().elem_type() == SequenceProto::MAP) {
+    num_values = map.values().map_values_size();
+  }
+
+  if (num_keys != num_values) {
+    fail_check("Length of map keys and map values are not the same (map name: ", map.name(), ")");
+  }
+}
+
 // Check that the index data stored in a SparseTensorProto is valid.
 // indices: a 1-dimensional tensor; indices[i] represents the
 // linearized index value for the i-th nonzero value.
@@ -239,14 +324,9 @@ void check_sparse_tensor_indices_1(
   int64_t dense_size = 1;
   for (int i = 0; i < dense_rank; ++i)
     dense_size *= sparse_tensor_proto.dims(i);
-  if (static_cast<size_t>(indices.dims(0)) != nnz)
-    fail_check(
-        "Sparse tensor indices (",
-        indices.name(),
-        ") has ",
-        indices.dims(0),
-        " values, but NNZ is ",
-        nnz);
+  if (static_cast<size_t>(indices.dims(0)) != nnz) {
+    fail_check("Sparse tensor indices (", indices.name(), ") has ", indices.dims(0), " values, but NNZ is ", nnz);
+  }
 
   // Check if indices appear in ascending order, and if they have valid
   // values. The i-th value in index_data is the linear index of the i-th
@@ -256,7 +336,7 @@ void check_sparse_tensor_indices_1(
   int64_t prev_index = -1;
   for (size_t i = 0; i < nnz; ++i) {
     int64_t curr_index = index_data[i]; // linearized index of i-th value
-    if (curr_index < 0 || curr_index >= dense_size)
+    if (curr_index < 0 || curr_index >= dense_size) {
       fail_check(
           "Sparse tensor (",
           indices.name(),
@@ -265,13 +345,9 @@ void check_sparse_tensor_indices_1(
           "] out of range [0, ",
           dense_size - 1,
           "]");
+    }
     if (curr_index <= prev_index) {
-      fail_check(
-          "Sparse tensor (",
-          indices.name(),
-          ") index value at position [",
-          i,
-          "] not in sorted order.");
+      fail_check("Sparse tensor (", indices.name(), ") index value at position [", i, "] not in sorted order.");
     }
     prev_index = curr_index;
   }
@@ -285,52 +361,35 @@ void check_sparse_tensor_indices_2(
     const SparseTensorProto& sparse_tensor_proto,
     size_t nnz) {
   int dense_rank = sparse_tensor_proto.dims_size();
-  if (static_cast<size_t>(indices.dims(0)) != nnz)
-    fail_check(
-        "Sparse tensor indices (",
-        indices.name(),
-        ") first dimension size does not equal NNZ.");
-  if (indices.dims(1) != dense_rank)
-    fail_check(
-        "Sparse tensor indices (",
-        indices.name(),
-        ") second dimension size does not match rank of tensor.");
+  if (static_cast<size_t>(indices.dims(0)) != nnz) {
+    fail_check("Sparse tensor indices (", indices.name(), ") first dimension size does not equal NNZ.");
+  }
+  if (indices.dims(1) != dense_rank) {
+    fail_check("Sparse tensor indices (", indices.name(), ") second dimension size does not match rank of tensor.");
+  }
 
   // Check if indices appear in ascending order, and if they have valid
   // values.
   const std::vector<int64_t> index_data = ParseData<int64_t>(&indices);
-
   int64_t prev_index = -1;
   for (size_t i = 0; i < nnz; ++i) {
     int64_t curr_index = 0; // linearized index of i-th value
     for (int j = 0; j < dense_rank; ++j) {
       auto index_ij = index_data[i * dense_rank + j];
-      if ((index_ij < 0) || (index_ij >= sparse_tensor_proto.dims(j)))
-        fail_check(
-            "Sparse tensor (",
-            indices.name(),
-            ") index value at position [",
-            i,
-            ",",
-            j,
-            "] out of range.");
+      if ((index_ij < 0) || (index_ij >= sparse_tensor_proto.dims(j))) {
+        fail_check("Sparse tensor (", indices.name(), ") index value at position [", i, ",", j, "] out of range.");
+      }
       curr_index = curr_index * sparse_tensor_proto.dims(j) + index_ij;
     }
     if (curr_index <= prev_index) {
       fail_check(
-          "Sparse tensor (",
-          indices.name(),
-          ") index value at position [",
-          i,
-          "] not in lexicographic sorted order.");
+          "Sparse tensor (", indices.name(), ") index value at position [", i, "] not in lexicographic sorted order.");
     }
     prev_index = curr_index;
   }
 }
 
-void check_sparse_tensor(
-    const SparseTensorProto& sparse_tensor_proto,
-    const CheckerContext& ctx) {
+void check_sparse_tensor(const SparseTensorProto& sparse_tensor_proto, const CheckerContext& ctx) {
   enforce_has_field(sparse_tensor_proto, values);
 
   const TensorProto& values = sparse_tensor_proto.values();
@@ -341,29 +400,26 @@ void check_sparse_tensor(
   // to be a single value. In the future, if there is a requirement,
   // we may extend this to permit the value to be a "sub-tensor", in which
   // case values will have dimension > 1.
-  if (values.dims_size() != 1)
+  if (values.dims_size() != 1) {
     fail_check("Sparse tensor values (", values.name(), ") must have rank 1.");
+  }
   size_t nnz = static_cast<size_t>(values.dims(0));
-
   int dense_rank = sparse_tensor_proto.dims_size();
   if (dense_rank == 0) {
-    // TODO: Should we add a name field for a sparse-tensor-proto?
-    // Currently, values has a name, but message may be a bit confusing.
-    fail_check(
-        "Sparse tensor (", values.name(), ") must have a dense-rank > 0");
+    fail_check("Sparse tensor (", values.name(), ") must have a dense-rank > 0");
   }
   for (int i = 0; i < dense_rank; ++i) {
-    if (sparse_tensor_proto.dims(i) <= 0)
-      fail_check(
-          "Sparse tensor (", values.name(), ") dimensions are not positive.");
+    if (sparse_tensor_proto.dims(i) <= 0) {
+      fail_check("Sparse tensor (", values.name(), ") dimensions are not positive.");
+    }
   }
 
   if (sparse_tensor_proto.has_indices()) {
     const TensorProto& indices = sparse_tensor_proto.indices();
     check_tensor(indices, ctx);
-    if (indices.data_type() != TensorProto::INT64)
-      fail_check(
-          "Sparse tensor indices (", indices.name(), ") must have INT64 type.");
+    if (indices.data_type() != TensorProto::INT64) {
+      fail_check("Sparse tensor indices (", indices.name(), ") must have INT64 type.");
+    }
     switch (indices.dims().size()) {
       case 1:
         // Indices in linearized format
@@ -374,21 +430,16 @@ void check_sparse_tensor(
         check_sparse_tensor_indices_2(indices, sparse_tensor_proto, nnz);
         return;
       default:
-        fail_check(
-            "Sparse tensor indices (",
-            indices.name(),
-            ") must have rank 1 or 2.");
+        fail_check("Sparse tensor indices (", indices.name(), ") must have rank 1 or 2.");
     }
-  } else if (nnz != 0)
+  } else if (nnz != 0) {
     fail_check("Sparse tensor (", values.name(), ") has no index values.");
+  }
 }
 
 // NB: This is a generic "attribute well-formedness" check, it doesn't
 // actually test if an attribute is valid per a schema
-void check_attribute(
-    const AttributeProto& attr,
-    const CheckerContext& ctx,
-    const LexicalScopeContext& lex_ctx) {
+void check_attribute(const AttributeProto& attr, const CheckerContext& ctx, const LexicalScopeContext& lex_ctx) {
   enforce_non_empty_field(attr, name);
 
   if (ctx.get_ir_version() >= 0x00000002) {
@@ -397,10 +448,9 @@ void check_attribute(
 
   int used_fields = 0;
 
-#define check_type(expected_type)                                              \
-  if (attr.has_type() && attr.type() != expected_type) {                       \
-    fail_check(                                                                \
-        "type field and data field mismatch in attribute ", attr.name(), "."); \
+#define check_type(expected_type)                                                     \
+  if (attr.has_type() && attr.type() != expected_type) {                              \
+    fail_check("type field and data field mismatch in attribute ", attr.name(), "."); \
   }
 
 #define check_singular_field(field, type) \
@@ -420,6 +470,7 @@ void check_attribute(
   check_singular_field(s, AttributeProto::STRING);
   check_singular_field(t, AttributeProto::TENSOR);
   check_singular_field(g, AttributeProto::GRAPH);
+  check_singular_field(tp, AttributeProto::TYPE_PROTO);
   check_singular_field(sparse_tensor, AttributeProto::SPARSE_TENSOR);
   check_repeated_field(floats, AttributeProto::FLOATS);
   check_repeated_field(ints, AttributeProto::INTS);
@@ -427,6 +478,7 @@ void check_attribute(
   check_repeated_field(tensors, AttributeProto::TENSORS);
   check_repeated_field(graphs, AttributeProto::GRAPHS);
   check_repeated_field(sparse_tensors, AttributeProto::SPARSE_TENSORS);
+  check_repeated_field(type_protos, AttributeProto::TYPE_PROTOS);
 
 #undef check_type
 #undef check_singular_field
@@ -436,10 +488,7 @@ void check_attribute(
   // In proto3, when the value to be set is type default value (say 0 for
   // int), used_fields may be 0.
   if (used_fields > 1) {
-    fail_check(
-        "Attribute (name: ",
-        attr.name(),
-        ") should not contain more than one value field.");
+    fail_check("Attribute (name: ", attr.name(), ") should not contain more than one value field.");
   }
 
   if (!ctx.is_main_graph()) {
@@ -447,10 +496,7 @@ void check_attribute(
     if (attr.has_ref_attr_name() && used_fields != 0) {
       // The attribute proto is supposed to refer to data outside and does not
       // have its own value field set.
-      fail_check(
-          "Attribute (name: ",
-          attr.name(),
-          ") should refer to attribute in parent node.");
+      fail_check("Attribute (name: ", attr.name(), ") should refer to attribute in parent node.");
     }
   }
 
@@ -483,38 +529,16 @@ void check_attribute(
   }
 }
 
-void check_node(
-    const NodeProto& node,
-    const CheckerContext& ctx,
-    const LexicalScopeContext& lex_ctx) {
+void check_node(const NodeProto& node, const CheckerContext& ctx, const LexicalScopeContext& lex_ctx) {
   enforce_non_empty_field(node, op_type);
 
   if (node.input().empty() && node.output().empty()) {
-    fail_check(
-        "NodeProto (name: ",
-        node.name(),
-        ", type: ",
-        node.op_type(),
-        ") has zero input and zero output.");
+    fail_check("NodeProto (name: ", node.name(), ", type: ", node.op_type(), ") has zero input and zero output.");
   }
 
-  // Put the removed experimental ops here
-  static std::set<std::string> experimental_ops = {"ATen",
-                                                   "Affine",
-                                                   "ConstantFill",
-                                                   "Crop",
-                                                   "DynamicSlice",
-                                                   "GRUUnit",
-                                                   "GivenTensorFill",
-                                                   "ImageScaler",
-                                                   "ParametricSoftplus",
-                                                   "Scale",
-                                                   "ScaledTanh"};
-  if (experimental_ops.count(node.op_type())) {
-    std::cerr << "Warning: " << node.op_type() << " was a removed "
-              << "experimental ops. In the future, we may directly "
-              << "reject this operator. Please update your model as soon "
-              << "as possible." << std::endl;
+  // If encounter experimental op, stop checking
+  if (check_is_experimental_op(node.op_type())) {
+    std::cerr << "Warning: Checker does not support models with experimental ops: " << node.op_type() << std::endl;
     return;
   }
 
@@ -530,15 +554,13 @@ void check_node(
     check_attribute(attr, ctx, lex_ctx);
   }
 
-  const auto* schema = ctx.get_schema_registry()->GetSchema(
-      node.op_type(), domain_version, node.domain());
+  const auto* schema = ctx.get_schema_registry()->GetSchema(node.op_type(), domain_version, node.domain());
   if (!schema) {
-    if (node.domain() == ONNX_DOMAIN || node.domain() == AI_ONNX_ML_DOMAIN ||
-        node.domain() == "ai.onnx" || node.domain() == AI_ONNX_TRAINING_DOMAIN) {
+    if (node.domain() == ONNX_DOMAIN || node.domain() == AI_ONNX_ML_DOMAIN || node.domain() == "ai.onnx" ||
+        node.domain() == AI_ONNX_TRAINING_DOMAIN) {
       // fail the checker if op in built-in domains has no schema
       fail_check(
-          "No Op registered for " + node.op_type() +
-          " with domain_version of " +
+          "No Op registered for " + node.op_type() + " with domain_version of " +
           ONNX_NAMESPACE::to_string(domain_version));
     } else {
       // TODO: expose the registration of the op schemas appropriately in
@@ -549,18 +571,14 @@ void check_node(
     }
   } else if (schema->Deprecated()) {
     fail_check(
-        "Op registered for " + node.op_type() +
-        " is deprecated in domain_version of " +
+        "Op registered for " + node.op_type() + " is deprecated in domain_version of " +
         ONNX_NAMESPACE::to_string(domain_version));
   } else {
     schema->Verify(node);
   }
 }
 
-void check_graph(
-    const GraphProto& graph,
-    const CheckerContext& ctx,
-    const LexicalScopeContext& parent_lex) {
+void check_graph(const GraphProto& graph, const CheckerContext& ctx, const LexicalScopeContext& parent_lex) {
   enforce_non_empty_field(graph, name);
 
   for (const auto& value_info : graph.input()) {
@@ -587,27 +605,46 @@ void check_graph(
     lex_ctx.add(value_info.name());
   }
 
+  std::unordered_set<std::reference_wrapper<const std::string>, std::hash<std::string>, std::equal_to<std::string>>
+      initializer_name_checker;
+
   for (const auto& init : graph.initializer()) {
+    enforce_has_field(init, name);
+    const auto& name = init.name();
+    if (name.empty()) {
+      fail_check("Tensor initializers must have a non-empty name");
+    }
+
+    if (!initializer_name_checker.insert(std::cref(name)).second) {
+      fail_check(name + " initializer name is not unique");
+    }
+
+    check_tensor(init, ctx);
+
     if (ctx.get_ir_version() <= 0x00000003) {
       // Initializers are a subset of graph inputs for IR_VERSION <= 3
-      if (!lex_ctx.this_graph_has(init.name())) {
-        fail_check(init.name() + " in initializer but not in graph input");
+      if (!lex_ctx.this_graph_has(name)) {
+        fail_check(name + " in initializer but not in graph input");
       }
     } else {
       // An initializer is allowed to have the same name as an input,
       // but is not required to (for IR_VERSION >= 4)
-      lex_ctx.add(init.name());
+      lex_ctx.add(name);
     }
-    check_tensor(init, ctx);
   }
 
-  // TODO: Need to check that sparse-initializers names are distinct from
-  // initializer names. It looks like the existing checker does not check for
-  // certain duplication of names: e.g., two entries in the initializer list
-  // with same name. Will add a new integrated check.
   for (const auto& sparse_init : graph.sparse_initializer()) {
+    const auto& values = sparse_init.values();
+    enforce_has_field(values, name);
+    const auto& name = values.name();
+    if (name.empty()) {
+      fail_check("Sparse tensor initializers must have a non-empty name");
+    }
+    if (!initializer_name_checker.insert(std::cref(name)).second) {
+      fail_check(name + " sparse initializer name is not unique across initializers and sparse_initializers");
+    }
     check_sparse_tensor(sparse_init, ctx);
-    lex_ctx.add(sparse_init.values().name());
+    lex_ctx.add(name);
   }
 
   for (const auto& node : graph.node()) {
@@ -622,7 +659,10 @@ void check_graph(
             "Nodes in a graph must be topologically sorted, however input '",
             input,
             "' of node: \n",
-            ProtoDebugString(node),
+            "name: ",
+            node.name(),
+            " OpType: ",
+            node.op_type(),
             "\n is not output of any previous nodes.");
       }
     }
@@ -631,11 +671,14 @@ void check_graph(
     // find that outputs from control flow ops are colliding with names in the
     // inner block
 
-    try {
+    ONNX_TRY {
       check_node(node, ctx, lex_ctx);
-    } catch (ValidationError& ex) {
-      ex.AppendContext("Bad node spec: " + ProtoDebugString(node));
-      throw ex;
+    }
+    ONNX_CATCH(ValidationError & ex) {
+      ONNX_HANDLE_EXCEPTION([&]() {
+        ex.AppendContext("Bad node spec for node. Name: " + node.name() + " OpType: " + node.op_type());
+        ONNX_THROW_EX(ex);
+      });
     }
     // check for SSA form
     for (const auto& output : node.output()) {
@@ -655,21 +698,106 @@ void check_graph(
   }
 }
 
-void check_function(
-    const FunctionProto& function,
+// Utilify function to get the imported version of domain from opset imports
+// Returns -1 if requested domain is not found in the opset_imports
+int get_version_for_domain(const std::string& domain, const std::unordered_map<std::string, int>& opset_imports) {
+  auto it = opset_imports.find(domain);
+  if (it == opset_imports.end()) {
+    return -1;
+  }
+
+  return it->second;
+}
+
+void check_opset_compatibility(
+    const NodeProto& node,
+    const CheckerContext& ctx,
+    const std::unordered_map<std::string, int>& func_opset_imports,
+    const std::unordered_map<std::string, int>& model_opset_imports) {
+  auto func_opset_version = get_version_for_domain(node.domain(), func_opset_imports);
+  auto model_opset_version = get_version_for_domain(node.domain(), model_opset_imports);
+
+  if (func_opset_version == -1) {
+    fail_check("No Opset registered for domain " + node.domain());
+  }
+
+  if (model_opset_version == -1) {
+    // model does not include opset import for a node present in function body.
+    // This is ok as along as the opset import is present in function level opset imports.
+    return;
+  }
+
+  if (func_opset_version == model_opset_version) {
+    // both versions are same, no need to verify schema.
+    return;
+  }
+
+  const auto* schema_for_model_import =
+      ctx.get_schema_registry()->GetSchema(node.op_type(), model_opset_version, node.domain());
+
+  const auto* schema_for_function_import =
+      ctx.get_schema_registry()->GetSchema(node.op_type(), func_opset_version, node.domain());
+
+  if (!schema_for_model_import && !schema_for_function_import) {
+    // the op belongs to a custom domain so we cannot verify schema
+    return;
+  }
+
+  // if schema is present for 1 but not other or the schema since versions do not match then raise an error
+  if (!schema_for_model_import || !schema_for_function_import ||
+      schema_for_function_import->since_version() != schema_for_model_import->since_version()) {
+    fail_check(
+        "Opset import for domain " + node.domain() + " in function op " + node.op_type() +
+        "is not compatible with the version imported by model. FunctionOp imports version " +
+        ONNX_NAMESPACE::to_string(func_opset_version) + "whereas model imports version " +
+        ONNX_NAMESPACE::to_string(model_opset_version));
+  }
+}
+
+void check_model_local_functions(
+    const ModelProto& model,
     const CheckerContext& ctx,
     const LexicalScopeContext& parent_lex) {
-  enforce_non_empty_field(function, name);
-  enforce_has_field(function, since_version);
+  // make a copy of model opset imports to maintain a main copy of opset imports across the model and
+  // all model local functions to verify opset compatibility
+  std::unordered_map<std::string, int> model_opset_imports(ctx.get_opset_imports());
+
+  // merge the opset imports from every function in model_opset_imports
+  // only add the opset import if an entry for it does not exist in model_opset_imports
+  // if there is an entry then the compatibility will be checked later on in check_opset_compatibility
+  // called by check_function.
+  for (const auto& function_proto : model.functions()) {
+    for (const auto& opset_import : function_proto.opset_import()) {
+      if (get_version_for_domain(opset_import.domain(), model_opset_imports) == -1) {
+        model_opset_imports[opset_import.domain()] = opset_import.version();
+      }
+    }
+  }
 
   CheckerContext ctx_copy = ctx;
-  std::unordered_map<std::string, int> opsets;
-  for (auto& relied_opset : function.opset_import()) {
-    auto& domain = relied_opset.domain();
-    auto version = relied_opset.version();
-    opsets[domain] = static_cast<int>(version);
+  ctx_copy.set_opset_imports(model_opset_imports);
+
+  for (const auto& function_proto : model.functions()) {
+    check_function(function_proto, ctx_copy, parent_lex);
   }
-  ctx_copy.set_opset_imports(opsets);
+}
+
+void check_function(const FunctionProto& function, const CheckerContext& ctx, const LexicalScopeContext& parent_lex) {
+  enforce_non_empty_field(function, name);
+
+  if (ctx.get_ir_version() >= 0x00000008) {
+    enforce_has_field(function, domain);
+  }
+
+  const auto& model_opset_imports = ctx.get_opset_imports();
+  CheckerContext ctx_copy = ctx;
+
+  std::unordered_map<std::string, int> func_opset_imports;
+  for (auto& relied_opset : function.opset_import()) {
+    func_opset_imports[relied_opset.domain()] = static_cast<int>(relied_opset.version());
+  }
+
+  ctx_copy.set_opset_imports(func_opset_imports);
 
   LexicalScopeContext lex_ctx{parent_lex};
 
@@ -678,9 +806,7 @@ void check_function(
     // this_or_ancestor_graph_has
     if (lex_ctx.this_graph_has(input)) {
       fail_check(
-          "Graph must be in single static assignment (SSA) form, however '",
-          input,
-          "' has been used multiple times.");
+          "Graph must be in single static assignment (SSA) form, however '", input, "' has been used multiple times.");
     }
     lex_ctx.add(input);
   }
@@ -689,20 +815,15 @@ void check_function(
   for (const auto& output : function.output()) {
     auto result = outputs.insert(output);
     if (!result.second) {
-      fail_check(
-          "function (",
-          function.name(),
-          ") should not have duplicate outputs specified.");
+      fail_check("function (", function.name(), ") should not have duplicate outputs specified.");
     }
   }
+
   std::unordered_set<std::string> attrs;
   for (const auto& attr : function.attribute()) {
     auto result = attrs.insert(attr);
     if (!result.second) {
-      fail_check(
-          "function (",
-          function.name(),
-          ") should not have duplicate attributes specified.");
+      fail_check("function (", function.name(), ") should not have duplicate attributes specified.");
     }
   }
 
@@ -718,11 +839,18 @@ void check_function(
             "Nodes in a function must be topologically sorted, however input '",
             input,
             "' of node: \n",
-            ProtoDebugString(node),
+            "Name: ",
+            node.name(),
+            " OpType: ",
+            node.op_type(),
             "\n is neither output of any previous nodes nor input of the function.");
       }
     }
 
+    // check whether the opset version imported for a domain by function and model are
+    // compatible
+    check_opset_compatibility(node, ctx_copy, func_opset_imports, model_opset_imports);
+
     check_node(node, ctx_copy, lex_ctx);
 
     // check for SSA form
@@ -762,42 +890,31 @@ void check_model(const ModelProto& model, CheckerContext& ctx) {
   ctx.set_ir_version(static_cast<int>(model.ir_version()));
   std::unordered_map<std::string, int> opset_imports;
   for (const auto& opset_import : model.opset_import()) {
-    opset_imports[opset_import.domain()] =
-        static_cast<int>(opset_import.version());
+    opset_imports[opset_import.domain()] = static_cast<int>(opset_import.version());
   }
   if (model.ir_version() >= 3) {
-    if (opset_imports.empty())
-      fail_check(
-          "model with IR version >= 3 must specify opset_import for ONNX");
+    if (opset_imports.empty()) {
+      fail_check("model with IR version >= 3 must specify opset_import for ONNX");
+    }
   } else {
     if (opset_imports.empty())
       opset_imports[ONNX_DOMAIN] = 1;
-    else
-      fail_check(
-          "model with IR version < 3 cannot have opset_import specified");
+    else {
+      fail_check("model with IR version < 3 cannot have opset_import specified");
+    }
   }
   ctx.set_opset_imports(opset_imports);
   LexicalScopeContext lex_ctx;
   check_graph(model.graph(), ctx, lex_ctx);
+
+  if (ctx.get_ir_version() >= 0x00000008) {
+    check_model_local_functions(model, ctx, lex_ctx);
+  }
 }
 
 void check_model(const std::string& model_path) {
   ModelProto model;
-  std::fstream model_stream(model_path, std::ios::in | std::ios::binary);
-  if (!model_stream.good()) {
-    fail_check(
-        "Unable to open model file:",
-        model_path,
-        ". Please check if it is a valid file.");
-  }
-  std::string data{std::istreambuf_iterator<char>{model_stream},
-                   std::istreambuf_iterator<char>{}};
-  if (!ParseProtoFromBytes(&model, data.c_str(), data.size())) {
-    fail_check(
-        "Unable to parse model from file:",
-        model_path,
-        ". Please check if it is a valid protobuf file of model.");
-  }
+  LoadProtoFromPath(model_path, model);
 
   CheckerContext ctx;
   std::string model_dir;
@@ -814,6 +931,23 @@ void check_model(const ModelProto& model) {
   check_model(model, ctx);
 }
 
+std::set<std::string> experimental_ops = {
+    "ATen",
+    "Affine",
+    "ConstantFill",
+    "Crop",
+    "DynamicSlice",
+    "GRUUnit",
+    "GivenTensorFill",
+    "ImageScaler",
+    "ParametricSoftplus",
+    "Scale",
+    "ScaledTanh"};
+
+bool check_is_experimental_op(std::string node_op_type) {
+  return (experimental_ops.count(node_op_type)) ? true : false;
+}
+
 #undef fail_check
 #undef enforce_has_field
 #undef enforce_has_repeated_field
