@@ -1,10 +1,14 @@
+/*
+ * SPDX-License-Identifier: Apache-2.0
+ */
+
 // ATTENTION: The code in this file is highly EXPERIMENTAL.
 // Adventurous users should note that the APIs will probably change.
 
+#include "onnx/common/assertions.h"
 #include <cstdarg>
 #include <cstdio>
-
-#include "onnx/common/assertions.h"
+#include "onnx/common/common.h"
 
 namespace ONNX_NAMESPACE {
 
@@ -20,11 +24,11 @@ std::string barf(const char* fmt, ...) {
 }
 
 void throw_assert_error(std::string& msg) {
-  throw assert_error(msg);
+  ONNX_THROW_EX(assert_error(msg));
 }
 
 void throw_tensor_error(std::string& msg) {
-  throw tensor_error(msg);
+  ONNX_THROW_EX(tensor_error(msg));
 }
 
 } // namespace ONNX_NAMESPACE
