@@ -1,13 +1,17 @@
+/*
+ * SPDX-License-Identifier: Apache-2.0
+ */
+
 // ATTENTION: The code in this file is highly EXPERIMENTAL.
 // Adventurous users should note that the APIs will probably change.
 
-#include <sstream>
 #include "onnx/common/ir_pb_converter.h"
+#include <sstream>
 
 namespace ONNX_NAMESPACE {
 
 // Part 1: convert ONNX Protobuf to IR
-std::unique_ptr<Graph> graphProtoToGraph(const GraphProto& gp, bool nested);
+std::unique_ptr<Graph> graphProtoToGraph(const GraphProto& gp, bool nested, const int ir_version = IR_VERSION);
 
 Tensor tensorProtoToTensor(const ONNX_NAMESPACE::TensorProto& tp) {
   Tensor ret;
@@ -90,7 +94,7 @@ Tensor tensorProtoToTensor(const ONNX_NAMESPACE::TensorProto& tp) {
   return ret;
 }
 
-void convertAttribute(const ONNX_NAMESPACE::AttributeProto& ap, Node* n) {
+void convertAttribute(const ONNX_NAMESPACE::AttributeProto& ap, Node* n, const int ir_version = IR_VERSION) {
   Symbol sym = Symbol(ap.name());
   switch (ap.type()) {
     case ONNX_NAMESPACE::AttributeProto_AttributeType_FLOAT:
@@ -141,14 +145,26 @@ void convertAttribute(const ONNX_NAMESPACE::AttributeProto& ap, Node* n) {
       n->ts_(sym, std::move(tensors));
       break;
     }
+    case ONNX_NAMESPACE::AttributeProto_AttributeType_TYPE_PROTO:
+      n->tp_(sym, ap.tp());
+      break;
+    case ONNX_NAMESPACE::AttributeProto_AttributeType_TYPE_PROTOS: {
+      std::vector<TypeProto> types;
+      types.reserve(ap.type_protos_size());
+      for (int i = 0; i < ap.type_protos_size(); i++) {
+        types.push_back(ap.type_protos(i));
+      }
+      n->tps_(sym, std::move(types));
+      break;
+    }
     case ONNX_NAMESPACE::AttributeProto_AttributeType_GRAPH:
-      n->g_(sym, graphProtoToGraph(ap.g(), true));
+      n->g_(sym, graphProtoToGraph(ap.g(), true, ir_version));
       break;
     case ONNX_NAMESPACE::AttributeProto_AttributeType_GRAPHS: {
       std::vector<std::shared_ptr<Graph>> graphs;
       graphs.reserve(ap.graphs_size());
       for (int i = 0; i < ap.graphs_size(); i++) {
-        graphs.push_back(graphProtoToGraph(ap.graphs(i), true));
+        graphs.push_back(graphProtoToGraph(ap.graphs(i), true, ir_version));
       }
       n->gs_(sym, std::move(graphs));
       break;
@@ -163,29 +179,40 @@ void convertAttribute(const ONNX_NAMESPACE::AttributeProto& ap, Node* n) {
   }
 }
 
-void convertAttributes(ONNX_NAMESPACE::NodeProto& np, Node* n) {
+void convertAttributes(ONNX_NAMESPACE::NodeProto& np, Node* n, const int ir_version = IR_VERSION) {
   for (int i = 0; i < np.attribute_size(); i++) {
-    convertAttribute(np.attribute(i), n);
+    convertAttribute(np.attribute(i), n, ir_version);
   }
 }
 
-std::vector<Dimension> tensorShapeProtoToDimensions(
-    const ONNX_NAMESPACE::TensorShapeProto& tsp) {
+std::vector<Dimension> tensorShapeProtoToDimensions(const ONNX_NAMESPACE::TensorShapeProto& tsp) {
   std::vector<Dimension> dims;
   dims.reserve(tsp.dim_size());
   for (int i = 0; i < tsp.dim_size(); i++) {
     if (tsp.dim(i).has_dim_value()) {
       dims.push_back(Dimension(static_cast<int>(tsp.dim(i).dim_value())));
-    } else {
+    } else if (tsp.dim(i).has_dim_param()) {
       dims.push_back(Dimension(tsp.dim(i).dim_param()));
+    } else {
+      // a dimension that has neither dim_value nor dim_param set
+      // represents an unknown dimension unrelated to other unknown dimensions.
+      dims.push_back(Dimension());
     }
   }
   return dims;
 }
 
-std::unique_ptr<Graph> graphProtoToGraph(
-    const ONNX_NAMESPACE::GraphProto& gp,
-    bool nested) {
+void createDummyValue(
+    std::unique_ptr<Graph>& g,
+    const std::string& name,
+    std::unordered_map<std::string, Value*>& value_by_name_of) {
+  auto* undef = g->create(kCaptured, 1);
+  g->appendNode(undef);
+  undef->outputs()[0]->setUniqueName(name);
+  value_by_name_of[name] = undef->outputs()[0];
+}
+
+std::unique_ptr<Graph> graphProtoToGraph(const ONNX_NAMESPACE::GraphProto& gp, bool nested, const int ir_version) {
   std::unique_ptr<Graph> g(new Graph());
 
   if (gp.has_name()) {
@@ -231,16 +258,20 @@ std::unique_ptr<Graph> graphProtoToGraph(
   for (int i = 0; i < gp.input_size(); i++) {
     auto vip = gp.input(i);
     auto v = g->addInput();
-    v->setElemType(vip.type().tensor_type().elem_type());
-    v->setSizes(tensorShapeProtoToDimensions(vip.type().tensor_type().shape()));
+    const auto& tensor_type = vip.type().tensor_type();
+    if (tensor_type.has_elem_type()) {
+      v->setElemType(tensor_type.elem_type());
+    }
+    if (tensor_type.has_shape()) {
+      v->setSizes(tensorShapeProtoToDimensions(tensor_type.shape()));
+    }
     v->setUniqueName(vip.name());
     value_by_name_of[vip.name()] = v;
   }
 
   for (int i = 0; i < gp.node_size(); i++) {
     auto np = gp.node(i);
-    auto* n =
-        g->create(Symbol(np.op_type()), /* num_outputs = */ np.output_size());
+    auto* n = g->create(Symbol(np.op_type()), /* num_outputs = */ np.output_size());
     g->appendNode(n);
     for (int j = 0; j < np.output_size(); j++) {
       auto out = n->outputs()[j];
@@ -249,7 +280,7 @@ std::unique_ptr<Graph> graphProtoToGraph(
       out->setUniqueName(np.output(j));
       value_by_name_of[np.output(j)] = out;
     }
-    convertAttributes(np, n);
+    convertAttributes(np, n, ir_version);
     std::vector<std::string> inputs;
     inputs.reserve(np.input_size());
     for (int j = 0; j < np.input_size(); j++) {
@@ -267,6 +298,21 @@ std::unique_ptr<Graph> graphProtoToGraph(
     }
   }
 
+  for (int i = 0; i < gp.initializer_size(); ++i) {
+    auto init = tensorProtoToTensor(gp.initializer(i));
+    // If ir_version >= 4, initializer does not have to be included in input
+    // Create a Value from initializer by addInitializerNode if name does not exist in input
+    // and save it into value_by_name_of for later use (node input)
+    if (ir_version >= 4 && value_by_name_of.count(init.name()) == 0) {
+      value_by_name_of[init.name()] = g->addInitializerAndCreateValue(init);
+    } else {
+      // If ir_version < 4 or the initializer exists in input
+      // Simply add initializer without creating new value
+      // which means it will prioritize input value over initializer value if both exist
+      g->addInitializer(init);
+    }
+  }
+
   for (auto n : g->nodes()) {
     auto search = inputs_by_node.find(n);
     if (search == inputs_by_node.end()) {
@@ -276,16 +322,13 @@ std::unique_ptr<Graph> graphProtoToGraph(
       if (!value_by_name_of.count(input) && nested) {
         // Undefined reference to an input in a nested block. This may be a
         // captured value. Create a dummy node that we ignore later.
-        auto* undef = g->create(kCaptured, 1);
-        g->appendNode(undef);
-        undef->outputs()[0]->setUniqueName(input);
-        value_by_name_of[input] = undef->outputs()[0];
+        createDummyValue(g, input, value_by_name_of);
       }
 
       if (!value_by_name_of.count(input)) {
         std::ostringstream msg;
         msg << "Input " << input << " is undefined!";
-        throw std::out_of_range(msg.str());
+        ONNX_THROW_EX(std::out_of_range(msg.str()));
       }
       n->addInput(value_by_name_of.at(input));
     }
@@ -297,32 +340,30 @@ std::unique_ptr<Graph> graphProtoToGraph(
       // graph to be "inputs" of a dummy "output" node. The same lexical
       // scoping rules are valid here, thus we need to add a dummy node
       // in the case of an undefined reference
-      auto* undef = g->create(kCaptured, 1);
-      g->appendNode(undef);
-      undef->outputs()[0]->setUniqueName(gp.output(i).name());
-      value_by_name_of[gp.output(i).name()] = undef->outputs()[0];
+      createDummyValue(g, gp.output(i).name(), value_by_name_of);
+    }
+    const auto& output_tensor_type = gp.output(i).type().tensor_type();
+    if (output_tensor_type.has_elem_type()) {
+      value_by_name_of[gp.output(i).name()]->setElemType(output_tensor_type.elem_type());
+    }
+    if (output_tensor_type.has_shape()) {
+      value_by_name_of[gp.output(i).name()]->setSizes(tensorShapeProtoToDimensions(output_tensor_type.shape()));
     }
-    value_by_name_of[gp.output(i).name()]->setElemType(
-        gp.output(i).type().tensor_type().elem_type());
-    value_by_name_of[gp.output(i).name()]->setSizes(
-        tensorShapeProtoToDimensions(
-            gp.output(i).type().tensor_type().shape()));
     g->registerOutput(value_by_name_of[gp.output(i).name()]);
   }
 
   for (int i = 0; i < gp.value_info_size(); i++) {
-    value_by_name_of[gp.value_info(i).name()]->setElemType(
-        gp.value_info(i).type().tensor_type().elem_type());
-    if (gp.value_info(i).type().tensor_type().has_shape()) {
-      value_by_name_of[gp.value_info(i).name()]->setSizes(
-          tensorShapeProtoToDimensions(
-              gp.value_info(i).type().tensor_type().shape()));
+    const auto& tensor_type = gp.value_info(i).type().tensor_type();
+    if (!value_by_name_of.count(gp.value_info(i).name())) {
+      // Ideally the model should not have a value_info whose name does not exist in the graph (unused); simply skip it
+      continue;
+    }
+    if (tensor_type.has_elem_type()) {
+      value_by_name_of[gp.value_info(i).name()]->setElemType(tensor_type.elem_type());
+    }
+    if (tensor_type.has_shape()) {
+      value_by_name_of[gp.value_info(i).name()]->setSizes(tensorShapeProtoToDimensions(tensor_type.shape()));
     }
-  }
-
-  for (int i = 0; i < gp.initializer_size(); i++) {
-    auto init = tensorProtoToTensor(gp.initializer(i));
-    g->addInitializer(init, init.name());
   }
 
   return g;
@@ -335,11 +376,11 @@ std::unique_ptr<Graph> ImportModelProto(const ModelProto& mp) {
     return nullptr;
   }
 
-  std::unique_ptr<Graph> g(graphProtoToGraph(mp.graph(), false));
+  std::unique_ptr<Graph> g(graphProtoToGraph(mp.graph(), false, mp.ir_version()));
   for (int i = 0; i < mp.opset_import_size(); i++) {
-    OpSetID new_opset_version(
-        mp.opset_import(i).domain(), mp.opset_import(i).version());
-    g->opset_versions_mutable().emplace_back(std::move(new_opset_version));
+    OpSetID new_opset_version(mp.opset_import(i).domain(), mp.opset_import(i).version());
+    g->forSelfAndEachSubGraph(
+        [&new_opset_version](Graph* graph) { graph->opset_versions_mutable().emplace_back(new_opset_version); });
   }
   return g;
 }
@@ -415,7 +456,7 @@ void encodeTensor(ONNX_NAMESPACE::TensorProto* p, const Tensor& tensor) {
     case ONNX_NAMESPACE::TensorProto_DataType_UNDEFINED:
       fail_convert("Unknown tensor data type");
   }
-  if (!tensor.raw().empty()) {
+  if (tensor.is_raw_data()) {
     p->set_raw_data(tensor.raw());
   }
 }
@@ -424,72 +465,86 @@ void addAttribute(ONNX_NAMESPACE::NodeProto* n_p, Node* n, Symbol name) {
   auto attr = n_p->add_attribute();
   attr->set_name(name.toString());
   switch (n->kindOf(name)) {
-    case AttributeKind::f:
+    case AttributeKind::f: {
       attr->set_f(static_cast<float>(n->f(name)));
       attr->set_type(ONNX_NAMESPACE::AttributeProto_AttributeType_FLOAT);
-      break;
-    case AttributeKind::fs:
+    } break;
+    case AttributeKind::fs: {
       attr->set_type(ONNX_NAMESPACE::AttributeProto_AttributeType_FLOATS);
       for (auto& v : n->fs(name))
         attr->add_floats(static_cast<float>(v));
-      break;
-    case AttributeKind::i:
+    } break;
+    case AttributeKind::i: {
       attr->set_type(ONNX_NAMESPACE::AttributeProto_AttributeType_INT);
       attr->set_i(n->i(name));
-      break;
-    case AttributeKind::is:
+    } break;
+    case AttributeKind::is: {
       attr->set_type(ONNX_NAMESPACE::AttributeProto_AttributeType_INTS);
       for (auto& v : n->is(name))
         attr->add_ints(v);
-      break;
-    case AttributeKind::s:
+    } break;
+    case AttributeKind::s: {
       attr->set_type(ONNX_NAMESPACE::AttributeProto_AttributeType_STRING);
       attr->set_s(n->s(name));
-      break;
-    case AttributeKind::ss:
+    } break;
+    case AttributeKind::ss: {
       attr->set_type(ONNX_NAMESPACE::AttributeProto_AttributeType_STRINGS);
       for (auto& v : n->ss(name))
         attr->add_strings(v);
-      break;
+    } break;
     case AttributeKind::t: {
       attr->set_type(ONNX_NAMESPACE::AttributeProto_AttributeType_TENSOR);
       auto t = attr->mutable_t();
       encodeTensor(t, n->t(name));
     } break;
-    case AttributeKind::ts:
+    case AttributeKind::ts: {
       attr->set_type(ONNX_NAMESPACE::AttributeProto_AttributeType_TENSORS);
       for (auto& v : n->ts(name)) {
         auto t = attr->add_tensors();
         encodeTensor(t, v);
       }
-      break;
+    } break;
     case AttributeKind::g: {
       attr->set_type(ONNX_NAMESPACE::AttributeProto_AttributeType_GRAPH);
       auto g = attr->mutable_g();
       encodeGraph(g, n->g(name));
     } break;
-    case AttributeKind::gs:
+    case AttributeKind::gs: {
       attr->set_type(ONNX_NAMESPACE::AttributeProto_AttributeType_GRAPHS);
       for (auto& v : n->gs(name)) {
         auto g = attr->add_graphs();
         encodeGraph(g, v);
       }
-      break;
+    } break;
+    case AttributeKind::tp: {
+      attr->set_type(ONNX_NAMESPACE::AttributeProto_AttributeType_TYPE_PROTO);
+      auto tp = attr->mutable_tp();
+      tp->CopyFrom(n->tp(name));
+    } break;
+    case AttributeKind::tps: {
+      attr->set_type(ONNX_NAMESPACE::AttributeProto_AttributeType_TYPE_PROTOS);
+      for (auto& v : n->tps(name)) {
+        auto tp = attr->add_type_protos();
+        tp->CopyFrom(v);
+      }
+    } break;
   }
 }
 
-void encodeTypeProtoTensorType(
-    ONNX_NAMESPACE::TypeProto_Tensor* tensor_type,
-    Value* n) {
-  tensor_type->set_elem_type(n->elemType());
+void encodeTypeProtoTensorType(ONNX_NAMESPACE::TypeProto_Tensor* tensor_type, Value* n) {
+  if (n->elemType() != 0) {
+    tensor_type->set_elem_type(n->elemType());
+  }
   if (n->has_sizes()) {
     ONNX_NAMESPACE::TensorShapeProto* shape = tensor_type->mutable_shape();
     for (const Dimension& d : n->sizes()) {
       auto dim = shape->add_dim();
-      if (d.is_int) {
-        dim->set_dim_value(d.dim);
-      } else {
-        dim->set_dim_param(d.param);
+      if (!d.is_unknown) {
+        if (d.is_int) {
+          dim->set_dim_value(d.dim);
+        } else {
+          dim->set_dim_param(d.param);
+        }
       }
     }
   }
@@ -497,9 +552,11 @@ void encodeTypeProtoTensorType(
 
 void encodeValueInfo(ONNX_NAMESPACE::ValueInfoProto* v, Value* n) {
   v->set_name(value_name(n));
-  ONNX_NAMESPACE::TypeProto* t = v->mutable_type();
-  ONNX_NAMESPACE::TypeProto_Tensor* tensor_type = t->mutable_tensor_type();
-  encodeTypeProtoTensorType(tensor_type, n);
+  if (n->elemType() != 0 || n->has_sizes()) {
+    ONNX_NAMESPACE::TypeProto* t = v->mutable_type();
+    ONNX_NAMESPACE::TypeProto_Tensor* tensor_type = t->mutable_tensor_type();
+    encodeTypeProtoTensorType(tensor_type, n);
+  }
 }
 
 void encodeGraph(GraphProto* p_g, const std::shared_ptr<Graph>& g) {
@@ -522,8 +579,7 @@ void encodeGraph(GraphProto* p_g, const std::shared_ptr<Graph>& g) {
     encodeValueInfo(v, output);
   }
 
-  std::unordered_set<Value*> graph_outputs(
-      g->outputs().begin(), g->outputs().end());
+  std::unordered_set<Value*> graph_outputs(g->outputs().begin(), g->outputs().end());
 
   for (auto node : g->nodes()) {
     if (node->kind() == kUndefined || node->kind() == kCaptured) {
@@ -547,8 +603,7 @@ void encodeGraph(GraphProto* p_g, const std::shared_ptr<Graph>& g) {
       if (graph_outputs.find(output) != graph_outputs.end()) {
         continue;
       }
-      if (output->elemType() == TensorProto_DataType_UNDEFINED &&
-          output->sizes().empty()) {
+      if (output->elemType() == TensorProto_DataType_UNDEFINED && output->sizes().empty()) {
         continue;
       }
       ValueInfoProto* v = p_g->add_value_info();
