@@ -1,8 +1,12 @@
+/*
+ * SPDX-License-Identifier: Apache-2.0
+ */
+
 // ATTENTION: The code in this file is highly EXPERIMENTAL.
 // Adventurous users should note that the APIs will probably change.
 
 #pragma once
-
+#include "onnx/common/common.h"
 #include "onnx/common/ir.h"
 #include "onnx/onnx_pb.h"
 
@@ -22,16 +26,14 @@ class ConvertError final : public std::runtime_error {
   }
 
   void AppendContext(const std::string& context) {
-    expanded_message_ = MakeString(
-        std::runtime_error::what(), "\n\n==> Context: ", context);
+    expanded_message_ = MakeString(std::runtime_error::what(), "\n\n==> Context: ", context);
   }
 
  private:
   std::string expanded_message_;
 };
 
-#define fail_convert(...) \
-  throw ConvertError(MakeString(__VA_ARGS__));
+#define fail_convert(...) ONNX_THROW_EX(ConvertError(MakeString(__VA_ARGS__)));
 
 void ExportModelProto(ModelProto* p_m, const std::shared_ptr<Graph>& g);
 
