@@ -1,5 +1,6 @@
-// Copyright (c) ONNX Project Contributors.
-// Licensed under the MIT license.
+/*
+ * SPDX-License-Identifier: Apache-2.0
+ */
 
 #include "onnx/common/model_helpers.h"
 #include "onnx/checker.h"
@@ -17,10 +18,7 @@ Common::Status BuildNode(
     std::vector<std::string> const& outputs,
     NodeProto* node) {
   if (node == NULL) {
-    return Common::Status(
-        Common::CHECKER,
-        Common::INVALID_ARGUMENT,
-        "node_proto should not be nullptr.");
+    return Common::Status(Common::CHECKER, Common::INVALID_ARGUMENT, "node_proto should not be nullptr.");
   }
   node->set_name(name);
   node->set_domain(domain);
@@ -35,4 +33,4 @@ Common::Status BuildNode(
 
   return Common::Status::OK();
 }
-} // namespace ONNX_NAMESPACE
\ No newline at end of file
+} // namespace ONNX_NAMESPACE
