@@ -1,53 +1,59 @@
-// Copyright (c) ONNX Project Contributors.
-// Licensed under the MIT license.
+/*
+ * SPDX-License-Identifier: Apache-2.0
+ */
 
+#include <assert.h>
 #include "onnx/defs/schema.h"
+
 namespace ONNX_NAMESPACE {
 using SupportType = OpSchema::SupportType;
 
-int handle_negative_axis_validate(
-    const std::string& attrib,
-    int axis,
-    int rank) {
-  if (!(-rank <= axis && axis < rank))
-    fail_shape_inference(
-        attrib,
-        " axis value ",
-        axis,
-        " is invalid for a tensor of rank ",
-        rank);
+static std::vector<std::string> control_flow_types() {
+  auto t = OpSchema::all_tensor_types_with_bfloat();
+  auto s = OpSchema::all_tensor_sequence_types_with_bfloat();
+  auto o = OpSchema::all_optional_types_with_bfloat();
+  t.insert(t.end(), s.begin(), s.end());
+  t.insert(t.end(), o.begin(), o.end());
+  return t;
+}
+
+int handle_negative_axis_validate(const std::string& attrib, int axis, int rank) {
+  if (!(-rank <= axis && axis < rank)) {
+    fail_shape_inference(attrib, " axis value ", axis, " is invalid for a tensor of rank ", rank);
+  }
   return (axis >= 0 ? axis : axis + rank);
 }
 
 void ScanInferenceFunction(InferenceContext& ctx) {
   auto num_inputs = ctx.getNumInputs();
-  auto num_scan_inputs =
-      narrow_cast<size_t>(ctx.getAttribute("num_scan_inputs")->i());
+  auto num_scan_inputs = narrow_cast<size_t>(ctx.getAttribute("num_scan_inputs")->i());
   auto num_loop_state_vars = num_inputs - num_scan_inputs;
   auto num_outputs = ctx.getNumOutputs();
   auto num_scan_outputs = num_outputs - num_loop_state_vars;
 
   std::vector<int64_t> axes, output_axes;
   if (getRepeatedAttribute(ctx, "scan_input_axes", axes)) {
-    if (axes.size() != num_scan_inputs)
+    if (axes.size() != num_scan_inputs) {
       fail_shape_inference(
           "Number of scan input axes specified (",
           axes.size(),
           ") is not equal to number of scan inputs (",
           num_scan_inputs,
           ").");
+    }
   } else {
     axes.insert(axes.end(), num_scan_inputs, 0);
   }
 
   if (getRepeatedAttribute(ctx, "scan_output_axes", output_axes)) {
-    if (output_axes.size() != num_scan_outputs)
+    if (output_axes.size() != num_scan_outputs) {
       fail_shape_inference(
           "Number of scan output axes specified (",
           output_axes.size(),
           ") is not equal to number of scan outputs (",
           num_scan_outputs,
           ").");
+    }
   } else {
     output_axes.insert(output_axes.end(), num_scan_outputs, 0);
   }
@@ -56,6 +62,7 @@ void ScanInferenceFunction(InferenceContext& ctx) {
   temporary_type_protos.reserve(num_inputs);
 
   std::vector<const TypeProto*> subgraph_input_types;
+  subgraph_input_types.reserve(num_inputs);
 
   TensorShapeProto_Dimension sequence_len_dim;
 
@@ -89,16 +96,14 @@ void ScanInferenceFunction(InferenceContext& ctx) {
 
         // remove sequence length dimensions and add to subgraph_input_types
         int axis = static_cast<int>(axes[i - num_loop_state_vars]);
-        axis = handle_negative_axis_validate(
-            "scan_input_axes", axis, shape.dim_size());
+        axis = handle_negative_axis_validate("scan_input_axes", axis, shape.dim_size());
 
         // update sequence_len if a value is available
 
         const auto& dims = shape.dim();
         mergeInDimensionInfo(dims.Get(axis), sequence_len_dim, 1);
 
-        temporary_type_protos.push_back(
-            RemoveIthDimensionFromShape(*input_type, axis));
+        temporary_type_protos.push_back(RemoveIthDimensionFromShape(*input_type, axis));
         subgraph_input_types.push_back(&temporary_type_protos.back());
 
       } else {
@@ -113,14 +118,14 @@ void ScanInferenceFunction(InferenceContext& ctx) {
   GraphInferencer* graphInferencer = ctx.getGraphAttributeInferencer("body");
   if (graphInferencer) {
     std::vector<const TensorProto*> input_data;
+    input_data.reserve(num_inputs);
     for (size_t i = 0; i < num_inputs; ++i) {
       // ctx.getInputData(i), the input to scan, does not represent the input to
       // scan body. So, we pass in null, to represent an unknown value.
       input_data.push_back(nullptr);
     }
 
-    output_types =
-        graphInferencer->doInferencing(subgraph_input_types, input_data);
+    output_types = graphInferencer->doInferencing(subgraph_input_types, input_data);
   }
 
   // if empty(), assume inferencing was skipped
@@ -138,39 +143,30 @@ void ScanInferenceFunction(InferenceContext& ctx) {
       const bool is_loop_state_var = i < num_loop_state_vars;
       auto* subgraph_output_type = output_types[i];
       auto* scan_output_type = ctx.getOutputType(i);
-      auto* mutable_scan_output_tensor_type =
-          scan_output_type->mutable_tensor_type();
+      auto* mutable_scan_output_tensor_type = scan_output_type->mutable_tensor_type();
 
       if (!subgraph_output_type->has_tensor_type()) {
-        fail_type_inference(
-            "Scan 'body' subgraph outputs should all be tensors but output ",
-            i,
-            " was not");
+        fail_type_inference("Scan 'body' subgraph outputs should all be tensors but output ", i, " was not");
       }
       auto& subgraph_output_tensor_type = subgraph_output_type->tensor_type();
 
       if (is_loop_state_var) {
         // merge shape; type already propagated
-        mergeInShapeInfo(
-            subgraph_output_tensor_type, *mutable_scan_output_tensor_type);
+        mergeInShapeInfo(subgraph_output_tensor_type, *mutable_scan_output_tensor_type);
       } else {
-        scan_output_type->mutable_tensor_type()->set_elem_type(
-            subgraph_output_tensor_type.elem_type());
+        scan_output_type->mutable_tensor_type()->set_elem_type(subgraph_output_tensor_type.elem_type());
 
         // propagate shape
         if (subgraph_output_tensor_type.has_shape()) {
           // infer shape of scan-output from the shape of scan-output-element
           // by adding sequence-length at the correct axis position
-          const TensorShapeProto& subgraph_output_shape =
-              subgraph_output_tensor_type.shape();
+          const TensorShapeProto& subgraph_output_shape = subgraph_output_tensor_type.shape();
           TensorShapeProto inferred_shape;
 
           auto subgraph_output_rank = subgraph_output_shape.dim_size();
           auto output_rank = subgraph_output_rank + 1;
-          int output_axis =
-              static_cast<int>(output_axes[i - num_loop_state_vars]);
-          output_axis = handle_negative_axis_validate(
-              "scan_output_axes", output_axis, output_rank);
+          int output_axis = static_cast<int>(output_axes[i - num_loop_state_vars]);
+          output_axis = handle_negative_axis_validate("scan_output_axes", output_axis, output_rank);
 
           for (int j = 0; j < output_axis; ++j)
             *(inferred_shape.add_dim()) = subgraph_output_shape.dim(j);
@@ -196,17 +192,14 @@ void IfInferenceFunction(InferenceContext& ctx) {
   std::vector<const TypeProto*> else_output_types;
 
   // Run inferencing on the subgraph
-  GraphInferencer* graphInferencer =
-      ctx.getGraphAttributeInferencer("then_branch");
+  GraphInferencer* graphInferencer = ctx.getGraphAttributeInferencer("then_branch");
   if (graphInferencer) {
-    then_output_types =
-        graphInferencer->doInferencing(subgraph_input_types, input_data);
+    then_output_types = graphInferencer->doInferencing(subgraph_input_types, input_data);
   }
 
   graphInferencer = ctx.getGraphAttributeInferencer("else_branch");
   if (graphInferencer) {
-    else_output_types =
-        graphInferencer->doInferencing(subgraph_input_types, input_data);
+    else_output_types = graphInferencer->doInferencing(subgraph_input_types, input_data);
   }
 
   auto num_outputs = ctx.getNumOutputs();
@@ -223,55 +216,43 @@ void IfInferenceFunction(InferenceContext& ctx) {
   }
 
   if (num_then_outputs != num_outputs) {
-    fail_type_inference(
-        "If node has ",
-        num_outputs,
-        " but subgraphs produce ",
-        num_then_outputs);
+    fail_type_inference("If node has ", num_outputs, " but subgraphs produce ", num_then_outputs);
   }
 
   for (size_t i = 0, end = then_output_types.size(); i < end; ++i) {
     auto then_output = then_output_types[i];
     auto else_output = else_output_types[i];
 
-    if (then_output->value_case() != else_output->value_case()) {
-      fail_type_inference(
-          "Mismatched type for output ",
-          i,
-          " then=",
-          then_output->value_case(),
-          " else=",
-          else_output->value_case());
-    }
-
     auto* if_output = ctx.getOutputType(i);
     *if_output = *then_output;
 
-    if (then_output->has_tensor_type()) {
-      auto then_elem_type = then_output->tensor_type().elem_type();
-      auto else_elem_type = else_output->tensor_type().elem_type();
+    UnionTypeInfo(*else_output, *if_output);
+  }
+}
 
-      if (then_elem_type != else_elem_type) {
-        fail_type_inference(
-            "Mismatched tensor element type for output ",
-            i,
-            " then=",
-            then_elem_type,
-            " else=",
-            else_elem_type);
-      }
-
-      UnionShapeInfo(
-          else_output->tensor_type().shape(), *if_output->mutable_tensor_type());
+void ClearShape(TypeProto& input_type) {
+  if (input_type.has_tensor_type()) {
+    input_type.mutable_tensor_type()->clear_shape();
+  } else if (input_type.has_sequence_type()) {
+    auto& seq_type = *input_type.mutable_sequence_type();
+    if (seq_type.has_elem_type()) {
+      ClearShape(*(seq_type.mutable_elem_type()));
+    }
+  } else if (input_type.has_optional_type()) {
+    auto& opt_type = *input_type.mutable_optional_type();
+    if (opt_type.has_elem_type()) {
+      ClearShape(*(opt_type.mutable_elem_type()));
     }
   }
 }
 
 void LoopInferenceFunction(InferenceContext& ctx) {
   auto num_inputs = ctx.getNumInputs();
+  assert(num_inputs >= 2);
   auto num_loop_state_vars = num_inputs - 2; // skip 'M' and 'cond'
 
   std::vector<const TypeProto*> subgraph_input_types;
+  subgraph_input_types.reserve(num_inputs);
 
   std::vector<TypeProto> temporary_type_protos;
   temporary_type_protos.reserve(num_inputs - 2);
@@ -279,8 +260,7 @@ void LoopInferenceFunction(InferenceContext& ctx) {
   // create TypeProto to validate iteration number type is the same as the
   // optional 'M' input for max iterations.
   TypeProto iter_num_type;
-  iter_num_type.mutable_tensor_type()->set_elem_type(
-      TensorProto_DataType_INT64);
+  iter_num_type.mutable_tensor_type()->set_elem_type(TensorProto_DataType_INT64);
   subgraph_input_types.push_back(&iter_num_type);
 
   // 'cond'
@@ -296,8 +276,8 @@ void LoopInferenceFunction(InferenceContext& ctx) {
     // inferencing
     temporary_type_protos.push_back(*ctx.getInputType(i));
     auto& input_type = temporary_type_protos.back();
-    input_type.mutable_tensor_type()->clear_shape();
 
+    ClearShape(input_type);
     subgraph_input_types.push_back(&input_type);
   }
 
@@ -312,8 +292,7 @@ void LoopInferenceFunction(InferenceContext& ctx) {
       input_data.push_back(ctx.getInputData(i));
     }
 
-    subgraph_output_types =
-        graphInferencer->doInferencing(subgraph_input_types, input_data);
+    subgraph_output_types = graphInferencer->doInferencing(subgraph_input_types, input_data);
   }
 
   // if empty(), assume inferencing was skipped
@@ -337,9 +316,18 @@ void LoopInferenceFunction(InferenceContext& ctx) {
 
       const bool is_loop_state_var = i < num_loop_state_vars;
 
-      if (!subgraph_output_type->has_tensor_type()) {
+      if (!subgraph_output_type->has_tensor_type() && !subgraph_output_type->has_sequence_type() &&
+          !subgraph_output_type->has_optional_type()) {
         fail_type_inference(
-            "Loop 'body' subgraph outputs should all be tensors but output ",
+            "Loop 'body' subgraph outputs should all be tensors or sequences or optionals, but output ",
+            i,
+            " was ",
+            subgraph_output_type->value_case());
+      }
+
+      if (!is_loop_state_var && !subgraph_output_type->has_tensor_type()) {
+        fail_type_inference(
+            "Loop 'body' subgraph scan outputs should all be tensors but output ",
             i,
             " was ",
             subgraph_output_type->value_case());
@@ -351,28 +339,26 @@ void LoopInferenceFunction(InferenceContext& ctx) {
       if (is_loop_state_var) {
         // shape may change across iterations so ignore.
       } else {
-        // per iteration output. first dimension will be number of iterations
-        // but we don't know that value yet
-        TypeProto inferred_type(*subgraph_output_type);
-        auto* mutable_inferred_tensor_type =
-            inferred_type.mutable_tensor_type();
-        auto* mutable_inferred_shape =
-            mutable_inferred_tensor_type->mutable_shape();
+        // propogate shape
+        if (subgraph_output_type->tensor_type().has_shape()) {
+          // per iteration output. first dimension will be number of iterations
+          // but we don't know that value yet
+          TypeProto inferred_type(*subgraph_output_type);
+          auto* mutable_inferred_tensor_type = inferred_type.mutable_tensor_type();
+          auto* mutable_inferred_shape = mutable_inferred_tensor_type->mutable_shape();
 
-        mutable_inferred_shape->clear_dim();
+          mutable_inferred_shape->clear_dim();
 
-        // add empty dimension for number of iterations
-        mutable_inferred_shape->add_dim();
+          // add empty dimension for number of iterations
+          mutable_inferred_shape->add_dim();
 
-        // add dimensions from subgraph output shape
-        for (const auto& dim :
-             subgraph_output_type->tensor_type().shape().dim()) {
-          (*mutable_inferred_shape->add_dim()) = dim;
+          // add dimensions from subgraph output shape
+          for (const auto& dim : subgraph_output_type->tensor_type().shape().dim()) {
+            (*mutable_inferred_shape->add_dim()) = dim;
+          }
+
+          mergeInShapeInfo(*mutable_inferred_tensor_type, *loop_output_type->mutable_tensor_type());
         }
-
-        mergeInShapeInfo(
-            *mutable_inferred_tensor_type,
-            *loop_output_type->mutable_tensor_type());
       }
     }
   }
@@ -380,7 +366,7 @@ void LoopInferenceFunction(InferenceContext& ctx) {
 
 ONNX_OPERATOR_SET_SCHEMA(
     If,
-    11,
+    16,
     OpSchema()
         .SetDoc("If conditional")
         .Input(0, "cond", "Condition for the if", "B")
@@ -418,11 +404,14 @@ ONNX_OPERATOR_SET_SCHEMA(
             " be live-out to the enclosing scope. The number of outputs must match"
             " the number of outputs in the then_branch.",
             AttributeProto::GRAPH)
-        .TypeConstraint("V", OpSchema::all_tensor_types(), "All Tensor types")
+        .TypeConstraint(
+            "V",
+            control_flow_types(),
+            "All Tensor, Sequence(Tensor), Optional(Tensor), and Optional(Sequence(Tensor)) types")
         .TypeConstraint("B", {"tensor(bool)"}, "Only bool")
         .TypeAndShapeInferenceFunction(IfInferenceFunction));
 
-static const char* Loop_ver11_doc = R"DOC(
+static const char* Loop_ver16_doc = R"DOC(
 Generic Looping construct. This loop has multiple termination conditions:
 
 1) Trip count. Iteration count specified at runtime. Set by
@@ -512,13 +501,13 @@ C-style code:
       for (int i=0; i < max_trip_count && keepgoing_out; ++i) {
         /* Implicitly-defined code: bind actual parameter values
            to formal parameter variables of loop-body */
-        bool keepgoing_in = keepgoing_out; 
+        bool keepgoing_in = keepgoing_out;
         bool b_in = b_out;
 
         /* User-defined code (loop body) */
         int my_local = a + b_in; // Reading value "a" from the enclosing scope is fine
         b_out = a - b_in;
-        keepgoing_out = my_local > b_out; 
+        keepgoing_out = my_local > b_out;
         user_defined_val = b_in + b_in; // b_in and b_out are different variables
         /* End user-defined code */
 
@@ -556,13 +545,15 @@ Frontends should emit multi-layer RNNs as a series of While operators (with
 time being the inner looping dimension), with each successive layer consuming
 the scan_outputs from the previous layer, possibly going through several
 point-wise operators (e.g. dropout, residual connections, linear layer).
+
+The input/output of subgraph (produced by loop node) matching is based on order instead of name. The implementation will figure out the names based on this order.
 )DOC";
 
 ONNX_OPERATOR_SET_SCHEMA(
     Loop,
-    11,
+    16,
     OpSchema()
-        .SetDoc(Loop_ver11_doc)
+        .SetDoc(Loop_ver16_doc)
         .Input(
             0,
             "M",
@@ -588,7 +579,8 @@ ONNX_OPERATOR_SET_SCHEMA(
         .Output(
             0,
             "v_final_and_scan_outputs",
-            "Final N loop carried dependency values then K scan_outputs",
+            "Final N loop carried dependency values then K scan_outputs. "
+            "Scan outputs must be Tensors.",
             "V",
             OpSchema::Variadic,
             false)
@@ -602,21 +594,18 @@ ONNX_OPERATOR_SET_SCHEMA(
             " if the dimensions or data type of these scan_outputs change across loop"
             " iterations.",
             AttributeProto::GRAPH)
-        .TypeConstraint("V", OpSchema::all_tensor_types(), "All Tensor types")
         .TypeConstraint(
-            "I",
-            {"tensor(int64)"},
-            "tensor of int64, which should be a scalar.")
-        .TypeConstraint(
-            "B",
-            {"tensor(bool)"},
-            "tensor of bool, which should be a scalar.")
+            "V",
+            control_flow_types(),
+            "All Tensor, Sequence(Tensor), Optional(Tensor), and Optional(Sequence(Tensor)) types")
+        .TypeConstraint("I", {"tensor(int64)"}, "tensor of int64, which should be a scalar.")
+        .TypeConstraint("B", {"tensor(bool)"}, "tensor of bool, which should be a scalar.")
         .TypeAndShapeInferenceFunction(LoopInferenceFunction));
 
-static const char* scan_11_doc = R"DOC(
+static const char* scan_16_doc = R"DOC(
 Scan can be used to iterate over one or more scan_input tensors,
 constructing zero or more scan_output tensors. It combines ideas from general recurrences,
-functional programming constructs such as scan, fold, map, and zip and is intended to enable
+functional programming constructs such as scan, fold, map, and zip, and is intended to enable
 generalizations of RNN-like constructs for sequence-to-sequence processing.
 Other tensors (referred to as state_variables here) can be used to carry a state
 when iterating from one element to another (similar to hidden-state in RNNs, also referred
@@ -711,7 +700,7 @@ be encoded as a ScanLoop. Note that the loop-body is a nested graph, and it dire
 values are computed in the outer graph, they need to be passed in as extra state_variables.
 
     graph rnn-encoding {
-      %H_0 = ... 
+      %H_0 = ...
       %X = ...
       %Y_h, %Y = Scan[body = <graph rnn-cell-1>, num_scan_inputs=1](%H_0, %X)
       return %Y, %Y_h
@@ -739,9 +728,9 @@ values are computed in the outer graph, they need to be passed in as extra state
 
 ONNX_OPERATOR_SET_SCHEMA(
     Scan,
-    11,
+    16,
     OpSchema()
-        .SetDoc(scan_11_doc)
+        .SetDoc(scan_16_doc)
         .Input(
             0,
             "initial_state_and_scan_inputs",
@@ -766,11 +755,7 @@ ONNX_OPERATOR_SET_SCHEMA(
             " if the dimensions of these values change across loop iterations.",
             AttributeProto::GRAPH,
             true)
-        .Attr(
-            "num_scan_inputs",
-            "An attribute specifying the number of scan_inputs M. ",
-            AttributeProto::INT,
-            true)
+        .Attr("num_scan_inputs", "An attribute specifying the number of scan_inputs M. ", AttributeProto::INT, true)
         .Attr(
             "scan_input_directions",
             "An optional list of M flags. The i-th element of the list specifies the direction "
@@ -806,8 +791,7 @@ ONNX_OPERATOR_SET_SCHEMA(
             "range is [-r, r-1].",
             AttributeProto::INTS,
             false)
-        .TypeConstraint("I", {"tensor(int64)"}, "Int64 tensor")
-        .TypeConstraint("V", OpSchema::all_tensor_types(), "All Tensor types")
-        .TypeAndShapeInferenceFunction(ScanInferenceFunction));
+        .TypeConstraint("V", OpSchema::all_tensor_types_with_bfloat(), "All Tensor types")
+        .TypeAndShapeInferenceFunction(ScanInferenceFunction)); // Shares same shape inference as opset 11
 
 } // namespace ONNX_NAMESPACE
