@@ -1,27 +1,24 @@
-// Copyright (c) ONNX Project Contributors.
-// Licensed under the MIT license.
+/*
+ * SPDX-License-Identifier: Apache-2.0
+ */
 
-#include <cmath>
 #include <algorithm>
+#include <cmath>
 #include "onnx/defs/function.h"
 #include "onnx/defs/schema.h"
 
 namespace ONNX_NAMESPACE {
-static const char* Constant_ver12_doc = R"DOC(
+static const char* Constant_ver13_doc = R"DOC(
 This operator produces a constant tensor. Exactly one of the provided attributes, either value, sparse_value,
 or value_* must be specified.
 )DOC";
 
 ONNX_OPERATOR_SET_SCHEMA(
     Constant,
-    12,
+    13,
     OpSchema()
-        .SetDoc(Constant_ver12_doc)
-        .Attr(
-            "value",
-            "The value for the elements of the output tensor.",
-            AttributeProto::TENSOR,
-            false)
+        .SetDoc(Constant_ver13_doc)
+        .Attr("value", "The value for the elements of the output tensor.", AttributeProto::TENSOR, false)
         .Attr(
             "sparse_value",
             "The value for the elements of the output tensor in sparse format.",
@@ -57,14 +54,10 @@ ONNX_OPERATOR_SET_SCHEMA(
             "The values for the elements for the 1D, UTF-8 string, output tensor.",
             AttributeProto::STRINGS,
             false)
-        .Output(
-            0,
-            "output",
-            "Output tensor containing the same value of the provided tensor.",
-            "T")
+        .Output(0, "output", "Output tensor containing the same value of the provided tensor.", "T")
         .TypeConstraint(
             "T",
-            OpSchema::all_tensor_types(),
+            OpSchema::all_tensor_types_with_bfloat(),
             "Constrain input and output types to all tensor types.")
         .TypeAndShapeInferenceFunction([](InferenceContext& ctx) {
           auto* value = ctx.getAttribute("value");
@@ -77,18 +70,18 @@ ONNX_OPERATOR_SET_SCHEMA(
           auto* value_strings = ctx.getAttribute("value_strings");
 
           std::vector<bool> non_null_attr = {
-            (nullptr != value),
-            (nullptr != sparse_value),
-            (nullptr != value_int),
-            (nullptr != value_ints),
-            (nullptr != value_float),
-            (nullptr != value_floats),
-            (nullptr != value_string),
-            (nullptr != value_strings)
-          };
-          if (std::count(non_null_attr.begin(), non_null_attr.end(), true) != 1)
+              (nullptr != value),
+              (nullptr != sparse_value),
+              (nullptr != value_int),
+              (nullptr != value_ints),
+              (nullptr != value_float),
+              (nullptr != value_floats),
+              (nullptr != value_string),
+              (nullptr != value_strings)};
+          if (std::count(non_null_attr.begin(), non_null_attr.end(), true) != 1) {
             fail_shape_inference(
                 "One and only one of the attributes 'value', 'value_*' or 'sparse_value' must be specified for a Constant node.");
+          }
 
           if (nullptr != value) {
             // OpSchema::Verify check ensures that the attribute value has_t():
@@ -100,8 +93,9 @@ ONNX_OPERATOR_SET_SCHEMA(
 
           if (nullptr != value_int) {
             // OpSchema::Verify check ensures that the attribute value has_i():
-            if (!value_int->has_i())
+            if (!value_int->has_i()) {
               fail_shape_inference("Attribute 'value_int' expect an integer.")
+            }
             updateOutputElemType(ctx, 0, TensorProto::INT64);
             updateOutputShape(ctx, 0, TensorShapeProto());
             return;
@@ -109,8 +103,9 @@ ONNX_OPERATOR_SET_SCHEMA(
 
           if (nullptr != value_ints) {
             // OpSchema::Verify check ensures that the attribute value has ints.
-            if (value_ints->ints_size() < 1)
-              fail_shape_inference("Attribute 'value_ints' expect a list of integers.")
+            if (value_ints->ints_size() < 1) {
+              fail_shape_inference("Attribute 'value_ints' expect a list of integers.");
+            }
             updateOutputElemType(ctx, 0, TensorProto::INT64);
             appendDim(getOutputShape(ctx, 0), value_ints->ints_size());
             return;
@@ -118,8 +113,9 @@ ONNX_OPERATOR_SET_SCHEMA(
 
           if (nullptr != value_float) {
             // OpSchema::Verify check ensures that the attribute value has_i():
-            if (!value_float->has_f())
-              fail_shape_inference("Attribute 'value_float' expect a float.")
+            if (!value_float->has_f()) {
+              fail_shape_inference("Attribute 'value_float' expect a float.");
+            }
             updateOutputElemType(ctx, 0, TensorProto::FLOAT);
             updateOutputShape(ctx, 0, TensorShapeProto());
             return;
@@ -127,8 +123,9 @@ ONNX_OPERATOR_SET_SCHEMA(
 
           if (nullptr != value_floats) {
             // OpSchema::Verify check ensures that the attribute value has ints.
-            if (value_floats->floats_size() < 1)
-              fail_shape_inference("Attribute 'value_floats' expect a list of floats.")
+            if (value_floats->floats_size() < 1) {
+              fail_shape_inference("Attribute 'value_floats' expect a list of floats.");
+            }
             updateOutputElemType(ctx, 0, TensorProto::FLOAT);
             appendDim(getOutputShape(ctx, 0), value_floats->floats_size());
             return;
@@ -136,8 +133,9 @@ ONNX_OPERATOR_SET_SCHEMA(
 
           if (nullptr != value_string) {
             // OpSchema::Verify check ensures that the attribute value has_i():
-            if (!value_string->has_s())
-              fail_shape_inference("Attribute 'value_string' expect a string.")
+            if (!value_string->has_s()) {
+              fail_shape_inference("Attribute 'value_string' expect a string.");
+            }
             updateOutputElemType(ctx, 0, TensorProto::STRING);
             updateOutputShape(ctx, 0, TensorShapeProto());
             return;
@@ -145,8 +143,9 @@ ONNX_OPERATOR_SET_SCHEMA(
 
           if (nullptr != value_strings) {
             // OpSchema::Verify check ensures that the attribute value has ints.
-            if (value_strings->strings_size() < 1)
-              fail_shape_inference("Attribute 'value_strings' expect a list of strings.")
+            if (value_strings->strings_size() < 1) {
+              fail_shape_inference("Attribute 'value_strings' expect a list of strings.");
+            }
             updateOutputElemType(ctx, 0, TensorProto::STRING);
             appendDim(getOutputShape(ctx, 0), value_strings->strings_size());
             return;
@@ -167,7 +166,7 @@ ONNX_OPERATOR_SET_SCHEMA(
 
           fail_shape_inference(
               "TypeAndShapeInferenceFunction implementation incomplete: "
-              "this line should never be reached.")
+              "this line should never be reached.");
         }));
 
 static const char* ConstantOfShape_ver9_doc = R"DOC(
@@ -217,71 +216,15 @@ ONNX_OPERATOR_SET_SCHEMA(
             "Constrain output types to be numerics.")
         .TypeAndShapeInferenceFunction([](InferenceContext& ctx) {
           if (ctx.getAttribute("value") != nullptr) {
-            propagateElemTypeFromDtypeToOutput(
-                ctx, ctx.getAttribute("value"), 0);
+            propagateElemTypeFromDtypeToOutput(ctx, ctx.getAttribute("value"), 0);
           } else {
             propagateElemTypeFromDtypeToOutput(ctx, TensorProto::FLOAT, 0);
           }
 
-          // Shape inference based on input shape
-          const TensorProto* targetShapeInitializer = ctx.getInputData(0);
-          if (!targetShapeInitializer) {
-            // This is the case when exact shape input is not available.
-            // In this case, if the number of dimensions can be infered
-            // from the input 'shape' tensor, then we add the same number
-            // of dimensions (without any dim_value information) to the
-            // output.
-            if (ctx.getInputType(0)->tensor_type().has_shape()) {
-              auto& input_shape = getInputShape(ctx, 0);
-              auto input_shape_dim_size = input_shape.dim_size();
-              if (input_shape_dim_size > 1) {
-                fail_shape_inference(
-                    "Shape input must be a one-dimensional tensor.");
-              }
-              if (input_shape.dim(0).has_dim_value()) {
-                const auto& input_shape_dim_value =
-                    input_shape.dim(0).dim_value();
-                if (input_shape_dim_value > 0) {
-                  auto final_output_shape = ctx.getOutputType(0)
-                                                ->mutable_tensor_type()
-                                                ->mutable_shape();
-                  for (int i = 0; i < input_shape_dim_value; ++i) {
-                    auto newdim = final_output_shape->add_dim();
-                    (void)(newdim); // To eliminate "unused variable" compiler
-                                    // warning.
-                  }
-                }
-              }
-            }
-            return;
-          }
-
-          // This is the second case when exact shape data is available.
-          // In this case, we extract the shape values from input tensor
-          // and create output tensor of that shape.
-          // First, extract target shape value.
-          std::vector<int64_t> targetShape;
-          if (targetShapeInitializer->has_raw_data()) {
-            const std::string& bytes = targetShapeInitializer->raw_data();
-            targetShape.insert(
-                targetShape.end(),
-                reinterpret_cast<const int64_t*>(bytes.c_str()),
-                reinterpret_cast<const int64_t*>(bytes.c_str() + bytes.size()));
-          } else {
-            const auto& data = targetShapeInitializer->int64_data();
-            targetShape.insert(targetShape.end(), data.begin(), data.end());
-          }
-          // Next, set output shape to the target shape.
-          auto final_output_shape =
-              ctx.getOutputType(0)->mutable_tensor_type()->mutable_shape();
-          for (const int64_t& targetShapeElem : targetShape) {
-            if (targetShapeElem >= 0) {
-              auto* new_dim = final_output_shape->add_dim();
-              new_dim->set_dim_value(targetShapeElem);
-            } else {
-              // Check if value is less than -1; fail if so
-              fail_shape_inference("Invalid shape value: ", targetShapeElem);
-            }
+          bool found = false;
+          TensorShapeProto output_shape = getShapeInput(ctx, 0, found);
+          if (found) {
+            *ctx.getOutputType(0)->mutable_tensor_type()->mutable_shape() = output_shape;
           }
         }));
 
@@ -314,16 +257,8 @@ ONNX_OPERATOR_SET_SCHEMA(
             "specified, then type defaults to 'float'.",
             AttributeProto::INT,
             OPTIONAL_VALUE)
-        .Input(
-            0,
-            "input",
-            "2D input tensor to copy shape, and optionally, type information from.",
-            "T1")
-        .Output(
-            0,
-            "output",
-            "Output tensor, same shape as input tensor T1.",
-            "T2")
+        .Input(0, "input", "2D input tensor to copy shape, and optionally, type information from.", "T1")
+        .Output(0, "output", "Output tensor, same shape as input tensor T1.", "T2")
         .TypeConstraint(
             "T1",
             {"tensor(float16)",
@@ -383,16 +318,8 @@ ONNX_OPERATOR_SET_SCHEMA(
     1,
     OpSchema()
         .SetDoc(RandomUniform_ver1_doc)
-        .Attr(
-            "low",
-            "Lower boundary of the output values.",
-            AttributeProto::FLOAT,
-            0.0f)
-        .Attr(
-            "high",
-            "Upper boundary of the output values.",
-            AttributeProto::FLOAT,
-            1.0f)
+        .Attr("low", "Lower boundary of the output values.", AttributeProto::FLOAT, 0.0f)
+        .Attr("high", "Upper boundary of the output values.", AttributeProto::FLOAT, 1.0f)
         .Attr(
             "seed",
             "(Optional) Seed to the random generator, if not specified we will auto generate one.",
@@ -404,17 +331,13 @@ ONNX_OPERATOR_SET_SCHEMA(
             AttributeProto::INT,
             static_cast<int64_t>(TensorProto::FLOAT))
         .Attr("shape", "The shape of the output tensor.", AttributeProto::INTS)
-        .Output(
-            0,
-            "output",
-            "Output tensor of random values drawn from uniform distribution",
-            "T")
+        .Output(0, "output", "Output tensor of random values drawn from uniform distribution", "T")
         .TypeConstraint(
             "T",
             {"tensor(float16)", "tensor(float)", "tensor(double)"},
             "Constrain output types to float tensors.")
         .TypeAndShapeInferenceFunction([](InferenceContext& ctx) {
-          propagateElemTypeFromAttributeToOutput(ctx, "dtype", 0);
+          propagateElemTypeFromAttributeToOutput(ctx, "dtype", 0, TensorProto::FLOAT);
           propagateShapeFromAttributeToOutput(ctx, "shape", 0);
         }));
 
@@ -433,16 +356,8 @@ ONNX_OPERATOR_SET_SCHEMA(
     1,
     OpSchema()
         .SetDoc(RandomNormal_ver1_doc)
-        .Attr(
-            "mean",
-            "The mean of the normal distribution.",
-            AttributeProto::FLOAT,
-            0.0f)
-        .Attr(
-            "scale",
-            "The standard deviation of the normal distribution.",
-            AttributeProto::FLOAT,
-            1.0f)
+        .Attr("mean", "The mean of the normal distribution.", AttributeProto::FLOAT, 0.0f)
+        .Attr("scale", "The standard deviation of the normal distribution.", AttributeProto::FLOAT, 1.0f)
         .Attr(
             "seed",
             "(Optional) Seed to the random generator, if not specified we will auto generate one.",
@@ -454,17 +369,13 @@ ONNX_OPERATOR_SET_SCHEMA(
             AttributeProto::INT,
             static_cast<int64_t>(TensorProto::FLOAT))
         .Attr("shape", "The shape of the output tensor.", AttributeProto::INTS)
-        .Output(
-            0,
-            "output",
-            "Output tensor of random values drawn from normal distribution",
-            "T")
+        .Output(0, "output", "Output tensor of random values drawn from normal distribution", "T")
         .TypeConstraint(
             "T",
             {"tensor(float16)", "tensor(float)", "tensor(double)"},
             "Constrain output types to float tensors.")
         .TypeAndShapeInferenceFunction([](InferenceContext& ctx) {
-          propagateElemTypeFromAttributeToOutput(ctx, "dtype", 0);
+          propagateElemTypeFromAttributeToOutput(ctx, "dtype", 0, TensorProto::FLOAT);
           propagateShapeFromAttributeToOutput(ctx, "shape", 0);
         }));
 
@@ -483,16 +394,8 @@ ONNX_OPERATOR_SET_SCHEMA(
     1,
     OpSchema()
         .SetDoc(RandomUniformLike_ver1_doc)
-        .Attr(
-            "low",
-            "Lower boundary of the output values.",
-            AttributeProto::FLOAT,
-            0.0f)
-        .Attr(
-            "high",
-            "Upper boundary of the output values.",
-            AttributeProto::FLOAT,
-            1.0f)
+        .Attr("low", "Lower boundary of the output values.", AttributeProto::FLOAT, 0.0f)
+        .Attr("high", "Upper boundary of the output values.", AttributeProto::FLOAT, 1.0f)
         .Attr(
             "seed",
             "(Optional) Seed to the random generator, if not specified we will auto generate one.",
@@ -504,16 +407,8 @@ ONNX_OPERATOR_SET_SCHEMA(
             "the data type of the input tensor.",
             AttributeProto::INT,
             OPTIONAL_VALUE)
-        .Input(
-            0,
-            "input",
-            "Input tensor to copy shape and optionally type information from.",
-            "T1")
-        .Output(
-            0,
-            "output",
-            "Output tensor of random values drawn from uniform distribution",
-            "T2")
+        .Input(0, "input", "Input tensor to copy shape and optionally type information from.", "T1")
+        .Output(0, "output", "Output tensor of random values drawn from uniform distribution", "T2")
         .TypeConstraint(
             "T1",
             OpSchema::all_tensor_types(),
@@ -548,16 +443,8 @@ ONNX_OPERATOR_SET_SCHEMA(
     1,
     OpSchema()
         .SetDoc(RandomNormalLike_ver1_doc)
-        .Attr(
-            "mean",
-            "The mean of the normal distribution.",
-            AttributeProto::FLOAT,
-            0.0f)
-        .Attr(
-            "scale",
-            "The standard deviation of the normal distribution.",
-            AttributeProto::FLOAT,
-            1.0f)
+        .Attr("mean", "The mean of the normal distribution.", AttributeProto::FLOAT, 0.0f)
+        .Attr("scale", "The standard deviation of the normal distribution.", AttributeProto::FLOAT, 1.0f)
         .Attr(
             "seed",
             "(Optional) Seed to the random generator, if not specified we will auto generate one.",
@@ -569,16 +456,8 @@ ONNX_OPERATOR_SET_SCHEMA(
             "the data type of the input tensor.",
             AttributeProto::INT,
             OPTIONAL_VALUE)
-        .Input(
-            0,
-            "input",
-            "Input tensor to copy shape and optionally type information from.",
-            "T1")
-        .Output(
-            0,
-            "output",
-            "Output tensor of random values drawn from normal distribution",
-            "T2")
+        .Input(0, "input", "Input tensor to copy shape and optionally type information from.", "T1")
+        .Output(0, "output", "Output tensor of random values drawn from normal distribution", "T2")
         .TypeConstraint(
             "T1",
             OpSchema::all_tensor_types(),
@@ -608,11 +487,7 @@ ONNX_OPERATOR_SET_SCHEMA(
     7,
     OpSchema()
         .SetDoc(Multinomial_ver7_doc)
-        .Attr(
-            "sample_size",
-            "Number of times to sample.",
-            AttributeProto::INT,
-            static_cast<int64_t>(1))
+        .Attr("sample_size", "Number of times to sample.", AttributeProto::INT, static_cast<int64_t>(1))
         .Attr(
             "seed",
             "(Optional) Seed to the random generator, if not specified we will auto generate one.",
@@ -637,26 +512,25 @@ ONNX_OPERATOR_SET_SCHEMA(
             "T1",
             {"tensor(float16)", "tensor(float)", "tensor(double)"},
             "Constrain input types to float tensors.")
-        .TypeConstraint(
-            "T2",
-            {"tensor(int32)", "tensor(int64)"},
-            "Constrain output types to integral tensors.")
+        .TypeConstraint("T2", {"tensor(int32)", "tensor(int64)"}, "Constrain output types to integral tensors.")
         .TypeAndShapeInferenceFunction([](InferenceContext& ctx) {
           auto dtype = ctx.getAttribute("dtype");
           auto dataType = TensorProto_DataType::TensorProto_DataType_INT32;
           if (dtype != nullptr) {
             dataType = static_cast<TensorProto_DataType>(dtype->i());
             if (dataType != TensorProto_DataType::TensorProto_DataType_INT32 &&
-                dataType != TensorProto_DataType::TensorProto_DataType_INT64)
+                dataType != TensorProto_DataType::TensorProto_DataType_INT64) {
               fail_type_inference("Output type must be int32 or int64");
+            }
           }
           updateOutputElemType(ctx, 0, dataType);
 
           TensorShapeProto::Dimension batch_size, sample_size;
           if (hasInputShape(ctx, 0)) {
             auto& input_shape = getInputShape(ctx, 0);
-            if (input_shape.dim_size() != 2)
+            if (input_shape.dim_size() != 2) {
               fail_shape_inference("Input tensor must have rank 2");
+            }
             batch_size = input_shape.dim(0);
           } // else statically-unknown batch-size
           sample_size.set_dim_value(getAttribute(ctx, "sample_size", 1));
@@ -692,22 +566,17 @@ Output: [10, 8, 6]
 )DOC";
 
 template <typename T>
-inline int64_t compute_output_dim_for_range(
-    const TensorProto* start,
-    const TensorProto* limit,
-    const TensorProto* delta) {
-  if (start->dims().size() != 0 || limit->dims().size() != 0 ||
-      delta->dims().size() != 0) {
-    fail_shape_inference(
-        "Input to 'Range' op should be scalars (Tensor with only one element and shape empty)");
+inline int64_t
+compute_output_dim_for_range(const TensorProto* start, const TensorProto* limit, const TensorProto* delta) {
+  if (start->dims().size() != 0 || limit->dims().size() != 0 || delta->dims().size() != 0) {
+    fail_shape_inference("Input to 'Range' op should be scalars (Tensor with only one element and shape empty)");
   }
 
   const auto& start_data = ParseData<T>(start);
   const auto& limit_data = ParseData<T>(limit);
   const auto& delta_data = ParseData<T>(delta);
 
-  int64_t n = static_cast<int64_t>(
-      ceil((1.0 * (limit_data[0] - start_data[0])) / delta_data[0]));
+  int64_t n = static_cast<int64_t>(ceil((1.0 * (limit_data[0] - start_data[0])) / delta_data[0]));
 
   if (n < 0)
     n = 0;
@@ -715,127 +584,37 @@ inline int64_t compute_output_dim_for_range(
   return n;
 }
 
-const std::vector<NodeProto> build_nodes_range_op() {
-  // body for 'Loop node'
-  GraphProto loop_sub_graph;
-  loop_sub_graph.set_name("loop_body_attribute");
-
-  // 'Loop' node 'body' attribute's graph inputs
-  // input 0 - number of iteration
-  auto* input_value_info_proto_0 = loop_sub_graph.add_input();
-  input_value_info_proto_0->set_name("i");
-  // add an empty shape
-  auto* input_0_type_proto_tensor =
-      input_value_info_proto_0->mutable_type()->mutable_tensor_type();
-  input_0_type_proto_tensor->mutable_shape()->Clear();
-  // always INT64 type
-  input_0_type_proto_tensor->set_elem_type(TensorProto_DataType_INT64);
-
-  // input 1 - condition
-  auto* input_value_info_proto_1 = loop_sub_graph.add_input();
-  input_value_info_proto_1->set_name("cond");
-  // add an empty shape
-  auto* input_1_type_proto_tensor =
-      input_value_info_proto_1->mutable_type()->mutable_tensor_type();
-  input_1_type_proto_tensor->mutable_shape()->Clear();
-  // always BOOL type
-  input_1_type_proto_tensor->set_elem_type(TensorProto_DataType_BOOL);
-
-  // input 2 - loop carried dependency
-  auto* input_value_info_proto_2 = loop_sub_graph.add_input();
-  input_value_info_proto_2->set_name("prev");
-
-  // 'Loop' node 'body' attribute's graph nodes
-  auto* node_proto_0 = loop_sub_graph.add_node();
-  node_proto_0->set_op_type("Identity");
-  node_proto_0->add_input();
-  node_proto_0->set_input(0, "cond");
-  node_proto_0->add_output();
-  node_proto_0->set_output(0, "cond_out");
-
-  auto* node_proto_1 = loop_sub_graph.add_node();
-  node_proto_1->set_op_type("Add");
-  node_proto_1->add_input();
-  node_proto_1->set_input(0, "prev");
-  node_proto_1->add_input();
-  node_proto_1->set_input(1, "delta");
-  node_proto_1->add_output();
-  node_proto_1->set_output(0, "current");
-
-  auto* node_proto_2 = loop_sub_graph.add_node();
-  node_proto_2->set_op_type("Identity");
-  node_proto_2->add_input();
-  node_proto_2->set_input(0, "prev");
-  node_proto_2->add_output();
-  node_proto_2->set_output(0, "range");
-
-  // 'Loop' node 'body' attribute's graph inputs
-  auto* output_value_info_proto_0 = loop_sub_graph.add_output();
-  output_value_info_proto_0->set_name("cond_out");
-
-  auto* output_value_info_proto_1 = loop_sub_graph.add_output();
-  output_value_info_proto_1->set_name("current");
-
-  auto* output_value_info_proto_2 = loop_sub_graph.add_output();
-  output_value_info_proto_2->set_name("range");
-
-  return FunctionBodyHelper::BuildNodes(
-      {// nodes: {outputs, op, inputs, attributes}
-       {{"sub_result"}, "Sub", {"limit", "start"}},
-       {{"sub_result_casted"},
-        "Cast",
-        {"sub_result"},
-        {{"to", static_cast<int64_t>(1)}}},
-       {{"delta_casted"}, "Cast", {"delta"}, {{"to", static_cast<int64_t>(1)}}},
-       {{"div_result"}, "Div", {"sub_result_casted", "delta_casted"}},
-       {{"ceil_result"}, "Ceil", {"div_result"}},
-       // we want max(0, ceil_cast_int) as negative values would evaluate to
-       // bool true in next step
-       {{"ceil_result_relu"}, "Relu", {"ceil_result"}},
-       {{"ceil_result_relu_int"},
-        "Cast",
-        {"ceil_result_relu"},
-        {{"to", static_cast<int64_t>(7)}}},
-       {{"ceil_result_relu_bool"},
-        "Cast",
-        {"ceil_result_relu"},
-        {{"to", static_cast<int64_t>(9)}}},
-       {{"variadic_output", "output"},
-        "Loop",
-        {"ceil_result_relu_int", "ceil_result_relu_bool", "start"},
-        {MakeAttribute("body", loop_sub_graph)}}});
-}
-
 ONNX_OPERATOR_SET_SCHEMA(
     Range,
     11,
     OpSchema()
         .SetDoc(Range_ver11_doc)
-        .Input(
-            0,
-            "start",
-            "Scalar. First entry for the range of output values.",
-            "T")
-        .Input(
-            1,
-            "limit",
-            "Scalar. Exclusive upper limit for the range of output values.",
-            "T")
+        .Input(0, "start", "Scalar. First entry for the range of output values.", "T")
+        .Input(1, "limit", "Scalar. Exclusive upper limit for the range of output values.", "T")
         .Input(2, "delta", "Scalar. Value to step by.", "T")
-        .Output(
-            0,
-            "output",
-            "A 1-D tensor with same type as the inputs containing generated range of values.",
-            "T")
+        .Output(0, "output", "A 1-D tensor with same type as the inputs containing generated range of values.", "T")
         .TypeConstraint(
             "T",
-            {"tensor(float)",
-             "tensor(double)",
-             "tensor(int16)",
-             "tensor(int32)",
-             "tensor(int64)"},
+            {"tensor(float)", "tensor(double)", "tensor(int16)", "tensor(int32)", "tensor(int64)"},
             "Constrain input types to common numeric type tensors.")
-        .FunctionBody(build_nodes_range_op())
+        .FunctionBody(R"ONNX(
+          {
+            sub_result = Sub (limit, start)
+            sub_result_casted = Cast <to = 1> (sub_result)
+            delta_casted = Cast <to = 1> (delta)
+            div_result = Div (sub_result_casted, delta_casted)
+            ceil_result = Ceil (div_result)
+            ceil_result_relu = Relu (ceil_result)
+            ceil_result_relu_int = Cast <to = 7> (ceil_result_relu)
+            ceil_result_relu_bool = Cast <to = 9> (ceil_result_relu)
+            variadic_output, output = Loop (ceil_result_relu_int, ceil_result_relu_bool, start)
+              <body = loop_body_attribute (int64 i, bool cond, prev) => (cond_out, current, range) {
+                cond_out = Identity (cond)
+                current = Add (prev, delta)
+                range = Identity (prev)
+              }>
+          }
+        )ONNX")
         .TypeAndShapeInferenceFunction([](InferenceContext& ctx) {
           // Type inference
           propagateElemTypeFromInputToOutput(ctx, 0, 0);
@@ -846,38 +625,31 @@ ONNX_OPERATOR_SET_SCHEMA(
           const auto* delta_initializer = ctx.getInputData(2);
 
           // Output is always 1-D
-          auto* output_dim = ctx.getOutputType(0)
-                                 ->mutable_tensor_type()
-                                 ->mutable_shape()
-                                 ->add_dim();
+          auto* output_dim = ctx.getOutputType(0)->mutable_tensor_type()->mutable_shape()->add_dim();
 
           // If any of Range's inputs are not initializers, the output dimension
           // value would remain unknown.
-          if (start_initializer != nullptr && limit_initializer != nullptr &&
-              delta_initializer != nullptr) {
+          if (start_initializer != nullptr && limit_initializer != nullptr && delta_initializer != nullptr) {
             // Make sure the input types are homogeneous
-            if ((start_initializer->data_type() !=
-                 limit_initializer->data_type()) ||
-                (start_initializer->data_type() !=
-                 delta_initializer->data_type())) {
-              fail_shape_inference(
-                  "All inputs to 'Range' op must be of the same type");
+            if ((start_initializer->data_type() != limit_initializer->data_type()) ||
+                (start_initializer->data_type() != delta_initializer->data_type())) {
+              fail_shape_inference("All inputs to 'Range' op must be of the same type");
             }
 
             // Explicitly compute the output dimension if Range's inputs are
             // stored in initializer list.
             if (start_initializer->data_type() == TensorProto::FLOAT) {
-              output_dim->set_dim_value(compute_output_dim_for_range<float>(
-                  start_initializer, limit_initializer, delta_initializer));
+              output_dim->set_dim_value(
+                  compute_output_dim_for_range<float>(start_initializer, limit_initializer, delta_initializer));
             } else if (start_initializer->data_type() == TensorProto::INT32) {
-              output_dim->set_dim_value(compute_output_dim_for_range<int32_t>(
-                  start_initializer, limit_initializer, delta_initializer));
+              output_dim->set_dim_value(
+                  compute_output_dim_for_range<int32_t>(start_initializer, limit_initializer, delta_initializer));
             } else if (start_initializer->data_type() == TensorProto::INT64) {
-              output_dim->set_dim_value(compute_output_dim_for_range<int64_t>(
-                  start_initializer, limit_initializer, delta_initializer));
+              output_dim->set_dim_value(
+                  compute_output_dim_for_range<int64_t>(start_initializer, limit_initializer, delta_initializer));
             } else if (start_initializer->data_type() == TensorProto::DOUBLE) {
-              output_dim->set_dim_value(compute_output_dim_for_range<double>(
-                  start_initializer, limit_initializer, delta_initializer));
+              output_dim->set_dim_value(
+                  compute_output_dim_for_range<double>(start_initializer, limit_initializer, delta_initializer));
             } else {
               // 'float16' has no native CPU type -
               // stop with rank inference, no action here
@@ -887,4 +659,82 @@ ONNX_OPERATOR_SET_SCHEMA(
           }
         }));
 
+static const char* Bernoulli_ver15_doc = R"DOC(
+Draws binary random numbers (0 or 1) from a Bernoulli distribution. The input tensor should be a tensor
+containing probabilities p (a value in the range [0,1]) to be used for drawing the binary random number,
+where an output of 1 is produced with probability p and an output of 0 is produced with probability (1-p).
+
+This operator is non-deterministic and may not produce the same values in different
+implementations (even if a seed is specified).
+)DOC";
+
+ONNX_OPERATOR_SET_SCHEMA(
+    Bernoulli,
+    15,
+    OpSchema()
+        .SetDoc(Bernoulli_ver15_doc)
+        .Attr(
+            "seed",
+            "(Optional) Seed to the random generator, if not specified we will auto generate one.",
+            AttributeProto::FLOAT,
+            OPTIONAL_VALUE)
+        .Attr(
+            "dtype",
+            "The data type for the elements of the output tensor. if not specified, we will use "
+            "the data type of the input tensor.",
+            AttributeProto::INT,
+            OPTIONAL_VALUE)
+        .Input(0, "input", "All values in input have to be in the range:[0, 1].", "T1")
+        .Output(0, "output", "The returned output tensor only has values 0 or 1, same shape as input tensor.", "T2")
+        .TypeConstraint(
+            "T1",
+            {"tensor(float16)", "tensor(float)", "tensor(double)"},
+            "Constrain input types to float tensors.")
+        .TypeConstraint(
+            "T2",
+            {"tensor(float16)",
+             "tensor(float)",
+             "tensor(double)",
+             "tensor(bfloat16)",
+             "tensor(uint8)",
+             "tensor(uint16)",
+             "tensor(uint32)",
+             "tensor(uint64)",
+             "tensor(int8)",
+             "tensor(int16)",
+             "tensor(int32)",
+             "tensor(int64)",
+             "tensor(bool)"},
+            "Constrain output types to all numeric tensors and bool tensors.")
+        .TypeAndShapeInferenceFunction([](ONNX_NAMESPACE::InferenceContext& ctx) {
+          if (ctx.getAttribute("dtype") != nullptr)
+            propagateElemTypeFromAttributeToOutput(ctx, "dtype", 0);
+          else
+            propagateElemTypeFromInputToOutput(ctx, 0, 0);
+          if (!hasNInputShapes(ctx, 1)) {
+            return;
+          }
+          propagateShapeFromInputToOutput(ctx, 0, 0);
+        })
+        .SetContextDependentFunctionBodyBuilder(
+            [](const FunctionBodyBuildContext& ctx, const OpSchema& schema, FunctionProto& functionProto) -> bool {
+              if (ctx.getInputType(0) == nullptr) {
+                // we cannot create a correct function body without knowing the input type
+                return false;
+              }
+              auto input_type = ctx.getInputType(0)->tensor_type().elem_type();
+              auto dtype = ctx.getAttribute("dtype") != nullptr
+                  ? static_cast<TensorProto_DataType>(ctx.getAttribute("dtype")->i())
+                  : input_type;
+              FunctionBuilder builder(functionProto);
+              builder
+                  .Add(
+                      "X_random = RandomUniformLike <low = 0.0, high = 1.0, seed = @seed> (input)",
+                      "dtype",
+                      int64_t(input_type))
+                  .Add("X_greater = Greater (X_random, input)")
+                  .Add("output = Cast (X_greater)", "to", int64_t(dtype));
+              schema.BuildFunction(functionProto);
+              return true;
+            }));
 } // namespace ONNX_NAMESPACE
