@@ -1,13 +1,14 @@
-// Copyright (c) ONNX Project Contributors.
-// Licensed under the MIT license.
+/*
+ * SPDX-License-Identifier: Apache-2.0
+ */
 
 #include "onnx/defs/schema.h"
 #include <stdexcept>
 #include <unordered_set>
 #include "onnx/checker.h"
 #include "onnx/defs/operator_sets.h"
-#include "onnx/defs/operator_sets_training.h"
 #include "onnx/defs/operator_sets_preview.h"
+#include "onnx/defs/operator_sets_training.h"
 
 #ifdef ONNX_ML
 #include "onnx/defs/operator_sets_ml.h"
@@ -15,11 +16,18 @@
 
 #include "onnx/common/assertions.h"
 #include "onnx/common/stl_backports.h"
+#include "onnx/defs/parser.h"
 
 namespace ONNX_NAMESPACE {
+// -1 means ONNX schema hasn't been loaded yet
+// 0 means all versions of ONNX schema have been loaded
+// Other positive integer means the ONNX schemas for the specified version have been loaded
+int OpSchemaRegistry::loaded_schema_version = -1;
 
-void RegisterSchema(OpSchema&& schema) {
-  OpSchemaRegistry::OpSchemaRegisterOnce ONNX_UNUSED registration = schema;
+// By default if opset_version_to_load=0, it registers all opset schema for all opset versions
+// Otherwise, it only registers the latest schema according to opset_version_to_load
+void RegisterSchema(OpSchema schema, int opset_version_to_load) {
+  OpSchemaRegistry::OpSchemaRegisterOnce ONNX_UNUSED registration(schema, opset_version_to_load);
 }
 
 #ifndef NDEBUG
@@ -61,6 +69,10 @@ int OpSchema::FormalParameter::GetMinArity() const {
   return min_arity_;
 }
 
+OpSchema::DifferentiationCategory OpSchema::FormalParameter::GetDifferentiationCategory() const {
+  return differentiation_category_;
+}
+
 OpSchemaRegistry* OpSchemaRegistry::Instance() {
   static OpSchemaRegistry instance;
   return &instance;
@@ -69,20 +81,14 @@ OpSchemaRegistry* OpSchemaRegistry::Instance() {
 void OpSchema::CheckInputOutputType(struct InferenceContext& ctx) const {
   std::unordered_map<std::string, std::string> type_constraints;
   // check all input types
-  for (size_t in_idx = 0;
-       in_idx < ctx.getNumInputs() && in_idx < inputs_.size();
-       ++in_idx) {
+  for (size_t in_idx = 0; in_idx < ctx.getNumInputs() && in_idx < inputs_.size(); ++in_idx) {
     const auto& param = inputs_[in_idx];
     const auto& type_str = param.GetTypeStr();
     const auto& param_type = ctx.getInputType(in_idx);
     const auto& all_types = param.GetTypes();
-    if (nullptr == param_type ||
-        param_type->value_case() == TypeProto::VALUE_NOT_SET) {
+    if (nullptr == param_type || param_type->value_case() == TypeProto::VALUE_NOT_SET) {
       continue;
-    } else if (
-        !all_types.empty() &&
-        all_types.find(Utils::DataTypeUtils::ToType(*param_type)) ==
-            all_types.end()) {
+    } else if (!all_types.empty() && all_types.find(Utils::DataTypeUtils::ToType(*param_type)) == all_types.end()) {
       fail_check(
           param.GetName(),
           " typestr: ",
@@ -92,20 +98,17 @@ void OpSchema::CheckInputOutputType(struct InferenceContext& ctx) const {
     }
     if (param.GetIsHomogeneous()) {
       const auto& type_proto = Utils::DataTypeUtils::ToType(*param_type);
-      if (type_constraints.find(type_str) == type_constraints.end()) {
-        type_constraints[type_str] = *type_proto;
-      } else if (type_constraints[type_str] != *type_proto) {
-        fail_check(
-            param.GetName(),
-            " has inconsistent type ",
-            *Utils::DataTypeUtils::ToType(*param_type));
+      auto p = type_constraints.emplace(type_str, *type_proto);
+      if (!p.second) {
+        // failed to insert a new element due to a duplication, now check consistency
+        if (p.first->second != *type_proto) {
+          fail_check(param.GetName(), " has inconsistent type ", *Utils::DataTypeUtils::ToType(*param_type));
+        }
       }
     }
   } // for inputs
   // check all output types
-  for (size_t out_idx = 0;
-       out_idx < ctx.getNumOutputs() && out_idx < outputs_.size();
-       ++out_idx) {
+  for (size_t out_idx = 0; out_idx < ctx.getNumOutputs() && out_idx < outputs_.size(); ++out_idx) {
     const auto& param = outputs_[out_idx];
     const auto& type_str = param.GetTypeStr();
     const auto& param_type = ctx.getOutputType(out_idx);
@@ -116,8 +119,7 @@ void OpSchema::CheckInputOutputType(struct InferenceContext& ctx) const {
       if (all_types.size() == 1) {
         *param_type = Utils::DataTypeUtils::ToTypeProto(*all_types.begin());
       } else if (type_constraints.find(type_str) != type_constraints.end()) {
-        auto data_type =
-            Utils::DataTypeUtils::ToType(type_constraints[type_str]);
+        auto data_type = Utils::DataTypeUtils::ToType(type_constraints[type_str]);
         *param_type = Utils::DataTypeUtils::ToTypeProto(data_type);
       } else {
         output_type_found = false;
@@ -126,23 +128,15 @@ void OpSchema::CheckInputOutputType(struct InferenceContext& ctx) const {
     if (!output_type_found) {
       continue;
     }
-    if (!all_types.empty() &&
-        all_types.find(Utils::DataTypeUtils::ToType(*param_type)) ==
-            all_types.end()) {
-      fail_check(
-          param.GetName(),
-          " has unsupported type ",
-          *Utils::DataTypeUtils::ToType(*param_type));
+    if (!all_types.empty() && all_types.find(Utils::DataTypeUtils::ToType(*param_type)) == all_types.end()) {
+      fail_check(param.GetName(), " has unsupported type ", *Utils::DataTypeUtils::ToType(*param_type));
     }
     if (param.GetIsHomogeneous()) {
       const auto& type_proto = Utils::DataTypeUtils::ToType(*param_type);
       if (type_constraints.find(type_str) == type_constraints.end()) {
         type_constraints[type_str] = *type_proto;
       } else if (type_constraints[type_str] != *type_proto) {
-        fail_check(
-            param.GetName(),
-            " has inconsistent type ",
-            *Utils::DataTypeUtils::ToType(*param_type));
+        fail_check(param.GetName(), " has inconsistent type ", *Utils::DataTypeUtils::ToType(*param_type));
       }
     } // else
   } // for outputs
@@ -150,11 +144,7 @@ void OpSchema::CheckInputOutputType(struct InferenceContext& ctx) const {
 
 void OpSchema::Verify(const NodeProto& node) const {
   if (deprecated_) {
-    fail_check(
-        "Operator '",
-        name_,
-        "' has been deprecated since version ",
-        since_version_);
+    fail_check("Operator '", name_, "' has been deprecated since version ", since_version_);
   }
 
   // Check the number of inputs.
@@ -172,12 +162,7 @@ void OpSchema::Verify(const NodeProto& node) const {
   }
 
   if (!num_inputs_allowed_(node.input_size())) {
-    fail_check(
-        "Node (",
-        node.name(),
-        ") has input size ",
-        node.input_size(),
-        " not in allowed input sizes.");
+    fail_check("Node (", node.name(), ") has input size ", node.input_size(), " not in allowed input sizes.");
   }
 
   // Check the number of outputs.
@@ -195,18 +180,13 @@ void OpSchema::Verify(const NodeProto& node) const {
   }
 
   if (!num_outputs_allowed_(node.output_size())) {
-    fail_check(
-        "Node (",
-        node.name(),
-        "has output size ",
-        node.output_size(),
-        " not in allowed output sizes.");
+    fail_check("Node (", node.name(), "has output size ", node.output_size(), " not in allowed output sizes.");
   }
 
   // Check the values of inputs / outputs
   for (int in_idx = 0; in_idx < node.input_size(); ++in_idx) {
     if (in_idx >= static_cast<int>(inputs_.size())) {
-      if (inputs_.size() > 0 && Variadic == inputs_.back().GetOption()) {
+      if (!inputs_.empty() && Variadic == inputs_.back().GetOption()) {
         // The last input formal parameter should be variadic.
         break;
       } else {
@@ -221,18 +201,13 @@ void OpSchema::Verify(const NodeProto& node) const {
       }
     }
     if (node.input(in_idx).empty() && (Single == inputs_[in_idx].GetOption())) {
-      fail_check(
-          "Node (",
-          node.name(),
-          ")'s input ",
-          in_idx,
-          " is marked single but has an empty string in the graph");
+      fail_check("Node (", node.name(), ")'s input ", in_idx, " is marked single but has an empty string in the graph");
     }
   }
 
   for (int out_idx = 0; out_idx < node.output_size(); ++out_idx) {
     if (out_idx >= static_cast<int>(outputs_.size())) {
-      if (outputs_.size() > 0 && Variadic == outputs_.back().GetOption()) {
+      if (!outputs_.empty() && Variadic == outputs_.back().GetOption()) {
         // The last output formal parameter should be variadic.
         break;
       } else {
@@ -247,14 +222,9 @@ void OpSchema::Verify(const NodeProto& node) const {
       }
     }
 
-    if (node.output(out_idx).empty() &&
-        (Single == outputs_[out_idx].GetOption())) {
+    if (node.output(out_idx).empty() && (Single == outputs_[out_idx].GetOption())) {
       fail_check(
-          "Node (",
-          node.name(),
-          ")'s output ",
-          out_idx,
-          " is marked single but has an empty string in the graph");
+          "Node (", node.name(), ")'s output ", out_idx, " is marked single but has an empty string in the graph");
     }
   }
 
@@ -281,14 +251,12 @@ void OpSchema::Verify(const NodeProto& node) const {
     } else if (allows_unchecked_attributes_ || isInternalSymbol(name)) {
       continue;
     } else {
-      fail_check(
-          "Unrecognized attribute: ", name, " for operator ", node.op_type());
+      fail_check("Unrecognized attribute: ", name, " for operator ", node.op_type());
     }
 
     // Type would be UNDEFINED if not set
     if (attr_proto.type() != expected_type) {
-      fail_check(
-          "Mismatched attribute type in '", node.name() + " : " + name, "'");
+      fail_check("Mismatched attribute type in '", node.name() + " : " + name, "'");
     }
 
     // ref_attr_name is only valid when non-empty
@@ -313,10 +281,7 @@ void OpSchema::Verify(const NodeProto& node) const {
         break;
       case AttributeProto::SPARSE_TENSOR:
         if (!attr_proto.has_sparse_tensor()) {
-          fail_check(
-              "Attribute '",
-              name,
-              "' is expected to have field 'sparse_tensor'");
+          fail_check("Attribute '", name, "' is expected to have field 'sparse_tensor'");
         }
         break;
       case AttributeProto::GRAPH:
@@ -324,10 +289,14 @@ void OpSchema::Verify(const NodeProto& node) const {
           fail_check("Attribute '", name, "' is expected to have field 'g'");
         }
         break;
+      case AttributeProto::TYPE_PROTO:
+        if (!attr_proto.has_tp()) {
+          fail_check("Attribute '", name, "' is expected to have field 'type_proto'");
+        }
+        break;
       case AttributeProto::FLOATS:
         if (!attr_proto.floats_size()) {
-          fail_check(
-              "Attribute '", name, "' is expected to have field 'floats'");
+          fail_check("Attribute '", name, "' is expected to have field 'floats'");
         }
         break;
       case AttributeProto::INTS:
@@ -337,14 +306,12 @@ void OpSchema::Verify(const NodeProto& node) const {
         break;
       case AttributeProto::STRINGS:
         if (!attr_proto.strings_size()) {
-          fail_check(
-              "Attribute '", name, "' is expected to have field 'strings'");
+          fail_check("Attribute '", name, "' is expected to have field 'strings'");
         }
         break;
       case AttributeProto::TENSORS:
         if (!attr_proto.tensors_size()) {
-          fail_check(
-              "Attribute '", name, "' is expected to have field 'tensors'");
+          fail_check("Attribute '", name, "' is expected to have field 'tensors'");
         }
         break;
       case AttributeProto::SPARSE_TENSORS:
@@ -354,8 +321,12 @@ void OpSchema::Verify(const NodeProto& node) const {
         break;
       case AttributeProto::GRAPHS:
         if (!attr_proto.graphs_size()) {
-          fail_check(
-              "Attribute '", name, "' is expected to have field 'graphs'");
+          fail_check("Attribute '", name, "' is expected to have field 'graphs'");
+        }
+        break;
+      case AttributeProto::TYPE_PROTOS:
+        if (!attr_proto.type_protos_size()) {
+          fail_check("Attribute '", name, "' is expected to have field 'type_protos'");
         }
         break;
       default:
@@ -386,24 +357,26 @@ OpSchema& OpSchema::Deprecate() {
 }
 
 OpSchema& OpSchema::NumInputs(std::set<int> allowed_input_nums) {
-  num_inputs_allowed_ =
-      [MOVE_CAPTURE_IF_CPP14(allowed_input_nums)](int n) -> bool {
+  num_inputs_allowed_ = [MOVE_CAPTURE_IF_CPP14(allowed_input_nums)](int n) -> bool {
     return allowed_input_nums.count(n);
   };
   return *this;
 }
 
 OpSchema& OpSchema::NumOutputs(std::set<int> allowed_output_nums) {
-  num_outputs_allowed_ =
-      [MOVE_CAPTURE_IF_CPP14(allowed_output_nums)](int n) -> bool {
-    return allowed_output_nums.count(n);
+  num_outputs_allowed_ = [MOVE_CAPTURE_IF_CPP14(allowed_output_nums)](int n) -> bool {
+    return allowed_output_nums.count(n) > 0;
   };
   return *this;
 }
 
-OpSchema& OpSchema::TypeAndShapeInferenceFunction(
-    InferenceFunction inferenceFunction) {
-  tensor_inference_function_ = inferenceFunction;
+OpSchema& OpSchema::TypeAndShapeInferenceFunction(InferenceFunction inferenceFunction) {
+  tensor_inference_function_ = std::move(inferenceFunction);
+  return *this;
+}
+
+OpSchema& OpSchema::PartialDataPropagationFunction(DataPropagationFunction dataPropagationFunction) {
+  data_propagation_function_ = std::move(dataPropagationFunction);
   return *this;
 }
 
@@ -448,49 +421,31 @@ OpSchema& OpSchema::Attr(Attribute attr) {
   return *this;
 }
 
-OpSchema& OpSchema::Attr(
-    std::string name,
-    std::string description,
-    AttributeProto::AttributeType type,
-    bool required) {
+OpSchema& OpSchema::Attr(std::string name, std::string description, AttributeProto::AttributeType type, bool required) {
   Attr(Attribute{std::move(name), std::move(description), type, required});
   return *this;
 }
 
-OpSchema& OpSchema::Attr(
-    const char* name,
-    const char* description,
-    AttributeProto::AttributeType type,
-    bool required) {
+OpSchema& OpSchema::Attr(const char* name, const char* description, AttributeProto::AttributeType type, bool required) {
   return Attr(std::string(name), std::string(description), type, required);
 }
 
-#define ATTR_SETTER_WITH_SINGLE_VALUE(type, field, attrtype)                \
-  OpSchema& OpSchema::Attr(                                                 \
-      std::string name,                                                     \
-      std::string description,                                              \
-      AttributeProto::AttributeType attr_type,                              \
-      const type& default_value) {                                          \
-    if (attrtype != attr_type) {                                            \
-      fail_schema("Attribute specification type mismatch.");                \
-    }                                                                       \
-    AttributeProto a;                                                       \
-    a.set_name(name);                                                       \
-    a.set_##field(default_value);                                           \
-    a.set_type(attr_type);                                                  \
-    Attr(Attribute(std::move(name), std::move(description), std::move(a))); \
-    return *this;                                                           \
-  }                                                                         \
-  OpSchema& OpSchema::Attr(                                                 \
-      const char* name,                                                     \
-      const char* description,                                              \
-      AttributeProto::AttributeType attr_type,                              \
-      const type& default_value) {                                          \
-    return Attr(                                                            \
-        std::string(name),                                                  \
-        std::string(description),                                           \
-        attr_type,                                                          \
-        default_value);                                                     \
+#define ATTR_SETTER_WITH_SINGLE_VALUE(type, field, attrtype)                                                           \
+  OpSchema& OpSchema::Attr(                                                                                            \
+      std::string name, std::string description, AttributeProto::AttributeType attr_type, const type& default_value) { \
+    if (attrtype != attr_type) {                                                                                       \
+      fail_schema("Attribute specification type mismatch.");                                                           \
+    }                                                                                                                  \
+    AttributeProto a;                                                                                                  \
+    a.set_name(name);                                                                                                  \
+    a.set_##field(default_value);                                                                                      \
+    a.set_type(attr_type);                                                                                             \
+    Attr(Attribute(std::move(name), std::move(description), std::move(a)));                                            \
+    return *this;                                                                                                      \
+  }                                                                                                                    \
+  OpSchema& OpSchema::Attr(                                                                                            \
+      const char* name, const char* description, AttributeProto::AttributeType attr_type, const type& default_value) { \
+    return Attr(std::string(name), std::string(description), attr_type, default_value);                                \
   }
 
 #define ATTR_SETTER_WITH_LIST_VALUE(type, field, attrtype)                  \
@@ -512,21 +467,18 @@ OpSchema& OpSchema::Attr(
     return *this;                                                           \
   }
 
-#define ATTR_SETTER_WITH_SINGLE_COMPLEXVALUE(type, field, attrtype) \
-  OpSchema& OpSchema::Attr(                                         \
-      std::string name,                                             \
-      std::string description,                                      \
-      AttributeProto::AttributeType attr_type,                      \
-      const type& default_value) {                                  \
-    if (attrtype != attr_type) {                                    \
-      fail_schema("Attribute specification type mismatch.");        \
-    }                                                               \
-    AttributeProto a;                                               \
-    a.set_name(name);                                               \
-    *(a.mutable_##field()) = default_value;                         \
-    a.set_type(attr_type);                                          \
-    Attr(Attribute(std::move(name), std::move(description), a));    \
-    return *this;                                                   \
+#define ATTR_SETTER_WITH_SINGLE_COMPLEXVALUE(type, field, attrtype)                                                    \
+  OpSchema& OpSchema::Attr(                                                                                            \
+      std::string name, std::string description, AttributeProto::AttributeType attr_type, const type& default_value) { \
+    if (attrtype != attr_type) {                                                                                       \
+      fail_schema("Attribute specification type mismatch.");                                                           \
+    }                                                                                                                  \
+    AttributeProto a;                                                                                                  \
+    a.set_name(name);                                                                                                  \
+    *(a.mutable_##field()) = default_value;                                                                            \
+    a.set_type(attr_type);                                                                                             \
+    Attr(Attribute(std::move(name), std::move(description), a));                                                       \
+    return *this;                                                                                                      \
   }
 
 #define ATTR_SETTER_WITH_LIST_COMPLEXVALUE(type, field, attrtype)           \
@@ -553,17 +505,13 @@ ATTR_SETTER_WITH_SINGLE_VALUE(float, f, AttributeProto::FLOAT)
 ATTR_SETTER_WITH_SINGLE_VALUE(std::string, s, AttributeProto::STRING)
 ATTR_SETTER_WITH_SINGLE_COMPLEXVALUE(TensorProto, t, AttributeProto::TENSOR)
 ATTR_SETTER_WITH_SINGLE_COMPLEXVALUE(GraphProto, g, AttributeProto::GRAPH)
+ATTR_SETTER_WITH_SINGLE_COMPLEXVALUE(TypeProto, tp, AttributeProto::TYPE_PROTO)
 ATTR_SETTER_WITH_LIST_VALUE(int64_t, ints, AttributeProto::INTS)
 ATTR_SETTER_WITH_LIST_VALUE(float, floats, AttributeProto::FLOATS)
-ATTR_SETTER_WITH_LIST_COMPLEXVALUE(
-    std::string,
-    strings,
-    AttributeProto::STRINGS)
-ATTR_SETTER_WITH_LIST_COMPLEXVALUE(
-    TensorProto,
-    tensors,
-    AttributeProto::TENSORS)
+ATTR_SETTER_WITH_LIST_COMPLEXVALUE(std::string, strings, AttributeProto::STRINGS)
+ATTR_SETTER_WITH_LIST_COMPLEXVALUE(TensorProto, tensors, AttributeProto::TENSORS)
 ATTR_SETTER_WITH_LIST_COMPLEXVALUE(GraphProto, graphs, AttributeProto::GRAPHS)
+ATTR_SETTER_WITH_LIST_COMPLEXVALUE(TypeProto, type_protos, AttributeProto::TYPE_PROTOS)
 
 OpSchema& OpSchema::AllowUncheckedAttributes() {
   allows_unchecked_attributes_ = true;
@@ -577,7 +525,8 @@ OpSchema& OpSchema::Input(
     std::string type_str,
     OpSchema::FormalParameterOption param_option,
     bool is_homogeneous,
-    int min_arity) {
+    int min_arity,
+    DifferentiationCategory differentiation_category) {
   if (int(inputs_.size()) <= n) {
     inputs_.resize(n + 1);
   }
@@ -591,7 +540,8 @@ OpSchema& OpSchema::Input(
       std::move(type_str),
       param_option,
       is_homogeneous,
-      min_arity);
+      min_arity,
+      differentiation_category);
   return *this;
 }
 
@@ -602,7 +552,8 @@ OpSchema& OpSchema::Input(
     const char* type_str,
     FormalParameterOption param_option,
     bool is_homogeneous,
-    int min_arity) {
+    int min_arity,
+    DifferentiationCategory differentiation_category) {
   return Input(
       n,
       std::string(name),
@@ -614,7 +565,8 @@ OpSchema& OpSchema::Input(
       std::string(type_str),
       param_option,
       is_homogeneous,
-      min_arity);
+      min_arity,
+      differentiation_category);
 }
 
 OpSchema& OpSchema::Output(
@@ -624,7 +576,8 @@ OpSchema& OpSchema::Output(
     std::string type_str,
     OpSchema::FormalParameterOption param_option,
     bool is_homogeneous,
-    int min_arity) {
+    int min_arity,
+    DifferentiationCategory differentiation_category) {
   if (int(outputs_.size()) <= n) {
     outputs_.resize(n + 1);
   }
@@ -638,7 +591,8 @@ OpSchema& OpSchema::Output(
       std::move(type_str),
       param_option,
       is_homogeneous,
-      min_arity);
+      min_arity,
+      differentiation_category);
   return *this;
 }
 
@@ -649,7 +603,8 @@ OpSchema& OpSchema::Output(
     const char* type_str,
     FormalParameterOption param_option,
     bool is_homogeneous,
-    int min_arity) {
+    int min_arity,
+    DifferentiationCategory differentiation_category) {
   return Output(
       n,
       std::string(name),
@@ -661,13 +616,12 @@ OpSchema& OpSchema::Output(
       std::string(type_str),
       param_option,
       is_homogeneous,
-      min_arity);
+      min_arity,
+      differentiation_category);
 }
 
-OpSchema& OpSchema::TypeConstraint(
-    std::string type_str,
-    std::vector<std::string> constraints,
-    std::string description) {
+OpSchema&
+OpSchema::TypeConstraint(std::string type_str, std::vector<std::string> constraints, std::string description) {
   if (type_constraints_.end() != type_constraints_.find(type_str)) {
     fail_schema("Duplicate type constraint name");
   }
@@ -676,10 +630,9 @@ OpSchema& OpSchema::TypeConstraint(
   for (const auto& t : constraints) {
     d.insert(Utils::DataTypeUtils::ToType(t));
   }
-  type_constraints_.insert(
-      std::make_pair(type_str, std::make_pair(d, description)));
-  type_constraint_params_.push_back(TypeConstraintParam(
-      std::move(type_str), std::move(constraints), std::move(description)));
+  type_constraints_.insert(std::make_pair(type_str, std::make_pair(d, description)));
+  type_constraint_params_.push_back(
+      TypeConstraintParam(std::move(type_str), std::move(constraints), std::move(description)));
   return *this;
 }
 
@@ -693,8 +646,7 @@ OpSchema& OpSchema::TypeConstraint(
     constraints_vector.push_back(*iter);
   }
 
-  return TypeConstraint(
-      std::string(type_str), constraints_vector, std::string(description));
+  return TypeConstraint(std::string(type_str), constraints_vector, std::string(description));
 }
 
 void OpSchema::ParseAndSetTypes(
@@ -713,21 +665,28 @@ void OpSchema::ParseAndSetTypes(
   }
 }
 
-OpSchema& OpSchema::SetContextDependentFunctionBodyBuilder(
-    ContextDependentFunctionBodyBuilder functionBuilder) {
-  functionBuilder_ = functionBuilder;
+OpSchema& OpSchema::SetContextDependentFunctionBodyBuilder(ContextDependentFunctionBodyBuilder functionBuilder) {
+  functionBuilder_ = std::move(functionBuilder);
   return *this;
 }
 
-bool OpSchema::BuildContextDependentFunction(
-    const FunctionBodyBuildContext& ctx,
-    FunctionProto& functionProto) const {
+bool OpSchema::BuildContextDependentFunction(const FunctionBodyBuildContext& ctx, FunctionProto& functionProto) const {
   if (functionBuilder_)
     return functionBuilder_(ctx, *this, functionProto);
   else
     return false;
 }
 
+OpSchema& OpSchema::FunctionBody(const char* func_body) {
+  OnnxParser parser(func_body);
+  auto status = parser.Parse(*function_body_.mutable_node());
+  if (!status.IsOK())
+    ONNX_THROW_EX(std::logic_error("Error parsing function body:" + status.ErrorMessage()));
+  if (!parser.EndOfInput())
+    ONNX_THROW_EX(std::logic_error("Extra unparsed input unexpected."));
+  return *this;
+}
+
 OpSchema& OpSchema::FunctionBody(const std::vector<NodeProto>& func_nodes) {
   for (const auto& node : func_nodes) {
     auto new_node = function_body_.add_node();
@@ -760,8 +719,7 @@ OpSchema& OpSchema::FillUsing(const std::function<void(OpSchema&)>& populator) {
 void OpSchema::BuildFunction(FunctionProto& function_body) const {
   function_body.set_name(this->name_);
   function_body.set_doc_string(this->doc_);
-  function_body.set_since_version(this->since_version_);
-  function_body.set_status(OperatorStatus(1 - (int)this->support_));
+  function_body.set_domain(this->domain_);
   for (auto& i : inputs_) {
     function_body.add_input(i.GetName());
   }
@@ -771,19 +729,25 @@ void OpSchema::BuildFunction(FunctionProto& function_body) const {
   for (auto& a : attributes_) {
     function_body.add_attribute(a.first);
   }
-  // By default, the function body graph is relying on the OperatorSet this
-  // function belongs to.
-  auto relied_opset = function_body.mutable_opset_import()->Add();
-  relied_opset->set_domain(this->domain());
-  relied_opset->set_version(this->SinceVersion());
+
+  // In a typical onnx function where the function and all the
+  // ops in function body belong to the same domain we implicitly add
+  // {domain_, since_version_} to funciton opset imports if it is not already added.
+  // This is simply for convienince. If any of the function body ops do not belong to same
+  // domain as function itself, then the function author needs to explicitly add all the relevant
+  // opset imports.
+  if (function_body.opset_import().size() == 0) {
+    auto* schema_opset = function_body.mutable_opset_import()->Add();
+    schema_opset->set_domain(domain_);
+    schema_opset->set_version(since_version_);
+  }
 }
 
 void OpSchema::Finalize() {
-#define ENFORCE(x)                                                          \
-  do {                                                                      \
-    if (!(x))                                                               \
-      throw std::logic_error(                                               \
-          "ONNX Schema " + name_ + ": failed validating the check: " + #x); \
+#define ENFORCE(x)                                                                                      \
+  do {                                                                                                  \
+    if (!(x))                                                                                           \
+      ONNX_THROW_EX(std::logic_error("ONNX Schema " + name_ + ": failed validating the check: " + #x)); \
   } while (0)
 
   // Calculate min/max number of inputs.
@@ -851,8 +815,7 @@ std::ostream& operator<<(std::ostream& out, const OpSchema& schema) {
   if (!schema.attributes_.empty()) {
     out << "Attributes:" << std::endl;
     for (const auto& pair : schema.attributes_) {
-      out << "  " << pair.second.name << " : " << pair.second.description
-          << std::endl;
+      out << "  " << pair.second.name << " : " << pair.second.description << std::endl;
     }
   }
   if (schema.max_input_ > 0) {
@@ -863,9 +826,9 @@ std::ostream& operator<<(std::ostream& out, const OpSchema& schema) {
         const auto& name = p.GetName();
         const auto& description = p.GetDescription();
         const auto& type_str = p.GetTypeStr();
-        out << "  " << i << ", " << ("" != name ? name : "(unnamed)") << " : "
-            << ("" != description ? description : "(no doc)") << " : "
-            << ("" != type_str ? type_str : "(no type)") << std::endl;
+        out << "  " << i << ", " << (!name.empty() ? name : "(unnamed)") << " : "
+            << (!description.empty() ? description : "(no doc)") << " : "
+            << (!type_str.empty() ? type_str : "(no type)") << std::endl;
       }
     } else {
       out << "  (no explicit description available)" << std::endl;
@@ -879,9 +842,9 @@ std::ostream& operator<<(std::ostream& out, const OpSchema& schema) {
         const auto& name = p.GetName();
         const auto& description = p.GetDescription();
         const auto& type_str = p.GetTypeStr();
-        out << "  " << i << ", " << ("" != name ? name : "(unnamed)") << " : "
-            << ("" != description ? description : "(no doc)") << " : "
-            << ("" != type_str ? type_str : "(no type)") << std::endl;
+        out << "  " << i << ", " << (!name.empty() ? name : "(unnamed)") << " : "
+            << (!description.empty() ? description : "(no doc)") << " : "
+            << (!type_str.empty() ? type_str : "(no type)") << std::endl;
       }
     } else {
       out << "  (no explicit description available)" << std::endl;
@@ -900,15 +863,13 @@ std::ostream& operator<<(std::ostream& out, const OpSchema& schema) {
   return out;
 }
 
-OpSchemaRegistry::DomainToVersionRange&
-OpSchemaRegistry::DomainToVersionRange::Instance() {
+OpSchemaRegistry::DomainToVersionRange& OpSchemaRegistry::DomainToVersionRange::Instance() {
   static DomainToVersionRange domain_to_version_range;
   return domain_to_version_range;
 };
 
 // Private method used by OpSchemaRegisterOnce and OpSchemaRegistry::map()
-OpName_Domain_Version_Schema_Map&
-OpSchemaRegistry::GetMapWithoutEnsuringRegistration() {
+OpName_Domain_Version_Schema_Map& OpSchemaRegistry::GetMapWithoutEnsuringRegistration() {
   static OpName_Domain_Version_Schema_Map map;
   return map;
 }
@@ -940,15 +901,16 @@ OpName_Domain_Version_Schema_Map& OpSchemaRegistry::map() {
       RegisterOnnxPreviewOperatorSetSchema();
 
 #ifndef NDEBUG
-      size_t dbg_registered_schema_count =
-          GetRegisteredSchemaCount() - dbg_initial_schema_count;
-
-      ONNX_ASSERTM(
-          dbg_registered_schema_count == ONNX_DBG_GET_COUNT_IN_OPSETS(),
-          "%u schema were exposed from operator sets and automatically placed into the static registry.  "
-          "%u were expected based on calls to registration macros. Operator set functions may need to be updated.",
-          dbg_registered_schema_count,
-          ONNX_DBG_GET_COUNT_IN_OPSETS());
+      size_t dbg_registered_schema_count = GetRegisteredSchemaCount() - dbg_initial_schema_count;
+      // Check enabled only if schemas for all opset versions are loaded
+      if (OpSchemaRegistry::Instance()->GetLoadedSchemaVersion() == 0) {
+        ONNX_ASSERTM(
+            dbg_registered_schema_count == ONNX_DBG_GET_COUNT_IN_OPSETS(),
+            "%u schema were exposed from operator sets and automatically placed into the static registry.  "
+            "%u were expected based on calls to registration macros. Operator set functions may need to be updated.",
+            dbg_registered_schema_count,
+            ONNX_DBG_GET_COUNT_IN_OPSETS());
+      }
 #endif
     }
 
@@ -975,8 +937,7 @@ size_t ReplaceAll(std::string& s, const char* from, const char* to) {
   size_t numReplaced = 0;
   std::string::size_type lenFrom = std::strlen(from);
   std::string::size_type lenTo = std::strlen(to);
-  for (std::string::size_type pos = s.find(from); pos != std::string::npos;
-       pos = s.find(from, pos + lenTo)) {
+  for (std::string::size_type pos = s.find(from); pos != std::string::npos; pos = s.find(from, pos + lenTo)) {
     s.replace(pos, lenFrom, to);
     numReplaced++;
   }
