@@ -1,5 +1,6 @@
-// Copyright (c) ONNX Project Contributors.
-// Licensed under the MIT license.
+/*
+ * SPDX-License-Identifier: Apache-2.0
+ */
 
 #pragma once
 
@@ -10,7 +11,7 @@
 
 namespace ONNX_NAMESPACE {
 // The below is called by ops after opset 11, inclusively.
-void resizeShapeInference(InferenceContext& ctx, bool is_resize_op);
+void resizeShapeInference(InferenceContext& ctx);
 
 void resizeShapeInferenceHelper(
     const TensorShapeProto& input_shape,
@@ -29,4 +30,6 @@ void resizeShapeInferenceHelper_opset7_to_10(
     const TensorShapeProto& input_shape,
     const std::vector<float>& scales_data,
     TensorShapeProto* output_shape);
+
+extern const char* NonZero_ver9_doc;
 } // namespace ONNX_NAMESPACE
