@@ -1,3 +1,7 @@
+/*
+ * SPDX-License-Identifier: Apache-2.0
+ */
+
 #include "onnxifi_utils.h"
 
 namespace ONNX_NAMESPACE {
@@ -11,8 +15,7 @@ onnxTensorDescriptorV1 ProtoToOnnxTensorDescriptor(
   onnx_tensor.name = proto_tensor.name().c_str();
   onnx_tensor.dataType = proto_tensor.data_type();
   onnx_tensor.memoryType = ONNXIFI_MEMORY_TYPE_CPU;
-  std::vector<uint64_t> shape_values(
-      proto_tensor.dims().begin(), proto_tensor.dims().end());
+  std::vector<uint64_t> shape_values(proto_tensor.dims().begin(), proto_tensor.dims().end());
   shape_pool.emplace_back(std::move(shape_values));
   onnx_tensor.dimensions = (uint32_t)shape_pool.back().size();
   onnx_tensor.shape = shape_pool.back().data();
