@@ -12,9 +12,11 @@
 namespace ONNX_NAMESPACE {
 namespace shape_inference {
 
+using ModelLocalFunctionsMap = std::unordered_map<std::string, const FunctionProto*>;
+
 class SymbolTableImpl : public SymbolTable {
  public:
-  SymbolTableImpl() : index_(0){}
+  SymbolTableImpl() : index_(0) {}
 
   void addFromGraph(const GraphProto& g) {
     AddExistingSymbolicDims(g.input());
@@ -23,11 +25,11 @@ class SymbolTableImpl : public SymbolTable {
   }
   // Creates a new unique symbol with the given prefix and adds it to the SymbolTable
   // Returns the newly created symbol
-  std::string createNew(const std::string& symbol_prefix="unk__") {
+  std::string createNew(const std::string& symbol_prefix = "unk__") {
     std::string newSymbol;
     do {
       newSymbol = symbol_prefix + std::to_string(index_++);
-    } while(existing_symbols.count(newSymbol) > 0);
+    } while (existing_symbols.count(newSymbol) > 0);
     existing_symbols.insert(newSymbol);
     return newSymbol;
   }
@@ -49,19 +51,25 @@ class SymbolTableImpl : public SymbolTable {
   }
 
   void AddExistingSymbolicDims(const TypeProto& typeProto) {
-      const auto val_case = typeProto.value_case();
-      switch (val_case) {
-        case TypeProto::kTensorType:
-          AddExistingSymbolicDims(typeProto.tensor_type());
-          break;
-        case TypeProto::kSparseTensorType:
-          AddExistingSymbolicDims(typeProto.sparse_tensor_type());
-          break;
-        case TypeProto::kSequenceType:
-          AddExistingSymbolicDims(typeProto.sequence_type().elem_type());
-          break;
-        default:
-          break;
+    const auto val_case = typeProto.value_case();
+    switch (val_case) {
+      case TypeProto::kTensorType:
+        AddExistingSymbolicDims(typeProto.tensor_type());
+        break;
+      case TypeProto::kSparseTensorType:
+        AddExistingSymbolicDims(typeProto.sparse_tensor_type());
+        break;
+      case TypeProto::kSequenceType:
+        AddExistingSymbolicDims(typeProto.sequence_type().elem_type());
+        break;
+      case TypeProto::kOptionalType:
+        AddExistingSymbolicDims(typeProto.optional_type().elem_type());
+        break;
+      case TypeProto::kMapType:
+        AddExistingSymbolicDims(typeProto.map_type().value_type());
+        break;
+      default:
+        break;
     }
   }
 
@@ -74,37 +82,38 @@ class SymbolTableImpl : public SymbolTable {
 
 struct GraphInferenceContext {
   GraphInferenceContext(
-      const std::unordered_map<std::string, TypeProto*>&
-          outer_scope_value_types_by_name_in,
+      const std::unordered_map<std::string, TypeProto*>& outer_scope_value_types_by_name_in,
       const std::unordered_map<std::string, int> opset_imports_in,
-      SymbolTable* symbolTable_in,
-      const ISchemaRegistry* schema_registry_in = OpSchemaRegistry::Instance())
+      SymbolTable* symbol_table_in = nullptr,
+      const ModelLocalFunctionsMap& model_local_functions_in = {},
+      const ISchemaRegistry* schema_registry_in = OpSchemaRegistry::Instance(),
+      std::unordered_map<std::string, TensorShapeProto>* generated_shape_data_by_name_in = nullptr,
+      const int ir_version_in = IR_VERSION)
       : outer_scope_value_types_by_name{&outer_scope_value_types_by_name_in},
         opset_imports{opset_imports_in},
+        symbol_table{symbol_table_in},
+        model_local_functions{model_local_functions_in},
         schema_registry{schema_registry_in},
-        symbolTable{symbolTable_in} {}
+        generated_shape_data_by_name{generated_shape_data_by_name_in},
+        ir_version{ir_version_in} {}
 
-
-  const std::unordered_map<std::string, TypeProto*>*
-      outer_scope_value_types_by_name;
+  const std::unordered_map<std::string, TypeProto*>* outer_scope_value_types_by_name;
   const std::unordered_map<std::string, int> opset_imports;
+  SymbolTable* symbol_table;
+  const ModelLocalFunctionsMap& model_local_functions;
   const ISchemaRegistry* schema_registry;
-  SymbolTable* symbolTable;
+  std::unordered_map<std::string, TensorShapeProto>* generated_shape_data_by_name;
+  const int ir_version;
 };
 
 class GraphInferencerImpl : public GraphInferencer {
  public:
-  GraphInferencerImpl(GraphProto& g, GraphInferenceContext& context)
-      : g_{&g}, context_{&context} {}
+  GraphInferencerImpl(GraphProto& g, GraphInferenceContext& context) : g_{&g}, context_{&context} {}
 
   std::vector<const TypeProto*> doInferencing(
       const std::vector<const TypeProto*>& inputTypes,
       const std::vector<const TensorProto*>& inputData) override;
 
-  SymbolTable* getSymbolTable() {
-    return context_->symbolTable;
-  }
-
  private:
   GraphProto* g_;
   GraphInferenceContext* context_;
@@ -114,11 +123,9 @@ struct InferenceContextImpl : public InferenceContext {
   InferenceContextImpl(
       NodeProto& n,
       const std::unordered_map<std::string, TypeProto*>& valueTypesByName,
-      const std::unordered_map<std::string, const TensorProto*>&
-          inputDataByName,
-      const std::unordered_map<std::string, const SparseTensorProto*>& 
-          inputSparseDataByName,
-      const std::unordered_map<std::string, TensorShapeProto>* generatedShapeData = nullptr,
+      const std::unordered_map<std::string, const TensorProto*>& inputDataByName,
+      const std::unordered_map<std::string, const SparseTensorProto*>& inputSparseDataByName,
+      std::unordered_map<std::string, TensorShapeProto>* generatedShapeData = nullptr,
       GraphInferenceContext* graphInferenceContext = nullptr)
       : graphInferenceContext_{graphInferenceContext} {
     for (auto& attr : *n.mutable_attribute()) {
@@ -137,7 +144,7 @@ struct InferenceContextImpl : public InferenceContext {
         allInputTypes_.push_back(nullptr);
       }
 
-      // input data can be in 1 of the 3 containers 
+      // input data can be in 1 of the 3 containers
       // inputDataByName - this is when input is TensorProto
       // inputSparseDataByName - this is when input is SparseTesnorProto
       // generatedShapeData - this is when input was geenrated as part of partial data propagation
@@ -224,11 +231,9 @@ struct InferenceContextImpl : public InferenceContext {
     return &allOutputTypes_[index];
   }
 
-  GraphInferencer* getGraphAttributeInferencer(
-      const std::string& attr_name) override {
+  GraphInferencer* getGraphAttributeInferencer(const std::string& attr_name) override {
     if (!graphInferenceContext_) {
-      fail_type_inference(
-          "GraphProto attribute inferencing is not enabled in this InferenceContextImpl instance.");
+      fail_type_inference("GraphProto attribute inferencing is not enabled in this InferenceContextImpl instance.");
     }
 
     GraphInferencer* inferencer = nullptr;
@@ -238,12 +243,11 @@ struct InferenceContextImpl : public InferenceContext {
       // create GraphInferencer instance
       auto attrNameToGraphProto = graphProtoAttributesByName_.find(attr_name);
       if (attrNameToGraphProto == graphProtoAttributesByName_.cend()) {
-        fail_type_inference(
-            "Attribute ", attr_name, " does not contain a graph.");
+        fail_type_inference("Attribute ", attr_name, " does not contain a graph.");
       }
 
-      std::unique_ptr<GraphInferencer> new_inferencer{new GraphInferencerImpl(
-          *attrNameToGraphProto->second, *graphInferenceContext_)};
+      std::unique_ptr<GraphInferencer> new_inferencer{
+          new GraphInferencerImpl(*attrNameToGraphProto->second, *graphInferenceContext_)};
 
       inferencer = new_inferencer.get();
       graphAttributeInferencers_.emplace(attr_name, std::move(new_inferencer));
@@ -253,6 +257,7 @@ struct InferenceContextImpl : public InferenceContext {
 
     return inferencer;
   }
+
   std::vector<const TensorProto*> allInputData_;
   std::vector<const SparseTensorProto*> allInputSparseData_;
   std::vector<const TensorShapeProto*> allShapeInputData_;
@@ -263,8 +268,7 @@ struct InferenceContextImpl : public InferenceContext {
   GraphInferenceContext* graphInferenceContext_;
 
   // mutable as internal cache of GraphInferencer instances
-  mutable std::unordered_map<std::string, std::unique_ptr<GraphInferencer>>
-      graphAttributeInferencers_;
+  mutable std::unordered_map<std::string, std::unique_ptr<GraphInferencer>> graphAttributeInferencers_;
 };
 
 struct DataPropagationContextImpl : public DataPropagationContext {
@@ -273,9 +277,9 @@ struct DataPropagationContextImpl : public DataPropagationContext {
       const std::unordered_map<std::string, TypeProto*>& valueTypesByName,
       const std::unordered_map<std::string, const TensorProto*>& inputDataByName,
       std::unordered_map<std::string, TensorShapeProto>& generatedShapeData)
-      : generatedShapeData_{generatedShapeData} {
+      : generatedShapeData_(generatedShapeData) {
     size_t input_idx = 0;
-  
+
     for (auto& attr : *n.mutable_attribute()) {
       attributesByName_[attr.name()] = &attr;
     }
@@ -359,25 +363,24 @@ struct DataPropagationContextImpl : public DataPropagationContext {
     const auto* input_data = allInputData_[index];
     // Only scalar (0D tensor) or 1D tensor can be converted for now
     // TODO: It should support tensors with more dimension on demand
-    if (input_data != nullptr &&
-        (input_data->dims_size() == 0 || input_data->dims_size() == 1)) {
-        TensorShapeProto tsp;
+    if (input_data != nullptr && (input_data->dims_size() == 0 || input_data->dims_size() == 1)) {
+      TensorShapeProto tsp;
 
-        if (input_data->data_type() == TensorProto_DataType_INT64) {
-          vectorToTensorShapeProto(ParseData<int64_t>(input_data), tsp);
-        } else if (input_data->data_type() == TensorProto_DataType_INT32) {
-          vectorToTensorShapeProto(ParseData<int32_t>(input_data), tsp);
-        } else {
-          // Only supports integer type to form a shape
-          return nullptr;
-        }
+      if (input_data->data_type() == TensorProto_DataType_INT64) {
+        vectorToTensorShapeProto(ParseData<int64_t>(input_data), tsp);
+      } else if (input_data->data_type() == TensorProto_DataType_INT32) {
+        vectorToTensorShapeProto(ParseData<int32_t>(input_data), tsp);
+      } else {
+        // Only supports integer type to form a shape
+        return nullptr;
+      }
 
-        // Adds this TensorShapeProto from initializer into generatedShapeData
-        // for future use
-        auto result = generatedShapeData_.insert({input_name, std::move(tsp)});
-        if (result.second) {
-          return &(result.first->second);
-        }
+      // Adds this TensorShapeProto from initializer into generatedShapeData
+      // for future use
+      auto result = generatedShapeData_.insert({input_name, std::move(tsp)});
+      if (result.second) {
+        return &(result.first->second);
+      }
     }
     return nullptr;
   }
@@ -401,76 +404,77 @@ struct DataPropagationContextImpl : public DataPropagationContext {
   std::unordered_map<std::string, const AttributeProto*> attributesByName_;
 };
 
-void checkShapesAndTypes(
-    const TypeProto_Sequence& inferredType,
-    const TypeProto_Sequence& existingType);
+void checkShapesAndTypes(const TypeProto_Sequence& inferredType, const TypeProto_Sequence& existingType);
 
-void checkShapesAndTypes(
-    const TypeProto& inferredType,
-    const TypeProto& existingType);
+void checkShapesAndTypes(const TypeProto& inferredType, const TypeProto& existingType);
 
 template <typename TensorTypeProto>
-void generateSymbolicShape(TensorTypeProto* inferredType, SymbolTable& symbolTable);
+void GenerateSymbolicShape(TensorTypeProto* inferredType, SymbolTable& symbolTable);
 
-void materializeSymbolicShape(TypeProto* inferredType, SymbolTable& symbolTable);
+void MaterializeSymbolicShape(TypeProto* inferredType, SymbolTable& symbolTable);
 
-void mergeShapesAndTypes(
-    const TypeProto_Tensor& inferredType,
-    TypeProto_Tensor* existingType);
+void mergeShapesAndTypes(const TypeProto_Tensor& inferredType, TypeProto_Tensor* existingType);
 
-void mergeShapesAndTypes(
-    const TypeProto_SparseTensor& inferredType,
-    TypeProto_SparseTensor* existingType);
+void mergeShapesAndTypes(const TypeProto_SparseTensor& inferredType, TypeProto_SparseTensor* existingType);
 
-void mergeShapesAndTypes(
-    const TypeProto_Sequence& inferredType,
-    TypeProto_Tensor* existingType);
+void mergeShapesAndTypes(const TypeProto_Sequence& inferredType, TypeProto_Tensor* existingType);
 
-void mergeShapesAndTypes(
-    const TypeProto& inferredType,
-    TypeProto* existingType);
-
-void InferShapes(
-    ModelProto& m,
-    const ISchemaRegistry* schema_registry = OpSchemaRegistry::Instance(),
-    const ShapeInferenceOptions& options = {}
-    );
+void mergeShapesAndTypes(const TypeProto& inferredType, TypeProto* existingType);
 
+///
+/// ModelLocalFunctionsMap is a map of function id -> model local function proto
+/// All the ONNX helper utilities expect the function id == <function_proto.domain>:<function_proto.name>
+///
 void InferShapes(
     GraphProto* g,
     const std::unordered_map<std::string, int>& opset_imports,
     const ISchemaRegistry* schema_registry = OpSchemaRegistry::Instance(),
-    const ShapeInferenceOptions& options = {}
-    );
+    const ShapeInferenceOptions& options = {},
+    const ModelLocalFunctionsMap& in_model_functions = {});
+
+void InferShapes(
+    ModelProto& m,
+    const ISchemaRegistry* schema_registry = OpSchemaRegistry::Instance(),
+    const ShapeInferenceOptions& options = {},
+    std::unordered_map<std::string, TensorShapeProto>* generated_shape_data_by_name = nullptr);
 
 void InferShapes(
     const std::string& model_path,
     const std::string& save_path = "",
     const ISchemaRegistry* schema_registry = OpSchemaRegistry::Instance(),
-    const ShapeInferenceOptions& options = {}
-    );
+    const ShapeInferenceOptions& options = {},
+    std::unordered_map<std::string, TensorShapeProto>* generated_shape_data_by_name = nullptr);
 
+///
+/// ModelLocalFunctionsMap is a map of function id -> model local function proto
+/// All the ONNX helper utilities expect the function id == <function_proto.domain>:<function_proto.name>
+///
 void InferShapeForFunctionNode(
-    const FunctionProto* func,
+    const FunctionProto& func,
     const ISchemaRegistry* schema_registry,
     InferenceContext& ctx,
     const ShapeInferenceOptions& options = {},
+    const ModelLocalFunctionsMap& model_local_functions_map = {},
     SymbolTable* symbolTable = nullptr,
-    std::unordered_map<std::string, TensorShapeProto>* generatedShapeDataByName = nullptr);
+    std::unordered_map<std::string, TensorShapeProto>* generated_shape_data_by_name = nullptr);
 
+///
+/// ModelLocalFunctionsMap is a map of function id -> model local function proto
+/// All the ONNX helper utilities expect the function id == <function_proto.domain>:<function_proto.name>
+///
 void InferShapeForFunctionNode(
-    const FunctionProto* func,
+    const FunctionProto& func_proto,
     const std::unordered_map<std::string, int>& func_opset_imports,
     const ISchemaRegistry* schema_registry,
     InferenceContext& ctx,
     const ShapeInferenceOptions& options = {},
+    const ModelLocalFunctionsMap& model_local_functions_map = {},
     SymbolTable* symbolTable = nullptr,
-    std::unordered_map<std::string, TensorShapeProto>* generatedShapeDataByName = nullptr);
-    
+    std::unordered_map<std::string, TensorShapeProto>* generated_shape_data_by_name = nullptr);
 
-std::string getErrorWithNodeInfo(NodeProto n, std::runtime_error err);
+std::string GetErrorWithNodeInfo(NodeProto n, std::runtime_error err);
 
-void traverseGraphsToAddExistingSymbols(const GraphProto& g, SymbolTable& symbolTable);
+void TraverseGraphsToAddExistingSymbols(const GraphProto& g, SymbolTable& symbolTable);
 
 } // namespace shape_inference
 } // namespace ONNX_NAMESPACE
