@@ -1,3 +1,4 @@
+# SPDX-License-Identifier: Apache-2.0
 import unittest
 
 from onnx import defs, helper
@@ -5,7 +6,7 @@ from onnx import defs, helper
 
 class TestRelu(unittest.TestCase):
 
-    def test_relu(self):  # type: () -> None
+    def test_relu(self) -> None:
         self.assertTrue(defs.has('Relu'))
         helper.make_node(
             'Relu', ['X'], ['Y'])
