@@ -1,3 +1,4 @@
+# SPDX-License-Identifier: Apache-2.0
 import unittest
 
 from onnx import defs, AttributeProto
@@ -5,13 +6,13 @@ from onnx import defs, AttributeProto
 
 class TestSchema(unittest.TestCase):
 
-    def test_get_schema(self):  # type: () -> None
+    def test_get_schema(self) -> None:
         defs.get_schema("Relu")
 
-    def test_typecheck(self):  # type: () -> None
+    def test_typecheck(self) -> None:
         defs.get_schema("Conv")
 
-    def test_attr_default_value(self):  # type: () -> None
+    def test_attr_default_value(self) -> None:
         v = defs.get_schema(
             "BatchNormalization").attributes['epsilon'].default_value
         self.assertEqual(type(v), AttributeProto)
