@@ -1,16 +1,17 @@
 #!/usr/bin/env python
 
+# SPDX-License-Identifier: Apache-2.0
+
 import subprocess
 import os
 
 
-def main():  # type: () -> None
+def main() -> None:
     try:
         root_folder = os.path.realpath(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
         os.chdir(root_folder)
-
-        subprocess.check_call(["mypy", "."])
-        subprocess.check_call(["mypy", "--py2", "."])
+        # Use --no-site-packages to prevent mypy catching other typecheck errors which are not related to ONNX itself
+        subprocess.check_call(["mypy", ".", "--no-site-packages"])
 
         exit(0)
     except subprocess.CalledProcessError:
